@@ -1,14 +1,6 @@
-/////////////////////////////////////////////////////////////////////////////
-
-// Name:        3d_canvas.cpp
-/////////////////////////////////////////////////////////////////////////////
-
-
-#ifdef __GNUG__
-#pragma implementation
-#pragma interface
-#endif
-
+/**
+ * @file 3d_canvas.cpp
+*/
 #include "fctsys.h"
 #include "trigo.h"
 
@@ -20,96 +12,113 @@
 
 #include "wx/dataobj.h"
 #include "wx/clipbrd.h"
+#include <wx/wupdlock.h>
 
-#include "fctsys.h"
-#include "id.h"
 #include "gestfich.h"
 
 #include "3d_viewer.h"
 #include "trackball.h"
 
-/* Tool and button Bitmaps */
-#define XPM_3D_MAIN
-#include "bitmaps.h"
 
-enum onrclick_id {
-    ID_POPUP_3D_VIEW_START = 2000,
-    ID_POPUP_ZOOMIN,
-    ID_POPUP_ZOOMOUT,
-    ID_POPUP_VIEW_XPOS,
-    ID_POPUP_VIEW_XNEG,
-    ID_POPUP_VIEW_YPOS,
-    ID_POPUP_VIEW_YNEG,
-    ID_POPUP_VIEW_ZPOS,
-    ID_POPUP_VIEW_ZNEG,
-    ID_POPUP_MOVE3D_LEFT,
-    ID_POPUP_MOVE3D_RIGHT,
-    ID_POPUP_MOVE3D_UP,
-    ID_POPUP_MOVE3D_DOWN,
-    ID_POPUP_3D_VIEW_END
-};
+// -----------------
+// helper function (from wxWidgets, opengl/cube.cpp sample
+// -----------------
+void CheckGLError()
+{
+    GLenum errLast = GL_NO_ERROR;
 
+    for ( ; ; )
+    {
+        GLenum err = glGetError();
+        if ( err == GL_NO_ERROR )
+            return;
+
+        // normally the error is reset by the call to glGetError() but if
+        // glGetError() itself returns an error, we risk looping forever here
+        // so check that we get a different error than the last time
+        if ( err == errLast )
+        {
+            wxLogError(wxT("OpenGL error state couldn't be reset."));
+            return;
+        }
+
+        errLast = err;
+
+        wxLogError(wxT("OpenGL error %d"), err);
+    }
+}
 
 /*
  * Pcb3D_GLCanvas implementation
  */
 
 BEGIN_EVENT_TABLE( Pcb3D_GLCanvas, wxGLCanvas )
-EVT_SIZE( Pcb3D_GLCanvas::OnSize )
 EVT_PAINT( Pcb3D_GLCanvas::OnPaint )
+
+// key event:
 EVT_CHAR( Pcb3D_GLCanvas::OnChar )
-EVT_MOUSE_EVENTS( Pcb3D_GLCanvas::OnMouseEvent )
+
+// mouse events
+EVT_RIGHT_DOWN( Pcb3D_GLCanvas::OnRightClick )
+EVT_MOUSEWHEEL( Pcb3D_GLCanvas::OnMouseWheel )
+EVT_MOTION( Pcb3D_GLCanvas::OnMouseMove )
+
+// other events
 EVT_ERASE_BACKGROUND( Pcb3D_GLCanvas::OnEraseBackground )
 EVT_MENU_RANGE( ID_POPUP_3D_VIEW_START, ID_POPUP_3D_VIEW_END,
                 Pcb3D_GLCanvas::OnPopUpMenu )
 END_EVENT_TABLE()
 
-/*************************************************************************/
-Pcb3D_GLCanvas::Pcb3D_GLCanvas( WinEDA3D_DrawFrame* parent, const wxWindowID id,
-                                int* gl_attrib ) :
-    wxGLCanvas( parent, id,
-                wxPoint( -1, -1 ), wxSize( -1, -1 ), 0, wxT( "Pcb3D_glcanvas" ), gl_attrib )
-/*************************************************************************/
+Pcb3D_GLCanvas::Pcb3D_GLCanvas( WinEDA3D_DrawFrame* parent, int* attribList ) :
+#if wxCHECK_VERSION( 2, 7, 0 )
+    wxGLCanvas( parent, -1, attribList, wxDefaultPosition, wxDefaultSize,
+                wxFULL_REPAINT_ON_RESIZE )
+#else
+    wxGLCanvas( parent, -1, wxDefaultPosition, wxDefaultSize,
+                wxFULL_REPAINT_ON_RESIZE )
+#endif
 {
     m_init   = FALSE;
     m_gllist = 0;
     m_Parent = parent;
+    m_ortho = false;
+
+#if wxCHECK_VERSION( 2, 7, 0 )
+
+    // Explicitly create a new rendering context instance for this canvas.
+    m_glRC = new wxGLContext( this );
+#endif
+
     DisplayStatus();
 }
 
 
-/*************************************/
 Pcb3D_GLCanvas::~Pcb3D_GLCanvas()
-/*************************************/
 {
     ClearLists();
-	m_init = FALSE;
+    m_init = FALSE;
+#if wxCHECK_VERSION( 2, 7, 0 )
+    delete m_glRC;
+#endif
 }
 
 
-/*************************************/
 void Pcb3D_GLCanvas::ClearLists()
-/*************************************/
 {
     if( m_gllist > 0 )
         glDeleteLists( m_gllist, 1 );
-//    m_init   = FALSE;
     m_gllist = 0;
 }
 
 
-/*********************************************/
 void Pcb3D_GLCanvas::OnChar( wxKeyEvent& event )
-/*********************************************/
 {
     SetView3D( event.GetKeyCode() );
     event.Skip();
 }
 
 
-/*********************************************/
 void Pcb3D_GLCanvas::SetView3D( int keycode )
-/*********************************************/
 {
     int    ii;
     double delta_move = 0.7 * g_Parm_3D_Visu.m_Zoom;
@@ -225,61 +234,59 @@ void Pcb3D_GLCanvas::SetView3D( int keycode )
 }
 
 
-/********************************************************/
-void Pcb3D_GLCanvas::OnMouseEvent( wxMouseEvent& event )
-/********************************************************/
+void Pcb3D_GLCanvas::OnMouseWheel( wxMouseEvent& event )
 {
     wxSize size( GetClientSize() );
-    double  spin_quat[4];
 
-
-    if( event.RightDown() )
+    if( event.ShiftDown() )
     {
-        OnRightClick( event ); return;
-    }
-
-    if( event.m_wheelRotation )
-    {
-        if( event.ShiftDown() )
+        if( event.GetWheelRotation() < 0 )
         {
-            if( event.GetWheelRotation() < 0 )
-            {
-                /* up */
-                SetView3D( WXK_UP );
-            }
-            else
-            {
-                /* down */
-                SetView3D( WXK_DOWN );
-            }
-        }
-        else if( event.ControlDown() )
-        {
-            if( event.GetWheelRotation() > 0 )
-            {
-                /* right */
-                SetView3D( WXK_RIGHT );
-            }
-            else
-            {
-                /* left */
-                SetView3D( WXK_LEFT );
-            }
+            /* up */
+            SetView3D( WXK_UP );
         }
         else
         {
-            if( event.GetWheelRotation() > 0 )
-            {
-                g_Parm_3D_Visu.m_Zoom /= 1.4;
-                if( g_Parm_3D_Visu.m_Zoom <= 0.01 )
-                    g_Parm_3D_Visu.m_Zoom = 0.01;
-            }
-            else
-                g_Parm_3D_Visu.m_Zoom *= 1.4;
-            DisplayStatus();
-            Refresh( FALSE );
+            /* down */
+            SetView3D( WXK_DOWN );
         }
     }
+    else if( event.ControlDown() )
+    {
+        if( event.GetWheelRotation() > 0 )
+        {
+            /* right */
+            SetView3D( WXK_RIGHT );
+        }
+        else
+        {
+            /* left */
+            SetView3D( WXK_LEFT );
+        }
+    }
+    else
+    {
+        if( event.GetWheelRotation() > 0 )
+        {
+            g_Parm_3D_Visu.m_Zoom /= 1.4;
+            if( g_Parm_3D_Visu.m_Zoom <= 0.01 )
+                g_Parm_3D_Visu.m_Zoom = 0.01;
+        }
+        else
+            g_Parm_3D_Visu.m_Zoom *= 1.4;
+        DisplayStatus();
+        Refresh( FALSE );
+    }
+
+    g_Parm_3D_Visu.m_Beginx = event.GetX();
+    g_Parm_3D_Visu.m_Beginy = event.GetY();
+}
+
+
+void Pcb3D_GLCanvas::OnMouseMove( wxMouseEvent& event )
+{
+    wxSize size( GetClientSize() );
+    double spin_quat[4];
 
     if( event.Dragging() )
     {
@@ -297,10 +304,14 @@ void Pcb3D_GLCanvas::OnMouseEvent( wxMouseEvent& event )
         else if( event.MiddleIsDown() )
         {
             /* middle button drag -> pan */
-            /* Current zoom and an additional factor are taken into account for the amount of panning. */
+
+            /* Current zoom and an additional factor are taken into account
+             * for the amount of panning. */
             const double PAN_FACTOR = 8.0 * g_Parm_3D_Visu.m_Zoom;
-            g_Draw3d_dx -= PAN_FACTOR * ( g_Parm_3D_Visu.m_Beginx - event.GetX() ) / size.x;
-            g_Draw3d_dy -= PAN_FACTOR * (event.GetY() - g_Parm_3D_Visu.m_Beginy) / size.y;
+            g_Draw3d_dx -= PAN_FACTOR *
+                           ( g_Parm_3D_Visu.m_Beginx - event.GetX() ) / size.x;
+            g_Draw3d_dy -= PAN_FACTOR *
+                           (event.GetY() - g_Parm_3D_Visu.m_Beginy) / size.y;
         }
 
         /* orientation has changed, redraw mesh */
@@ -313,13 +324,9 @@ void Pcb3D_GLCanvas::OnMouseEvent( wxMouseEvent& event )
 }
 
 
-/*******************************************************/
-void Pcb3D_GLCanvas::OnRightClick( wxMouseEvent& event )
-/*******************************************************/
-
-/* Construit et affiche un menu Popup lorsque on actionne le bouton droit
- *  de la souris
+/* Construct and display a popup menu when the right button is clicked.
  */
+void Pcb3D_GLCanvas::OnRightClick( wxMouseEvent& event )
 {
     wxPoint     pos;
     wxMenu      PopUpMenu;
@@ -394,9 +401,7 @@ void Pcb3D_GLCanvas::OnRightClick( wxMouseEvent& event )
 }
 
 
-/*******************************************************/
 void Pcb3D_GLCanvas::OnPopUpMenu( wxCommandEvent& event )
-/*******************************************************/
 {
     int key = 0;
 
@@ -458,9 +463,7 @@ void Pcb3D_GLCanvas::OnPopUpMenu( wxCommandEvent& event )
 }
 
 
-/***************************************/
 void Pcb3D_GLCanvas::DisplayStatus()
-/***************************************/
 {
     wxString msg;
 
@@ -475,56 +478,23 @@ void Pcb3D_GLCanvas::DisplayStatus()
 }
 
 
-/*************************************************/
 void Pcb3D_GLCanvas::OnPaint( wxPaintEvent& event )
-/*************************************************/
 {
     wxPaintDC dc( this );
 
-#ifndef __WXMOTIF__
-    if( !GetContext() )
-        return;
-#endif
     Redraw();
     event.Skip();
 }
 
 
-/**********************************************/
-void Pcb3D_GLCanvas::OnSize( wxSizeEvent& event )
-/**********************************************/
-{
-    int w, h;
-    // set GL viewport (not called by wxGLCanvas::OnSize on all platforms...)
-    // this is also necessary to update the context on some platforms
-    wxGLCanvas::OnSize( event );
-
-    GetClientSize( &w, &h );
-#ifndef __WXMOTIF__
-    if( GetContext() )
-#endif
-    {
-        glViewport( 0, 0, (GLint) w, (GLint) h );
-    }
-
-    event.Skip();
-}
-
-
-/***********************************************************/
 void Pcb3D_GLCanvas::OnEraseBackground( wxEraseEvent& event )
-/***********************************************************/
 {
     // Do nothing, to avoid flashing.
 }
 
 
-/****************************/
+/* Initialize broad parameters for OpenGL */
 void Pcb3D_GLCanvas::InitGL()
-/****************************/
-
-/* Int parametres generaux pour OPENGL
- */
 {
     wxSize size = GetClientSize();
 
@@ -533,61 +503,72 @@ void Pcb3D_GLCanvas::InitGL()
         m_init = TRUE;
         g_Parm_3D_Visu.m_Zoom = 1.0;
         ZBottom = 1.0; ZTop = 10.0;
+
+        glDisable( GL_CULL_FACE );      // show back faces
+
+        glEnable( GL_DEPTH_TEST );      // Enable z-buferring
+
+        glEnable( GL_LINE_SMOOTH );
+        glEnable( GL_COLOR_MATERIAL );
+        glColorMaterial( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
+
+        /* speedups */
+        glEnable( GL_DITHER );
+        glShadeModel( GL_SMOOTH );
+        glHint( GL_PERSPECTIVE_CORRECTION_HINT, GL_FASTEST );
+        glHint( GL_POLYGON_SMOOTH_HINT, GL_FASTEST );
+
+        /* blend */
+        glEnable( GL_BLEND );
+        glBlendFunc( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA );
     }
 
-    /* set viewing projection */
-    double ratio_HV = (double) size.x / size.y; // Ratio largeur /hauteur de la fenetre d'affichage
+    // set viewing projection
+
     glMatrixMode( GL_PROJECTION );
     glLoadIdentity();
 
-#define MAX_VIEW_ANGLE  160.0 / 45.0
+#define MAX_VIEW_ANGLE 160.0 / 45.0
     if( g_Parm_3D_Visu.m_Zoom > MAX_VIEW_ANGLE )
         g_Parm_3D_Visu.m_Zoom = MAX_VIEW_ANGLE;
-    gluPerspective( 45.0 * g_Parm_3D_Visu.m_Zoom, ratio_HV, 1, 10 );
 
-//	glFrustum(-1., 1.1F, -1.1F, 1.1F, ZBottom, ZTop);
+     if( ModeIsOrtho() )
+     {
+         // OrthoReductionFactor is chosen so as to provide roughly the same size as Perspective View
+         const double orthoReductionFactor = 400/g_Parm_3D_Visu.m_Zoom;
+         // Initialize Projection Matrix for Ortographic View
+         glOrtho(-size.x/orthoReductionFactor, size.x/orthoReductionFactor, -size.y/orthoReductionFactor, size.y/orthoReductionFactor, 1, 10);
+     }
+     else
+     {
+         // Ratio width / height of the window display
+         double ratio_HV = (double) size.x / size.y;
 
-    /* position viewer */
+         // Initialize Projection Matrix for Perspective View
+         gluPerspective( 45.0 * g_Parm_3D_Visu.m_Zoom, ratio_HV, 1, 10 );
+     }
+
+
+    // position viewer
     glMatrixMode( GL_MODELVIEW );
     glLoadIdentity();
     glTranslatef( 0.0F, 0.0F, -( ZBottom + ZTop) / 2 );
 
-    /* clear color and depth buffers */
+    // clear color and depth buffers
     glClearColor( g_Parm_3D_Visu.m_BgColor.m_Red,
                   g_Parm_3D_Visu.m_BgColor.m_Green,
                   g_Parm_3D_Visu.m_BgColor.m_Blue, 1 );
     glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
 
-    /* Setup light souces: */
+    // Setup light souces:
     SetLights();
 
-
-    glDisable( GL_CULL_FACE );      // show back faces
-
-    glEnable( GL_DEPTH_TEST );      // Enable z-buferring
-
-    glEnable( GL_LINE_SMOOTH );
-    glEnable( GL_COLOR_MATERIAL );
-    glColorMaterial( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE );
-
-    /* speedups */
-    glEnable( GL_DITHER );
-    glShadeModel( GL_SMOOTH );
-    glHint( GL_PERSPECTIVE_CORRECTION_HINT, GL_FASTEST );
-    glHint( GL_POLYGON_SMOOTH_HINT, GL_FASTEST );
-
-    /* blend */
-    glEnable( GL_BLEND );
-    glBlendFunc( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA );
+    CheckGLError();
 }
 
 
-/***********************************/
+/* Initialize OpenGL light sources. */
 void Pcb3D_GLCanvas::SetLights()
-/***********************************/
-
-/* Init sources lumineuses pour OPENGL
- */
 {
     double  light;
     GLfloat light_color[4];
@@ -612,49 +593,69 @@ void Pcb3D_GLCanvas::SetLights()
 }
 
 
-/**********************************************************/
-void Pcb3D_GLCanvas::TakeScreenshot( wxCommandEvent& event )
-/**********************************************************/
-
 /* Create a Screenshot of the current 3D view.
- *  Output file format is png or jpeg, or image is copied on clipboard
+ *  Output file format is png or jpeg, or image is copied to the clipboard
  */
+void Pcb3D_GLCanvas::TakeScreenshot( wxCommandEvent& event )
 {
-    wxString FullFileName;
-    wxString file_ext, mask;
-    bool     fmt_is_jpeg = FALSE;
+    wxFileName fn( m_Parent->m_Parent->GetScreen()->GetFileName() );
+    wxString   FullFileName;
+    wxString   file_ext, mask;
+    bool       fmt_is_jpeg = FALSE;
 
     if( event.GetId() == ID_MENU_SCREENCOPY_JPEG )
         fmt_is_jpeg = TRUE;
     if( event.GetId() != ID_TOOL_SCREENCOPY_TOCLIBBOARD )
     {
-        file_ext = fmt_is_jpeg ? wxT( ".jpg" ) : wxT( ".png"; )
-                   mask = wxT( "*" ) + file_ext;
-        FullFileName    = m_Parent->m_Parent->GetScreen()->m_FileName;
-        ChangeFileNameExt( FullFileName, file_ext );
+        file_ext     = fmt_is_jpeg ? wxT( "jpg" ) : wxT( "png" );
+        mask         = wxT( "*." ) + file_ext;
+        FullFileName = m_Parent->m_Parent->GetScreen()->GetFileName();
+        fn.SetExt( file_ext );
 
         FullFileName =
-            EDA_FileSelector( _( "3D Image filename:" ),
-                              wxEmptyString,    /* Chemin par defaut */
-                              FullFileName,     /* nom fichier par defaut */
-                              file_ext,         /* extension par defaut */
-                              mask,             /* Masque d'affichage */
-                              this,
-                              wxFD_SAVE,
-                              TRUE
-                              );
+            EDA_FileSelector( _( "3D Image filename:" ), wxEmptyString,
+                              fn.GetFullName(), file_ext, mask, this,
+                              wxFD_SAVE, TRUE );
+
         if( FullFileName.IsEmpty() )
             return;
+
+        // Be sure the screen area destroyed by the file dialog is redrawn before making
+        // a screen copy.
+        // Without this call, under Linux the screen refresh is made to late.
+        wxYield();
     }
 
-    Redraw( true );
-    wxSize     image_size = GetClientSize();
-    wxClientDC dc( this );
-    wxBitmap   bitmap( image_size.x, image_size.y );
-    wxMemoryDC memdc;
-    memdc.SelectObject( bitmap );
-    memdc.Blit( 0, 0, image_size.x, image_size.y, &dc, 0, 0 );
-    memdc.SelectObject( wxNullBitmap );
+    struct vieport_params
+    {
+        GLint originx;
+        GLint originy;
+        GLint x;
+        GLint y;
+    } viewport;
+
+    // Build image from the 3D buffer
+    wxWindowUpdateLocker noUpdates( this );
+    glGetIntegerv( GL_VIEWPORT, (GLint*) &viewport );
+
+    unsigned char*       pixelbuffer = (unsigned char*) malloc( viewport.x * viewport.y * 3 );
+    unsigned char*       alphabuffer = (unsigned char*) malloc( viewport.x * viewport.y );
+    wxImage image( viewport.x, viewport.y );
+
+    glPixelStorei( GL_PACK_ALIGNMENT, 1 );
+    glReadBuffer( GL_BACK_LEFT );
+    glReadPixels( viewport.originx, viewport.originy,
+                  viewport.x, viewport.y,
+                  GL_RGB, GL_UNSIGNED_BYTE, pixelbuffer );
+    glReadPixels( viewport.originx, viewport.originy,
+                  viewport.x, viewport.y,
+                  GL_ALPHA, GL_UNSIGNED_BYTE, alphabuffer );
+
+
+    image.SetData( pixelbuffer );
+    image.SetAlpha( alphabuffer );
+    image = image.Mirror( false );
+    wxBitmap bitmap( image );
 
     if( event.GetId() == ID_TOOL_SCREENCOPY_TOCLIBBOARD )
     {
@@ -663,9 +664,11 @@ void Pcb3D_GLCanvas::TakeScreenshot( wxCommandEvent& event )
         if( wxTheClipboard->Open() )
         {
             if( !wxTheClipboard->SetData( dobjBmp ) )
-                wxLogError( _T( "Failed to copy image to clipboard" ) );
-            wxTheClipboard->Flush();    /* the data on clipboard
-                                         *  will stay available after the application exits */
+                wxMessageBox( _( "Failed to copy image to clipboard" ) );
+
+            wxTheClipboard->Flush();    /* the data in clipboard will stay
+                                         * available after the
+                                         * application exits */
             wxTheClipboard->Close();
         }
     }
@@ -674,8 +677,9 @@ void Pcb3D_GLCanvas::TakeScreenshot( wxCommandEvent& event )
         wxImage image = bitmap.ConvertToImage();
 
         if( !image.SaveFile( FullFileName,
-                             fmt_is_jpeg ? wxBITMAP_TYPE_JPEG : wxBITMAP_TYPE_PNG ) )
-            wxLogError( wxT( "Can't save file" ) );
+                             fmt_is_jpeg ? wxBITMAP_TYPE_JPEG :
+                             wxBITMAP_TYPE_PNG ) )
+            wxMessageBox( _( "Can't save file" ) );
 
         image.Destroy();
     }
