@@ -2,13 +2,6 @@
 // Name:        3d_frame.cpp
 /////////////////////////////////////////////////////////////////////////////
 
-
-#ifdef __GNUG__
-#pragma implementation
-#pragma interface
-#endif
-
-
 #include "fctsys.h"
 #include "appl_wxstruct.h"
 
@@ -16,8 +9,6 @@
 #error Please set wxUSE_GLCANVAS to 1 in setup.h.
 #endif
 
-#include "bitmaps.h"
-
 #include "3d_viewer.h"
 #include "trackball.h"
 
@@ -33,6 +24,7 @@ double       DataScale3D; // 3D conversion units.
 
 
 BEGIN_EVENT_TABLE( WinEDA3D_DrawFrame, wxFrame )
+    EVT_ACTIVATE( WinEDA3D_DrawFrame::OnActivate )
     EVT_TOOL_RANGE( ID_ZOOM_IN, ID_ZOOM_PAGE, WinEDA3D_DrawFrame::Process_Zoom )
     EVT_TOOL_RANGE( ID_START_COMMAND_3D, ID_END_COMMAND_3D,
                     WinEDA3D_DrawFrame::Process_Special_Functions )
@@ -44,11 +36,10 @@ BEGIN_EVENT_TABLE( WinEDA3D_DrawFrame, wxFrame )
     EVT_CLOSE( WinEDA3D_DrawFrame::OnCloseWindow )
 END_EVENT_TABLE()
 
-WinEDA3D_DrawFrame::WinEDA3D_DrawFrame( WinEDA_BasePcbFrame* parent,
-                                        const wxString&      title,
-                                        long                 style ) :
-    wxFrame( parent, DISPLAY3D_FRAME, title, wxPoint( -1, -1 ),
-             wxSize( -1, -1 ), style )
+WinEDA3D_DrawFrame::WinEDA3D_DrawFrame( PCB_BASE_FRAME* parent,
+                                        const wxString& title,
+                                        long            style ) :
+    wxFrame( parent, DISPLAY3D_FRAME, title, wxPoint( -1, -1 ), wxSize( -1, -1 ), style )
 {
     m_FrameName     = wxT( "Frame3D" );
     m_Canvas        = NULL;
@@ -56,6 +47,7 @@ WinEDA3D_DrawFrame::WinEDA3D_DrawFrame( WinEDA_BasePcbFrame* parent,
     m_HToolBar      = NULL;
     m_VToolBar      = NULL;
     m_InternalUnits = 10000;    // Internal units = 1/10000 inch
+    m_reloadRequest = false;
 
     // Give it an icon
     SetIcon( wxICON( icon_w3d ) );
@@ -76,7 +68,8 @@ WinEDA3D_DrawFrame::WinEDA3D_DrawFrame( WinEDA_BasePcbFrame* parent,
     ReCreateVToolbar();
 
     // Make a Pcb3D_GLCanvas
-    m_Canvas = new Pcb3D_GLCanvas( this );
+    int attrs[] = {WX_GL_RGBA, WX_GL_DOUBLEBUFFER, WX_GL_DEPTH_SIZE, 16, 0};
+    m_Canvas = new Pcb3D_GLCanvas( this, attrs );
 
     m_auimgr.SetManagedWindow( this );
 
@@ -291,6 +284,10 @@ void WinEDA3D_DrawFrame::Process_Special_Functions( wxCommandEvent& event )
         m_Canvas->SetView3D( WXK_DOWN );
         return;
 
+    case ID_ORTHO:
+        m_Canvas->ToggleOrtho();
+        return;
+
     case ID_TOOL_SCREENCOPY_TOCLIBBOARD:
     case ID_MENU_SCREENCOPY_PNG:
     case ID_MENU_SCREENCOPY_JPEG:
@@ -342,6 +339,8 @@ error: unknown command" ) );
 
 void WinEDA3D_DrawFrame::NewDisplay()
 {
+    m_reloadRequest = false;
+
     m_Canvas->ClearLists();
     m_Canvas->CreateDrawGL_List();
 
@@ -351,6 +350,17 @@ void WinEDA3D_DrawFrame::NewDisplay()
 }
 
 
+void WinEDA3D_DrawFrame::OnActivate( wxActivateEvent& event )
+{
+    // Reload data if 3D frame shows a footprint,
+    // because it can be changed since last frame activation
+    if( m_reloadRequest )
+        NewDisplay();
+
+    event.Skip();   // required under wxMAC
+}
+
+
 /* called to set the background color of the 3D scene
  */
 void WinEDA3D_DrawFrame::Set3DBgColor()
