@@ -19,7 +19,7 @@ void WinEDA3D_DrawFrame::ReCreateHToolbar()
     }
 
 
-    m_HToolBar = new WinEDA_Toolbar( TOOLBAR_MAIN, this, ID_H_TOOLBAR, TRUE );
+    m_HToolBar = new EDA_TOOLBAR( TOOLBAR_MAIN, this, ID_H_TOOLBAR, TRUE );
 
     // Set up toolbar
     m_HToolBar->AddTool( ID_RELOAD3D_BOARD, wxEmptyString,
@@ -46,8 +46,8 @@ void WinEDA3D_DrawFrame::ReCreateHToolbar()
                          wxBitmap( zoom_redraw_xpm ),
                          _( "Redraw view" ) );
 
-    m_HToolBar->AddTool( ID_ZOOM_PAGE, wxEmptyString, wxBitmap( zoom_auto_xpm ),
-                         _( "Zoom auto" ) );
+    m_HToolBar->AddTool( ID_ZOOM_PAGE, wxEmptyString, wxBitmap( zoom_fit_in_page_xpm ),
+                         _( "Fit in page" ) );
 
     m_HToolBar->AddSeparator();
     m_HToolBar->AddTool( ID_ROTATE3D_X_NEG, wxEmptyString,
@@ -87,7 +87,12 @@ void WinEDA3D_DrawFrame::ReCreateHToolbar()
                          _( "Move up ^" ) );
 
     m_HToolBar->AddTool( ID_MOVE3D_DOWN, wxEmptyString, wxBitmap( down_xpm ),
-                         _( "Move down" ) );
+                         _( "Move down v" ) );
+
+    m_HToolBar->AddSeparator();
+    m_HToolBar->AddTool( ID_ORTHO, wxEmptyString, wxBitmap( ortho_xpm ),
+                         _( "Enable/Disable orthographic projection" ),
+                         wxITEM_CHECK );
 
     m_HToolBar->Realize();
 }
@@ -104,9 +109,9 @@ void WinEDA3D_DrawFrame::ReCreateMenuBar()
 
     // If called from the display frame of cvpcb, only some options are
     // relevant
-    if( m_Parent->m_FrameName == wxT( "CmpFrame" ) )    // Called from cvpcb !
-        full_options = false;                           // Do not display all
-                                                        // options
+    if( m_Parent->m_FrameName == wxT( "CmpFrame" ) )
+    // Called from cvpcb: do not display all options
+        full_options = false;
 
     wxMenuBar* menuBar = new wxMenuBar;
 
@@ -118,6 +123,13 @@ void WinEDA3D_DrawFrame::ReCreateMenuBar()
                       _( "Create Image (png format)" ) );
     fileMenu->Append( ID_MENU_SCREENCOPY_JPEG,
                       _( "Create Image (jpeg format)" ) );
+
+#if (defined(__WINDOWS__) || defined(__APPLE__ ) )
+    // Does not work properly under linux
+    fileMenu->AppendSeparator();
+    fileMenu->Append( ID_TOOL_SCREENCOPY_TOCLIBBOARD,
+                         _( "Copy 3D Image to Clipboard" ) );
+#endif
     fileMenu->AppendSeparator();
     fileMenu->Append( wxID_EXIT, _( "&Exit" ) );
 
