@@ -55,7 +55,7 @@
 static inline double DegToRad( double deg )
 {
     return (deg * M_PI) / 180.0;
-};
+}
 
 wxString wxColStr( wxColour c )
 {
@@ -157,8 +157,8 @@ void wxSVGFileDC::Init( wxString f, int Width, int Height, float dpi )
         write( s );
         s.Printf( wxT( "  version=\"1.1\"\n" ) );
         write( s );
-        s.Printf( wxT( "  width=\"%.2gcm\" height=\"%.2gcm\" viewBox=\"0 0 %d %d \"\n" ),
-                  float (Width) / dpi * 2.54, float (Height) / dpi * 2.54, Width, Height );
+        s.Printf( wxT( "  width=\"%gin\" height=\"%gin\" viewBox=\"0 0 %d %d \"\n" ),
+                  double (Width) / dpi, double (Height) / dpi, Width, Height );
         write( s );
         s.Printf( wxT( ">\n" ) );
         write( s );
@@ -180,17 +180,17 @@ wxSVGFileDC::wxSVGFileDC( wxString f )
 {
     // quarter 640x480 screen display at 72 dpi
     Init( f, 320, 240, 72.0 );
-};
+}
 
 wxSVGFileDC::wxSVGFileDC( wxString f, int Width, int Height )
 {
     Init( f, Width, Height, 72.0 );
-};
+}
 
 wxSVGFileDC::wxSVGFileDC( wxString f, int Width, int Height, float dpi )
 {
     Init( f, Width, Height, dpi );
-};
+}
 
 wxSVGFileDC::~wxSVGFileDC()
 {
@@ -217,7 +217,7 @@ void wxSVGFileDC::DoDrawLine( wxCoord x1, wxCoord y1, wxCoord x2, wxCoord y2 )
     CalcBoundingBox( x1, y1 );
     CalcBoundingBox( x2, y2 );
     return;
-};
+}
 
 void wxSVGFileDC::DoDrawLines( int n, wxPoint points[], wxCoord xoffset, wxCoord yoffset )
 {
@@ -879,7 +879,7 @@ void wxSVGFileDC::DoDrawIcon( const class wxIcon& myIcon, wxCoord x, wxCoord y )
 void wxSVGFileDC::DoDrawBitmap( const class wxBitmap& bmp,
                                 wxCoord               x,
                                 wxCoord               y,
-                                bool WXUNUSED (       bTransparent) /*=0*/ )
+                                bool                  bTransparent /*=0*/ )
 {
     if( m_graphics_changed )
         NewGraphics();
