@@ -17,59 +17,30 @@
 #include "kicad_device_context.h"
 #include "hotkeys_basic.h"
 
-/** Compute draw offset (scroll bars and draw parameters)
- *  in order to have the current graphic cursor position at the screen center
- *  @param ToMouse if TRUE, the mouse cursor is moved
- *  to the graphic cursor position (which is usually on grid)
- *
- *  Note: Mac OS ** does not ** allow moving mouse cursor by program.
- */
-void WinEDA_DrawFrame::Recadre_Trace( bool ToMouse )
+
+void EDA_DRAW_FRAME::RedrawScreen( const wxPoint& aCenterPoint, bool aWarpPointer )
 {
-    PutOnGrid( &(GetBaseScreen()->m_Curseur) );
-    AdjustScrollBars();
+    AdjustScrollBars( aCenterPoint );
 
-
-    /* We do not use here DrawPanel->Refresh() because
-     * the redraw is delayed and the mouse events (from MouseToCursorSchema ot others)
-     * during this delay create problems: the mouse cursor position is false in calculations.
-     * TODO: see exactly how the mouse creates problems when moving during refresh
-     * use Refresh() and update() do not change problems
-     */
-    INSTALL_DC( dc, DrawPanel );
-    DrawPanel->ReDraw( &dc );
+    DrawPanel->Refresh();
+    DrawPanel->Update();
 
     /* Move the mouse cursor to the on grid graphic cursor position */
-    if( ToMouse == TRUE )
-        DrawPanel->MouseToCursorSchema();
+    if( aWarpPointer )
+        DrawPanel->MoveCursorToCrossHair();
  }
 
 
-/** Adjust the coordinate to the nearest grid value
- * @param coord = coordinate to adjust
- */
-void WinEDA_DrawFrame::PutOnGrid( wxPoint* coord )
-{
-    wxRealPoint grid_size = GetBaseScreen()->GetGridSize();
-
-    if( !GetBaseScreen()->m_UserGridIsON )
-    {
-        int tmp = wxRound( (double) coord->x / grid_size.x );
-        coord->x = wxRound( (double) tmp * grid_size.x );
-
-        tmp = wxRound( (double) coord->y / grid_size.y );
-        coord->y = wxRound( (double) tmp * grid_size.y );
-    }
-}
-
-
 /** Redraw the screen with best zoom level and the best centering
  * that shows all the page or the board
  */
-void WinEDA_DrawFrame::Zoom_Automatique( bool move_mouse_cursor )
+void EDA_DRAW_FRAME::Zoom_Automatique( bool aWarpPointer )
 {
-    GetBaseScreen()->SetZoom( BestZoom() ); // Set the best zoom
-    Recadre_Trace( move_mouse_cursor );     // Set the best centering and refresh the screen
+    BASE_SCREEN * screen = GetScreen();
+    screen->SetZoom( BestZoom() ); // Set the best zoom and get center point.
+    if( screen->m_FirstRedraw )
+        screen->SetCrossHairPosition( screen->GetScrollCenterPosition() );
+    RedrawScreen( screen->GetScrollCenterPosition(), aWarpPointer );
 }
 
 
@@ -77,7 +48,7 @@ void WinEDA_DrawFrame::Zoom_Automatique( bool move_mouse_cursor )
  *  selected area (Rect) in full window screen
  *  @param Rect = selected area to show after zooming
  */
-void WinEDA_DrawFrame::Window_Zoom( EDA_Rect& Rect )
+void EDA_DRAW_FRAME::Window_Zoom( EDA_RECT& Rect )
 {
     double scalex, bestscale;
     wxSize size;
@@ -91,16 +62,16 @@ void WinEDA_DrawFrame::Window_Zoom( EDA_Rect& Rect )
     bestscale = (double) Rect.GetSize().y / size.y;
     bestscale = MAX( bestscale, scalex );
 
-    GetBaseScreen()->SetScalingFactor( bestscale );
-    GetBaseScreen()->m_Curseur = Rect.Centre();
-    Recadre_Trace( TRUE );
+    GetScreen()->SetScalingFactor( bestscale );
+    RedrawScreen( Rect.Centre(), true );
 }
 
 
-/** Function OnZoom
+/**
+ * Function OnZoom
  * Called from any zoom event (toolbar , hotkey or popup )
  */
-void WinEDA_DrawFrame::OnZoom( wxCommandEvent& event )
+void EDA_DRAW_FRAME::OnZoom( wxCommandEvent& event )
 {
     if( DrawPanel == NULL )
         return;
@@ -108,32 +79,30 @@ void WinEDA_DrawFrame::OnZoom( wxCommandEvent& event )
     int          i;
     int          id = event.GetId();
     bool         zoom_at_cursor = false;
-    BASE_SCREEN* screen = GetBaseScreen();
+    BASE_SCREEN* screen = GetScreen();
+    wxPoint      center = screen->GetScrollCenterPosition();
 
     switch( id )
     {
     case ID_POPUP_ZOOM_IN:
         zoom_at_cursor = true;
+        center = screen->GetCrossHairPosition();
 
     // fall thru
-
     case ID_ZOOM_IN:
-        if( id == ID_ZOOM_IN )
-            screen->m_Curseur = DrawPanel->GetScreenCenterRealPosition();
         if( screen->SetPreviousZoom() )
-            Recadre_Trace( zoom_at_cursor );
+            RedrawScreen( center, zoom_at_cursor );
         break;
 
     case ID_POPUP_ZOOM_OUT:
         zoom_at_cursor = true;
+        center = screen->GetCrossHairPosition();
 
     // fall thru
 
     case ID_ZOOM_OUT:
-        if( id == ID_ZOOM_OUT )
-            screen->m_Curseur = DrawPanel->GetScreenCenterRealPosition();
         if( screen->SetNextZoom() )
-            Recadre_Trace( zoom_at_cursor );
+            RedrawScreen( center, zoom_at_cursor );
         break;
 
     case ID_ZOOM_REDRAW:
@@ -141,7 +110,8 @@ void WinEDA_DrawFrame::OnZoom( wxCommandEvent& event )
         break;
 
     case ID_POPUP_ZOOM_CENTER:
-        Recadre_Trace( true );
+        center = screen->GetCrossHairPosition();
+        RedrawScreen( center, true );
         break;
 
     case ID_ZOOM_PAGE:
@@ -152,7 +122,7 @@ void WinEDA_DrawFrame::OnZoom( wxCommandEvent& event )
         break;
 
     case ID_POPUP_CANCEL:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         break;
 
     default:
@@ -165,7 +135,7 @@ void WinEDA_DrawFrame::OnZoom( wxCommandEvent& event )
             return;
         }
         if( screen->SetZoom( screen->m_ZoomList[i] ) )
-            Recadre_Trace( true );
+            RedrawScreen( center, true );
     }
 
     UpdateStatusBar();
@@ -175,7 +145,7 @@ void WinEDA_DrawFrame::OnZoom( wxCommandEvent& event )
 /* add the zoom list menu the the MasterMenu.
  *  used in OnRightClick(wxMouseEvent& event)
  */
-void WinEDA_DrawFrame::AddMenuZoomAndGrid( wxMenu* MasterMenu )
+void EDA_DRAW_FRAME::AddMenuZoomAndGrid( wxMenu* MasterMenu )
 {
     int         maxZoomIds;
     int         zoom;
@@ -183,7 +153,7 @@ void WinEDA_DrawFrame::AddMenuZoomAndGrid( wxMenu* MasterMenu )
     BASE_SCREEN * screen = DrawPanel->GetScreen();
 
     msg = AddHotkeyName( _( "Center" ), m_HotkeysZoomAndGridList, HK_ZOOM_CENTER );
-    ADD_MENUITEM( MasterMenu, ID_POPUP_ZOOM_CENTER, msg, zoom_center_xpm );
+    ADD_MENUITEM( MasterMenu, ID_POPUP_ZOOM_CENTER, msg, zoom_center_on_screen_xpm );
     msg = AddHotkeyName( _( "Zoom in" ), m_HotkeysZoomAndGridList, HK_ZOOM_IN );
     ADD_MENUITEM( MasterMenu, ID_POPUP_ZOOM_IN, msg, zoom_in_xpm );
     msg = AddHotkeyName( _( "Zoom out" ), m_HotkeysZoomAndGridList, HK_ZOOM_OUT );
@@ -191,13 +161,13 @@ void WinEDA_DrawFrame::AddMenuZoomAndGrid( wxMenu* MasterMenu )
     msg = AddHotkeyName( _( "Redraw view" ), m_HotkeysZoomAndGridList, HK_ZOOM_REDRAW );
     ADD_MENUITEM( MasterMenu, ID_ZOOM_REDRAW, msg, zoom_redraw_xpm );
     msg = AddHotkeyName( _( "Zoom auto" ), m_HotkeysZoomAndGridList, HK_ZOOM_AUTO );
-    ADD_MENUITEM( MasterMenu, ID_ZOOM_PAGE, msg, zoom_auto_xpm );
+    ADD_MENUITEM( MasterMenu, ID_ZOOM_PAGE, msg, zoom_fit_in_page_xpm );
 
 
     wxMenu* zoom_choice = new wxMenu;
     ADD_MENUITEM_WITH_SUBMENU( MasterMenu, zoom_choice,
                                ID_POPUP_ZOOM_SELECT, _( "Zoom select" ),
-                               zoom_select_xpm );
+                               zoom_selection_xpm );
 
     zoom = screen->GetZoom();
     maxZoomIds = ID_POPUP_ZOOM_LEVEL_END - ID_POPUP_ZOOM_LEVEL_START;
@@ -212,8 +182,7 @@ void WinEDA_DrawFrame::AddMenuZoomAndGrid( wxMenu* MasterMenu )
                         screen->m_ZoomList[i] / screen->m_ZoomScalar );
         else
             msg.Printf( wxT( "%.1f" ),
-                        (float) screen->m_ZoomList[i] /
-                        screen->m_ZoomScalar );
+                        (float) screen->m_ZoomList[i] / screen->m_ZoomScalar );
 
         zoom_choice->Append( ID_POPUP_ZOOM_LEVEL_START + i, _( "Zoom: " ) + msg,
                              wxEmptyString, wxITEM_CHECK );
@@ -222,23 +191,20 @@ void WinEDA_DrawFrame::AddMenuZoomAndGrid( wxMenu* MasterMenu )
     }
 
     /* Create grid submenu as required. */
-    if( !screen->m_GridList.IsEmpty() )
+    if( screen->GetGridCount() )
     {
         wxMenu* gridMenu = new wxMenu;
-        ADD_MENUITEM_WITH_SUBMENU( MasterMenu, gridMenu,
-                                   ID_POPUP_GRID_SELECT, _( "Grid Select" ),
-                                   grid_select_xpm );
+        ADD_MENUITEM_WITH_SUBMENU( MasterMenu, gridMenu, ID_POPUP_GRID_SELECT,
+                                   _( "Grid Select" ), grid_select_xpm );
 
         GRID_TYPE   tmp;
         wxRealPoint grid = screen->GetGridSize();
 
-        for( unsigned i = 0; i < screen->m_GridList.GetCount(); i++ )
+        for( size_t i = 0; i < screen->GetGridCount(); i++ )
         {
-            tmp = screen->m_GridList[i];
-            double gridValueInch = To_User_Unit( 0, tmp.m_Size.x,
-                                      m_InternalUnits );
-            double gridValue_mm = To_User_Unit( 1, tmp.m_Size.x,
-                                      m_InternalUnits );
+            tmp = screen->GetGrid( i );
+            double gridValueInch = To_User_Unit( INCHES, tmp.m_Size.x, m_InternalUnits );
+            double gridValue_mm = To_User_Unit( MILLIMETRES, tmp.m_Size.x, m_InternalUnits );
 
             if( tmp.m_Id == ID_POPUP_GRID_USER )
             {
@@ -246,14 +212,26 @@ void WinEDA_DrawFrame::AddMenuZoomAndGrid( wxMenu* MasterMenu )
             }
             else
             {
-                if( g_UnitMetric == 0 )     // inches
-                    msg.Printf( wxT( "%.1f mils\t(%.3f mm)" ),
+                switch( g_UserUnit )
+                {
+                case INCHES:
+                    msg.Printf( wxT( "%.1f mils, (%.3f mm)" ),
                                 gridValueInch * 1000, gridValue_mm );
-                else
-                    msg.Printf( wxT( "%.3f mm\t(%.1f mils)" ),
+                    break;
+
+                case MILLIMETRES:
+                    msg.Printf( wxT( "%.3f mm, (%.1f mils)" ),
                                 gridValue_mm, gridValueInch * 1000 );
+                    break;
+
+                case UNSCALED_UNITS:
+                    msg = wxT( "???" );
+                    break;
+                }
             }
+
             gridMenu->Append( tmp.m_Id, msg, wxEmptyString, true );
+
             if( grid == tmp.m_Size )
                 gridMenu->Check( tmp.m_Id, true );
         }
