@@ -17,29 +17,36 @@
 #include "common.h"
 #include "confirm.h"
 #include "gestfich.h"
+#include "wxEeschemaStruct.h"
+#include "class_sch_screen.h"
 
-#include "program.h"
 #include "general.h"
 #include "netlist.h"
 #include "protos.h"
+#include "sch_sheet.h"
+#include "dialog_helpers.h"
 #include "netlist_control.h"
+#include "dialogs/annotate_dialog.h"
 
 
+
+//Imported function:
+int TestDuplicateSheetNames( bool aCreateMarker );
+
 // ID for configuration:
 #define CUSTOM_NETLIST_TITLE   wxT( "CustomNetlistTitle" )
 #define CUSTOM_NETLIST_COMMAND wxT( "CustomNetlistCommand" )
 
-/****************************************************/
-wxString ReturnUserNetlistTypeName( bool first_item )
-/****************************************************/
 
-/** Function ReturnUserNetlistTypeName
+/**
+ * Function ReturnUserNetlistTypeName
  * to retrieve user netlist type names
- * @param first = true: return first name of the list, false = return next
+ * @param first_item = true: return first name of the list, false = return next
  * @return a wxString : name of the type netlist or empty string
  * this function must be called first with "first_item" = true
  * and after with "first_item" = false to get all the other existing netlist names
  */
+wxString ReturnUserNetlistTypeName( bool first_item )
 {
     static int index;
     wxString   name, msg;
@@ -59,15 +66,17 @@ wxString ReturnUserNetlistTypeName( bool first_item )
 }
 
 
-BEGIN_EVENT_TABLE( WinEDA_NetlistFrame, wxDialog )
-    EVT_BUTTON( wxID_CANCEL, WinEDA_NetlistFrame::OnCancelClick )
-    EVT_BUTTON( ID_CREATE_NETLIST, WinEDA_NetlistFrame::GenNetlist )
-    EVT_BUTTON( ID_SETUP_PLUGIN, WinEDA_NetlistFrame::SetupPluginData )
-    EVT_BUTTON( ID_DELETE_PLUGIN, WinEDA_NetlistFrame::DeletePluginPanel )
-    EVT_BUTTON( ID_VALIDATE_PLUGIN, WinEDA_NetlistFrame::ValidatePluginPanel )
+BEGIN_EVENT_TABLE( NETLIST_DIALOG, wxDialog )
+    EVT_BUTTON( wxID_CANCEL, NETLIST_DIALOG::OnCancelClick )
+    EVT_BUTTON( ID_CREATE_NETLIST, NETLIST_DIALOG::GenNetlist )
+    EVT_BUTTON( ID_SETUP_PLUGIN, NETLIST_DIALOG::AddNewPluginPanel )
+    EVT_BUTTON( ID_DELETE_PLUGIN, NETLIST_DIALOG::DeletePluginPanel )
+    EVT_BUTTON( ID_VALIDATE_PLUGIN, NETLIST_DIALOG::ValidatePluginPanel )
     EVT_CHECKBOX( ID_CURRENT_FORMAT_IS_DEFAULT,
-                  WinEDA_NetlistFrame::SelectNetlistType )
-    EVT_BUTTON( ID_RUN_SIMULATOR, WinEDA_NetlistFrame::RunSimulator )
+                  NETLIST_DIALOG::SelectNetlistType )
+    EVT_CHECKBOX( ID_ADD_SUBCIRCUIT_PREFIX,
+                  NETLIST_DIALOG::EnableSubcircuitPrefix )
+    EVT_BUTTON( ID_RUN_SIMULATOR, NETLIST_DIALOG::RunSimulator )
 END_EVENT_TABLE()
 
 
@@ -76,30 +85,22 @@ END_EVENT_TABLE()
 /*******************************/
 
 
-/*****************************************************************************/
-EDA_NoteBookPage::EDA_NoteBookPage( wxNotebook*     parent,
-                                    const wxString& title,
-                                    int             id_NetType,
-                                    int             idCheckBox,
-                                    int             idCreateFile,
-                                    bool            selected ) :
-    wxPanel( parent, -1, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL |
-             wxBORDER_SUNKEN )
-/*****************************************************************************/
-
-/** Contructor to create a setup page for one netlist format.
+/* Contructor to create a setup page for one netlist format.
  * Used in Netlist format Dialog box creation
- * @param parent = wxNotebook * parent
- * @param title = title (name) of the notebook page
- * @param id_NetType = netlist type id
- * @param idCheckBox = event ID attached to the "format is default" check box
- * @param idCreateFile = event ID attached to the "create netlist" button
  */
+NETLIST_PAGE_DIALOG::NETLIST_PAGE_DIALOG( wxNotebook*     parent,
+                                          const wxString& title,
+                                          int             id_NetType,
+                                          int             idCheckBox,
+                                          int             idCreateFile,
+                                          bool            selected ) :
+    wxPanel( parent, -1, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL | wxBORDER_SUNKEN )
 {
     m_IdNetType = id_NetType;
     m_CommandStringCtrl = NULL;
     m_TitleStringCtrl   = NULL;
     m_IsCurrentFormat   = NULL;
+    m_AddSubPrefix = NULL;
     m_ButtonCancel = NULL;
 
     parent->AddPage( this, title, selected );
@@ -116,18 +117,14 @@ EDA_NoteBookPage::EDA_NoteBookPage( wxNotebook*     parent,
     m_RightOptionsBoxSizer = new wxBoxSizer( wxVERTICAL );
     UpperBoxSizer->Add( m_LeftBoxSizer, 0, wxGROW | wxALL, 5 );
     UpperBoxSizer->Add( m_RightBoxSizer, 0, wxALIGN_CENTER_VERTICAL | wxALL, 5 );
-    UpperBoxSizer->Add( m_RightOptionsBoxSizer,
-                        0,
-                        wxALIGN_CENTER_VERTICAL | wxALL,
-                        5 );
+    UpperBoxSizer->Add( m_RightOptionsBoxSizer, 0, wxALIGN_CENTER_VERTICAL | wxALL, 5 );
 
     if( idCheckBox )
     {
         wxStaticText* text = new wxStaticText( this, -1, _( "Options:" ) );
         m_LeftBoxSizer->Add( text, 0, wxGROW | wxALL, 5 );
 
-        m_IsCurrentFormat =
-            new wxCheckBox( this, idCheckBox, _( "Default format" ) );
+        m_IsCurrentFormat = new wxCheckBox( this, idCheckBox, _( "Default format" ) );
         m_LeftBoxSizer->Add( m_IsCurrentFormat, 0, wxGROW | wxALL, 5 );
         m_IsCurrentFormat->SetValue( selected );
     }
@@ -137,15 +134,16 @@ EDA_NoteBookPage::EDA_NoteBookPage( wxNotebook*     parent,
     if( idCreateFile )
     {
         wxButton* Button;
+
         if( idCreateFile == ID_SETUP_PLUGIN )  /* This is the "add plugin" panel */
             Button = new wxButton( this, idCreateFile, _( "&Browse Plugin" ) );
         else
             Button = new wxButton( this, idCreateFile, _( "&Netlist" ) );
-        m_RightBoxSizer->Add( Button, 0, wxGROW | wxALL, 5 );
 
-        m_ButtonCancel =
-            Button     = new wxButton( this, wxID_CANCEL, _( "&Cancel" ) );
         m_RightBoxSizer->Add( Button, 0, wxGROW | wxALL, 5 );
+        Button->SetDefault();
+        m_ButtonCancel = new wxButton( this, wxID_CANCEL, _( "&Cancel" ) );
+        m_RightBoxSizer->Add( m_ButtonCancel, 0, wxGROW | wxALL, 5 );
 
         /* Add special buttons to plugin panels:
          * for panel plugins: added the "delete" button
@@ -165,14 +163,9 @@ EDA_NoteBookPage::EDA_NoteBookPage( wxNotebook*     parent,
 }
 
 
-/*************************************************************************************/
-WinEDA_NetlistFrame::WinEDA_NetlistFrame( WinEDA_SchematicFrame* parent ) :
+NETLIST_DIALOG::NETLIST_DIALOG( SCH_EDIT_FRAME* parent ) :
     wxDialog( parent, -1, _( "Netlist" ), wxDefaultPosition,
               wxDefaultSize, DIALOG_STYLE | MAYBE_RESIZE_BORDER )
-/*************************************************************************************/
-
-/* Constructor for the netlist generation dialog box
- */
 {
     int ii;
 
@@ -183,43 +176,43 @@ WinEDA_NetlistFrame::WinEDA_NetlistFrame( WinEDA_SchematicFrame* parent ) :
         m_PanelNetType[ii] = NULL;
     }
 
-    Centre();
-
     wxBoxSizer* GeneralBoxSizer = new wxBoxSizer( wxVERTICAL );
     SetSizer( GeneralBoxSizer );
 
     m_NoteBook = new wxNotebook( this, ID_NETLIST_NOTEBOOK,
-                                 wxDefaultPosition, wxDefaultSize );
+                                 wxDefaultPosition, wxDefaultSize,
+                                 wxNB_TOP );   // @todo: tabs on top are being hidden on linux
+
     GeneralBoxSizer->Add( m_NoteBook, 0, wxGROW | wxALL, 5 );
 
     // Add notebook pages:
 
     // Add Panel FORMAT PCBNEW
     m_PanelNetType[PANELPCBNEW] =
-        new EDA_NoteBookPage( m_NoteBook,
-                              wxT( "Pcbnew" ),
-                              NET_TYPE_PCBNEW,
-                              ID_CURRENT_FORMAT_IS_DEFAULT,
-                              ID_CREATE_NETLIST,
-                              m_Parent->m_NetlistFormat == NET_TYPE_PCBNEW );
+        new NETLIST_PAGE_DIALOG( m_NoteBook,
+                                 wxT( "Pcbnew" ),
+                                 NET_TYPE_PCBNEW,
+                                 ID_CURRENT_FORMAT_IS_DEFAULT,
+                                 ID_CREATE_NETLIST,
+                                 m_Parent->m_NetlistFormat == NET_TYPE_PCBNEW );
 
     // Add Panel FORMAT ORCADPCB2
     m_PanelNetType[PANELORCADPCB2] =
-        new EDA_NoteBookPage( m_NoteBook,
-                              wxT( "OrcadPCB2" ),
-                              NET_TYPE_ORCADPCB2,
-                              ID_CURRENT_FORMAT_IS_DEFAULT,
-                              ID_CREATE_NETLIST,
-                              m_Parent->m_NetlistFormat == NET_TYPE_ORCADPCB2 );
+        new NETLIST_PAGE_DIALOG( m_NoteBook,
+                                 wxT( "OrcadPCB2" ),
+                                 NET_TYPE_ORCADPCB2,
+                                 ID_CURRENT_FORMAT_IS_DEFAULT,
+                                 ID_CREATE_NETLIST,
+                                 m_Parent->m_NetlistFormat == NET_TYPE_ORCADPCB2 );
 
     // Add Panel FORMAT CADSTAR
     m_PanelNetType[PANELCADSTAR] =
-        new EDA_NoteBookPage( m_NoteBook,
-                              wxT( "CadStar" ),
-                              NET_TYPE_CADSTAR,
-                              ID_CURRENT_FORMAT_IS_DEFAULT,
-                              ID_CREATE_NETLIST,
-                              m_Parent->m_NetlistFormat == NET_TYPE_CADSTAR );
+        new NETLIST_PAGE_DIALOG( m_NoteBook,
+                                 wxT( "CadStar" ),
+                                 NET_TYPE_CADSTAR,
+                                 ID_CURRENT_FORMAT_IS_DEFAULT,
+                                 ID_CREATE_NETLIST,
+                                 m_Parent->m_NetlistFormat == NET_TYPE_CADSTAR );
 
     // Add Panel spice
     InstallPageSpice();
@@ -227,33 +220,35 @@ WinEDA_NetlistFrame::WinEDA_NetlistFrame( WinEDA_SchematicFrame* parent ) :
     // Add custom panels:
     InstallCustomPages();
 
-    GetSizer()->Fit( this );
+//    GetSizer()->Fit( this );
     GetSizer()->SetSizeHints( this );
+
+    Centre();
 }
 
 
-/*************************************************/
-void WinEDA_NetlistFrame::InstallPageSpice()
-/*************************************************/
-
-/* Create the spice page
- */
+void NETLIST_DIALOG::InstallPageSpice()
 {
-    wxButton*         Button;
-    EDA_NoteBookPage* page;
+    wxButton* Button;
+    NETLIST_PAGE_DIALOG* page;
 
     page = m_PanelNetType[PANELSPICE] =
-        new EDA_NoteBookPage( m_NoteBook,
-                              wxT( "Spice" ),
-                              NET_TYPE_SPICE,
-                              0, 0,
-                              m_Parent->m_NetlistFormat == NET_TYPE_SPICE );
+        new NETLIST_PAGE_DIALOG( m_NoteBook,
+                                 wxT( "Spice" ),
+                                 NET_TYPE_SPICE,
+                                 0, 0,
+                                 m_Parent->m_NetlistFormat == NET_TYPE_SPICE );
 
-    page->m_IsCurrentFormat =
-        new wxCheckBox( page, ID_CURRENT_FORMAT_IS_DEFAULT,
-                        _( "Default format" ) );
+    page->m_IsCurrentFormat = new wxCheckBox( page, ID_CURRENT_FORMAT_IS_DEFAULT,
+                                              _( "Default format" ) );
     page->m_IsCurrentFormat->SetValue( m_Parent->m_NetlistFormat == NET_TYPE_SPICE );
-    page->m_LeftBoxSizer->Add( page->m_IsCurrentFormat, 0, wxGROW | wxALL, 5 );
+    page->m_LeftBoxSizer->Add( page->m_IsCurrentFormat, 1, wxGROW | wxALL, 5 );
+
+    page->m_AddSubPrefix = new wxCheckBox( page, ID_ADD_SUBCIRCUIT_PREFIX,
+                                           _( "Prefix references 'U' and 'IC' with 'X'" ) );
+    page->m_AddSubPrefix->SetValue( m_Parent->m_AddSubPrefix );
+    page->m_LeftBoxSizer->Add( page->m_AddSubPrefix, 0, wxGROW | wxALL, 5 );
+
 
     wxString netlist_opt[2] = { _( "Use Net Names" ), _( "Use Net Numbers" ) };
     m_UseNetNamesInNetlist = new wxRadioBox( page, -1, _( "Netlist Options:" ),
@@ -262,6 +257,7 @@ void WinEDA_NetlistFrame::InstallPageSpice()
                                              wxRA_SPECIFY_COLS );
     if( !g_OptNetListUseNames )
         m_UseNetNamesInNetlist->SetSelection( 1 );
+
     page->m_LeftBoxSizer->Add( m_UseNetNamesInNetlist, 0, wxGROW | wxALL, 5 );
 
     page->m_CommandStringCtrl = new WinEDA_EnterText( page,
@@ -273,6 +269,7 @@ void WinEDA_NetlistFrame::InstallPageSpice()
     // Add buttons
     Button = new wxButton( page, ID_CREATE_NETLIST, _( "Netlist" ) );
     page->m_RightBoxSizer->Add( Button, 0, wxGROW | wxALL, 5 );
+    Button->SetDefault();
 
     Button = new wxButton( page, ID_RUN_SIMULATOR, _( "&Run Simulator" ) );
     page->m_RightBoxSizer->Add( Button, 0, wxGROW | wxALL, 5 );
@@ -282,20 +279,18 @@ void WinEDA_NetlistFrame::InstallPageSpice()
 }
 
 
-/*************************************************/
-void WinEDA_NetlistFrame::InstallCustomPages()
-/*************************************************/
-
 /* create the pages for custom netlist format selection:
  */
+void NETLIST_DIALOG::InstallCustomPages()
 {
-    bool selected;
-    int ii, CustomCount;
+    bool              selected;
+    int               ii, CustomCount;
     wxString          title, previoustitle, msg;
-    EDA_NoteBookPage* CurrPage;
+    NETLIST_PAGE_DIALOG* CurrPage;
 
     CustomCount   = CUSTOMPANEL_COUNTMAX;
     previoustitle = wxT( "dummy_title" );
+
     for( ii = 0; ii < CustomCount; ii++ )
     {
         title = ReturnUserNetlistTypeName( ii == 0 ? true : false );
@@ -311,21 +306,21 @@ void WinEDA_NetlistFrame::InstallCustomPages()
         if( title.IsEmpty() )
             CurrPage =
                 m_PanelNetType[PANELCUSTOMBASE + ii] =
-                    new EDA_NoteBookPage( m_NoteBook,
-                                          _( "Add Plugin" ),
-                                          NET_TYPE_CUSTOM1 + ii,
-                                          ID_CURRENT_FORMAT_IS_DEFAULT,
-                                          ID_SETUP_PLUGIN,
-                                          selected );
+                    new NETLIST_PAGE_DIALOG( m_NoteBook,
+                                             _( "Add Plugin" ),
+                                             NET_TYPE_CUSTOM1 + ii,
+                                             ID_CURRENT_FORMAT_IS_DEFAULT,
+                                             ID_SETUP_PLUGIN,
+                                             selected );
         else  /* Install a plugin panel */
             CurrPage =
                 m_PanelNetType[PANELCUSTOMBASE + ii] =
-                    new EDA_NoteBookPage( m_NoteBook,
-                                          title,
-                                          NET_TYPE_CUSTOM1 + ii,
-                                          ID_CURRENT_FORMAT_IS_DEFAULT,
-                                          ID_CREATE_NETLIST,
-                                          selected );
+                    new NETLIST_PAGE_DIALOG( m_NoteBook,
+                                             title,
+                                             NET_TYPE_CUSTOM1 + ii,
+                                             ID_CURRENT_FORMAT_IS_DEFAULT,
+                                             ID_CREATE_NETLIST,
+                                             selected );
 
         msg = CUSTOM_NETLIST_COMMAND;
         msg << ii + 1;
@@ -345,12 +340,11 @@ void WinEDA_NetlistFrame::InstallCustomPages()
 }
 
 
-/***********************************************************/
-void WinEDA_NetlistFrame::SetupPluginData( wxCommandEvent& event )
-/***********************************************************/
-
-/* Browse the plugin files and set the m_CommandStringCtrl field
+/*
+ * Browse plugin files, add a new panel
+ * and set m_CommandStringCtrl field
  */
+void NETLIST_DIALOG::AddNewPluginPanel( wxCommandEvent& event )
 {
     wxString FullFileName, Mask, Path;
 
@@ -363,175 +357,170 @@ void WinEDA_NetlistFrame::SetupPluginData( wxCommandEvent& event )
                                      Mask,
                                      this,
                                      wxFD_OPEN,
-                                     TRUE
+                                     true
                                      );
     if( FullFileName.IsEmpty() )
         return;
 
-    EDA_NoteBookPage* CurrPage;
-    CurrPage = (EDA_NoteBookPage*) m_NoteBook->GetCurrentPage();
+    NETLIST_PAGE_DIALOG* CurrPage;
+    CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
+
     if( CurrPage == NULL )
         return;
 
-    CurrPage->m_CommandStringCtrl->SetValue( FullFileName );
+    // Creates a default command line, suitable for external tool xslproc:
+    // try to build a default command line depending on plugin extension
+    wxString cmdLine;
+    wxFileName fn( FullFileName );
+    wxString ext = fn.GetExt();
+
+    if( ext == wxT("xsl" ) )
+        cmdLine.Printf(wxT("xsltproc -o \"%%O\" \"%s\" \"%%I\""), GetChars(FullFileName) );
+    else if( ext == wxT("exe" ) || ext.IsEmpty() )
+        cmdLine.Printf(wxT("\"%s\" > \"%%O\" < \"%%I\""), GetChars(FullFileName) );
+    else
+        cmdLine.Printf(wxT("\"%s\""), GetChars(FullFileName) );
+
+    CurrPage->m_CommandStringCtrl->SetValue( cmdLine );
 
     /* Get a title for this page */
     wxString title = CurrPage->m_TitleStringCtrl->GetValue();
     if( title.IsEmpty() )
         DisplayInfoMessage( this,
-                            _( "Do not forget to choose a title for this \
-netlist control page" ) );
+                            _( "Do not forget to choose a title for this netlist control page" ) );
 }
 
 
-/*****************************************************************/
-void WinEDA_NetlistFrame::SelectNetlistType( wxCommandEvent& event )
-/*****************************************************************/
-
 /* Called when the check box "default format" is clicked
  */
+void NETLIST_DIALOG::SelectNetlistType( wxCommandEvent& event )
 {
     int ii;
-    EDA_NoteBookPage* CurrPage;
+    NETLIST_PAGE_DIALOG* CurrPage;
 
     for( ii = 0; ii < PANELCUSTOMBASE + CUSTOMPANEL_COUNTMAX; ii++ )
         if( m_PanelNetType[ii] )
-            m_PanelNetType[ii]->m_IsCurrentFormat->SetValue( FALSE );
+            m_PanelNetType[ii]->m_IsCurrentFormat->SetValue( 	false );
+
+    CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
 
-    CurrPage = (EDA_NoteBookPage*) m_NoteBook->GetCurrentPage();
     if( CurrPage == NULL )
         return;
 
     m_Parent->m_NetlistFormat = CurrPage->m_IdNetType;
-    CurrPage->m_IsCurrentFormat->SetValue( TRUE );
+    CurrPage->m_IsCurrentFormat->SetValue( true );
 }
 
 
-/***********************************************/
-void WinEDA_NetlistFrame::NetlistUpdateOpt()
-/***********************************************/
+/* Called when the check box m_AddSubPrefix
+ * "default format" is clicked
+ * ( Spice format only )
+ */
+void NETLIST_DIALOG::EnableSubcircuitPrefix( wxCommandEvent& event )
+{
+
+    NETLIST_PAGE_DIALOG* CurrPage;
+
+    CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
+
+    if( CurrPage == NULL || CurrPage->m_AddSubPrefix == NULL )
+        return;
+
+    if( CurrPage->m_AddSubPrefix->IsChecked() )
+        m_Parent->m_AddSubPrefix = true;
+    else
+        m_Parent->m_AddSubPrefix = false;
+}
+
+void NETLIST_DIALOG::NetlistUpdateOpt()
 {
     int ii;
 
-    g_SimulatorCommandLine =
-        m_PanelNetType[PANELSPICE]->m_CommandStringCtrl->GetValue();
+    g_SimulatorCommandLine = m_PanelNetType[PANELSPICE]->m_CommandStringCtrl->GetValue();
     m_Parent->m_NetlistFormat = NET_TYPE_PCBNEW;
 
     for( ii = 0; ii < PANELCUSTOMBASE + CUSTOMPANEL_COUNTMAX; ii++ )
     {
         if( m_PanelNetType[ii] == NULL )
             break;
-        if( m_PanelNetType[ii]->m_IsCurrentFormat->GetValue() == TRUE )
+
+        if( m_PanelNetType[ii]->m_IsCurrentFormat->GetValue() == true )
             m_Parent->m_NetlistFormat = m_PanelNetType[ii]->m_IdNetType;
     }
 
-    g_OptNetListUseNames = TRUE; // Used for pspice, gnucap
+    g_OptNetListUseNames = true; // Used for pspice, gnucap
+
     if( m_UseNetNamesInNetlist->GetSelection() == 1 )
-        g_OptNetListUseNames = FALSE;
+        g_OptNetListUseNames = 	false;
 }
 
 
-/**********************************************************/
-void WinEDA_NetlistFrame::GenNetlist( wxCommandEvent& event )
-/**********************************************************/
-
-/** Function GenNetlist
+/**
+ * Function GenNetlist
  * Create the netlist file:
  * calculate the filename with the suitable extensions
  * and run the netlist creator
  */
+void NETLIST_DIALOG::GenNetlist( wxCommandEvent& event )
 {
-    wxFileName fn;
-    wxString FileWildcard, FileExt;
-    wxString msg, Command;
-    int      netformat_tmp = m_Parent->m_NetlistFormat;
+    wxFileName  fn;
+    wxString    fileWildcard;
+    wxString    fileExt;
+    wxString    title = _( "Save Netlist File" );
 
     NetlistUpdateOpt();
 
-    EDA_NoteBookPage* CurrPage;
-
-    CurrPage    = (EDA_NoteBookPage*) m_NoteBook->GetCurrentPage();
-    m_Parent->m_NetlistFormat = CurrPage->m_IdNetType;
+    NETLIST_PAGE_DIALOG* CurrPage;
+    CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
 
     /* Calculate the netlist filename */
-    fn = g_RootSheet->m_AssociatedScreen->m_FileName;
+    fn = g_RootSheet->GetScreen()->GetFileName();
 
-    switch( m_Parent->m_NetlistFormat )
+    switch( CurrPage->m_IdNetType )
     {
     case NET_TYPE_SPICE:
-        FileExt = wxT( "cir" );
-        FileWildcard = _( "SPICE netlist file (.cir)|*.cir" );
+        fileExt = wxT( "cir" );
+        fileWildcard = _( "SPICE netlist file (.cir)|*.cir" );
         break;
 
     case NET_TYPE_CADSTAR:
-        FileExt = wxT( "frp" );
-        FileWildcard = _( "CadStar netlist file (.frp)|*.frp" );
+        fileExt = wxT( "frp" );
+        fileWildcard = _( "CadStar netlist file (.frp)|*.frp" );
         break;
 
-    default:
-        FileExt = NetlistFileExtension;
-        FileWildcard = NetlistFileWildcard;
+    case NET_TYPE_PCBNEW:
+    case NET_TYPE_ORCADPCB2:
+        fileExt = NetlistFileExtension;
+        fileWildcard = NetlistFileWildcard;
         break;
+
+    default:    // custom, NET_TYPE_CUSTOM1 and greater
+        fileExt = wxEmptyString;    // wxT( "" );
+        fileWildcard = AllFilesWildcard;
+        title.Printf( _( "%s Export" ), CurrPage->m_TitleStringCtrl->GetValue().GetData() );
     }
 
-    fn.SetExt( FileExt );
+    fn.SetExt( fileExt );
 
-    wxFileDialog dlg( this, _( "Save Netlist Files" ), fn.GetPath(),
-                      fn.GetFullName(), FileWildcard,
-                      wxFD_SAVE /*| wxFD_OVERWRITE_PROMPT*/ );
+    wxFileDialog dlg( this, title, fn.GetPath(),
+                      fn.GetFullName(), fileWildcard,
+                      wxFD_SAVE );
 
     if( dlg.ShowModal() == wxID_CANCEL )
         return;
 
     m_Parent->ClearMsgPanel();
 
-    ReAnnotatePowerSymbolsOnly();
-    if( m_Parent->CheckAnnotate( NULL, 0 ) )
-    {
-        if( !IsOK( this, _( "Must be Annotated, Continue ?" ) ) )
-            return;
-    }
-
-    /* Cleanup the entire hierarchy */
-    EDA_ScreenList ScreenList;
-    for( SCH_SCREEN* screen = ScreenList.GetFirst();
-        screen != NULL;
-        screen = ScreenList.GetNext() )
-    {
-        bool ModifyWires;
-        ModifyWires = screen->SchematicCleanUp( NULL );
-
-        // if wire list has changed, delete the Undo Redo list to avoid
-        // pointer problems with deleted data
-        if( ModifyWires )
-            screen->ClearUndoRedoList();
-    }
-
-    m_Parent->BuildNetListBase();
     if( CurrPage->m_CommandStringCtrl )
         g_NetListerCommandLine = CurrPage->m_CommandStringCtrl->GetValue();
     else
         g_NetListerCommandLine.Empty();
 
-    switch( m_Parent->m_NetlistFormat )
-    {
-    default:
-        WriteNetList( m_Parent, dlg.GetPath(), TRUE );
-        break;
-
-    case NET_TYPE_CADSTAR:
-    case NET_TYPE_ORCADPCB2:
-        WriteNetList( m_Parent, dlg.GetPath(), FALSE );
-
-    case NET_TYPE_SPICE:
-        g_OptNetListUseNames = TRUE; // Used for pspice, gnucap
-        if( m_UseNetNamesInNetlist->GetSelection() == 1 )
-            g_OptNetListUseNames = FALSE;
-        WriteNetList( m_Parent, dlg.GetPath(), g_OptNetListUseNames );
-        break;
-    }
-
-    m_Parent->m_NetlistFormat = netformat_tmp;
+    bool addSubPrefix = false;
+    if( CurrPage->m_AddSubPrefix )
+        addSubPrefix = CurrPage->m_AddSubPrefix->GetValue();
+    m_Parent->CreateNetlist( CurrPage->m_IdNetType, dlg.GetPath(), g_OptNetListUseNames,
+                             addSubPrefix );
 
     WriteCurrentNetlistSetup();
 
@@ -539,47 +528,104 @@ void WinEDA_NetlistFrame::GenNetlist( wxCommandEvent& event )
 }
 
 
-/***********************************************************/
-void WinEDA_NetlistFrame::OnCancelClick( wxCommandEvent& event )
-/***********************************************************/
+/**
+ * Function CreateNetlist
+ * Create a netlist file:
+ *  build netlist info
+ *  test issues
+ *  create file
+ * @param aFormat = netlist format (NET_TYPE_PCBNEW ...)
+ * @param aFullFileName = full netlist file name
+ * @param aUse_netnames = bool. if true, use net names from labels in schematic
+ *                              if false, use net numbers (net codes)
+ *   bool aUse_netnames is used only for Spice netlist
+ * @return true if success.
+ */
+bool SCH_EDIT_FRAME::CreateNetlist( int aFormat, const wxString& aFullFileName,
+                                    bool aUse_netnames,
+                                    bool aUsePrefix )
+{
+    SCH_SHEET_LIST sheets;
+    sheets.AnnotatePowerSymbols();
+
+    // Performs some controls:
+    if( CheckAnnotate( NULL, 0 ) )
+    {
+        if( !IsOK( NULL, _( "Some items are not annotated\n\
+Do you want to annotate schematic?" ) ) )
+            return false;
+
+        // Schematic must be annotated: call Annotate dialog:
+        wxCommandEvent event;
+        OnAnnotate( event );
+
+        if( CheckAnnotate( NULL, 0 ) )
+            return false;
+    }
+
+    // Test duplicate sheet names:
+    if( TestDuplicateSheetNames( false ) > 0 )
+    {
+        if( !IsOK( NULL, _( "Error: duplicate sheet names. Continue?" ) ) )
+            return false;
+    }
+
+    /* Cleanup the entire hierarchy */
+    SCH_SCREENS screens;
+    screens.SchematicCleanUp();
+
+    BuildNetListBase();
+    bool success = WriteNetListFile( aFormat, aFullFileName, g_OptNetListUseNames, aUsePrefix );
+
+    return success;
+}
+
+
+void NETLIST_DIALOG::OnCancelClick( wxCommandEvent& event )
 {
     EndModal( NET_ABORT );
 }
 
 
-/***********************************************************/
-void WinEDA_NetlistFrame::RunSimulator( wxCommandEvent& event )
-/***********************************************************/
+void NETLIST_DIALOG::RunSimulator( wxCommandEvent& event )
 {
     wxFileName fn;
-    wxString ExecFile, CommandLine;
+    wxString   ExecFile, CommandLine;
 
-    g_SimulatorCommandLine =
-        m_PanelNetType[PANELSPICE]->m_CommandStringCtrl->GetValue();
-    g_SimulatorCommandLine.Trim( FALSE );
-    g_SimulatorCommandLine.Trim( TRUE );
+    g_SimulatorCommandLine = m_PanelNetType[PANELSPICE]->m_CommandStringCtrl->GetValue();
+    g_SimulatorCommandLine.Trim( false );
+    g_SimulatorCommandLine.Trim( true );
     ExecFile = g_SimulatorCommandLine.BeforeFirst( ' ' );
 
     CommandLine = g_SimulatorCommandLine.AfterFirst( ' ' );
 
     /* Calculate the netlist filename */
-    fn = g_RootSheet->m_AssociatedScreen->m_FileName;
+    fn = g_RootSheet->GetScreen()->GetFileName();
     fn.SetExt( wxT( "cir" ) );
     CommandLine += wxT( " \"" ) + fn.GetFullPath() + wxT( "\"" );
 
+    g_OptNetListUseNames = m_UseNetNamesInNetlist->GetSelection() == 0;
+    NETLIST_PAGE_DIALOG* CurrPage;
+    CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
+
+    bool addSubPrefix = false;
+    if( CurrPage->m_AddSubPrefix )
+        addSubPrefix = CurrPage->m_AddSubPrefix->GetValue();
+    if( ! m_Parent->CreateNetlist( CurrPage->m_IdNetType, fn.GetFullPath(),
+                                   g_OptNetListUseNames,addSubPrefix ) )
+        return;
+
     ExecuteFile( this, ExecFile, CommandLine );
 }
 
 
-/*********************************************************/
-void WinEDA_NetlistFrame::WriteCurrentNetlistSetup( void )
-/*********************************************************/
-
-/** Function WriteCurrentNetlistSetup
+/**
+ * Function WriteCurrentNetlistSetup
  * Write the current netlist options setup in the configuration
  */
+void NETLIST_DIALOG::WriteCurrentNetlistSetup( void )
 {
-    wxString msg, Command;
+    wxString  msg, Command;
     wxConfig* config = wxGetApp().m_EDA_Config;
 
     NetlistUpdateOpt();
@@ -587,14 +633,18 @@ void WinEDA_NetlistFrame::WriteCurrentNetlistSetup( void )
     // Update the new titles
     for( int ii = 0; ii < CUSTOMPANEL_COUNTMAX; ii++ )
     {
-        EDA_NoteBookPage* CurrPage = m_PanelNetType[ii + PANELCUSTOMBASE];
+        NETLIST_PAGE_DIALOG* CurrPage = m_PanelNetType[ii + PANELCUSTOMBASE];
+
         if( CurrPage == NULL )
             break;
+
         msg = wxT( "Custom" );
         msg << ii + 1;
+
         if( CurrPage->m_TitleStringCtrl )
         {
             wxString title = CurrPage->m_TitleStringCtrl->GetValue();
+
             if( msg != title ) // Title has changed, Update config
             {
                 msg = CUSTOM_NETLIST_TITLE;
@@ -614,45 +664,42 @@ void WinEDA_NetlistFrame::WriteCurrentNetlistSetup( void )
 }
 
 
-/******************************************************************/
-void WinEDA_NetlistFrame::DeletePluginPanel( wxCommandEvent& event )
-/******************************************************************/
-
-/** Function DeletePluginPanel
+/**
+ * Function DeletePluginPanel
  * Remove a panel relative to a netlist plugin
  */
+void NETLIST_DIALOG::DeletePluginPanel( wxCommandEvent& event )
 {
-    EDA_NoteBookPage* CurrPage =
-        (EDA_NoteBookPage*) m_NoteBook->GetCurrentPage();
+    NETLIST_PAGE_DIALOG* CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
 
     CurrPage->m_CommandStringCtrl->SetValue( wxEmptyString );
     CurrPage->m_TitleStringCtrl->SetValue( wxEmptyString );
+
     if( CurrPage->m_IsCurrentFormat->IsChecked() )
     {
-        CurrPage->m_IsCurrentFormat->SetValue( FALSE );
-        m_PanelNetType[PANELPCBNEW]->m_IsCurrentFormat->SetValue( TRUE );
+        CurrPage->m_IsCurrentFormat->SetValue( false );
+        m_PanelNetType[PANELPCBNEW]->m_IsCurrentFormat->SetValue( true );
     }
+
     WriteCurrentNetlistSetup();
     EndModal( NET_PLUGIN_CHANGE );
 }
 
 
-/******************************************************************/
-void WinEDA_NetlistFrame::ValidatePluginPanel( wxCommandEvent& event )
-/******************************************************************/
-
-/** Function ValidatePluginPanel
+/**
+ * Function ValidatePluginPanel
  * Validate the panel info relative to a new netlist plugin
  */
+void NETLIST_DIALOG::ValidatePluginPanel( wxCommandEvent& event )
 {
-    EDA_NoteBookPage* CurrPage =
-        (EDA_NoteBookPage*) m_NoteBook->GetCurrentPage();
+    NETLIST_PAGE_DIALOG* CurrPage = (NETLIST_PAGE_DIALOG*) m_NoteBook->GetCurrentPage();
 
     if( CurrPage->m_CommandStringCtrl->GetValue() == wxEmptyString )
     {
         DisplayError( this, _( "Error. You must provide a command String" ) );
         return;
     }
+
     if( CurrPage->m_TitleStringCtrl->GetValue() == wxEmptyString )
     {
         DisplayError( this, _( "Error. You must provide a Title" ) );
