@@ -5,28 +5,30 @@
 #include "fctsys.h"
 #include "common.h"
 #include "bitmaps.h"
+#include "macros.h"
 #include "eeschema_id.h"
+#include "wxstruct.h"
 
-#include "program.h"
 #include "general.h"
 #include "protos.h"
 #include "hotkeys.h"
 #include "class_library.h"
 #include "viewlib_frame.h"
+#include "dialog_helpers.h"
 
 
-void WinEDA_ViewlibFrame::ReCreateHToolbar()
+void LIB_VIEW_FRAME::ReCreateHToolbar()
 {
-    int  ii; wxString msg;
+    int  ii;
+    wxString msg;
     CMP_LIBRARY* lib;
     LIB_COMPONENT* component = NULL;
-    CMP_LIB_ENTRY* entry = NULL;
+    LIB_ALIAS* entry = NULL;
     bool asdeMorgan = false;
 
     if( m_HToolBar  == NULL )
     {
-        m_HToolBar = new WinEDA_Toolbar( TOOLBAR_MAIN, this, ID_H_TOOLBAR,
-                                         true );
+        m_HToolBar = new EDA_TOOLBAR( TOOLBAR_MAIN, this, ID_H_TOOLBAR, true );
 
         // Set up toolbar
         m_HToolBar->AddTool( ID_LIBVIEW_SELECT_LIB, wxEmptyString,
@@ -65,7 +67,7 @@ void WinEDA_ViewlibFrame::ReCreateHToolbar()
         msg = AddHotkeyName( _( "Zoom auto" ), s_Viewlib_Hokeys_Descr,
                              HK_ZOOM_AUTO, false );
         m_HToolBar->AddTool( ID_ZOOM_PAGE, wxEmptyString,
-                             wxBitmap( zoom_auto_xpm ), msg );
+                             wxBitmap( zoom_fit_in_page_xpm ), msg );
 
         m_HToolBar->AddSeparator();
         m_HToolBar->AddTool( ID_LIBVIEW_DE_MORGAN_NORMAL_BUTT, wxEmptyString,
@@ -80,9 +82,9 @@ void WinEDA_ViewlibFrame::ReCreateHToolbar()
 
         m_HToolBar->AddSeparator();
 
-        SelpartBox =
-            new WinEDAChoiceBox( m_HToolBar, ID_LIBVIEW_SELECT_PART_NUMBER,
-                                 wxDefaultPosition, wxSize( 150, -1 ) );
+        SelpartBox = new wxComboBox( m_HToolBar, ID_LIBVIEW_SELECT_PART_NUMBER,
+                                     wxEmptyString, wxDefaultPosition,
+                                     wxSize( 150, -1 ), 0, NULL, wxCB_READONLY );
         m_HToolBar->AddControl( SelpartBox );
 
         m_HToolBar->AddSeparator();
@@ -105,8 +107,7 @@ void WinEDA_ViewlibFrame::ReCreateHToolbar()
         m_HToolBar->Realize();
     }
 
-    if( (m_libraryName != wxEmptyString)
-        && (m_entryName != wxEmptyString) )
+    if( (m_libraryName != wxEmptyString) && (m_entryName != wxEmptyString) )
     {
         lib = CMP_LIBRARY::FindLibrary( m_libraryName );
 
@@ -158,6 +159,6 @@ void WinEDA_ViewlibFrame::ReCreateHToolbar()
 }
 
 
-void WinEDA_ViewlibFrame::ReCreateVToolbar()
+void LIB_VIEW_FRAME::ReCreateVToolbar()
 {
 }
