@@ -19,7 +19,7 @@ enum id_app_type {
     APP_TYPE_PCBNEW,
     APP_TYPE_CVPCB,
     APP_TYPE_GERBVIEW,
-    APP_TYPE_KICAD,
+    APP_TYPE_KICAD
 };
 
 class wxConfigBase;
@@ -76,14 +76,27 @@ protected:
 
 public: WinEDA_App();
     ~WinEDA_App();
+
+    /**
+     * Function OnInit
+     * this is the first executed function (like main() )
+     * @return true if the appliction can be started.
+     */
     bool      OnInit();
 
     bool      SetBinDir();
     void      SetDefaultSearchPaths( void );
 
+    /**
+     * Function MacOpenFile
+     * Specific to MacOSX. Not used under Linux or Windows
+     * MacOSX: Needed for file association
+     * http://wiki.wxwidgets.org/WxMac-specific_topics
+     */
     virtual void MacOpenFile(const wxString &fileName);
 
-    /** Function InitEDA_Appl
+    /**
+     * Function InitEDA_Appl
      * initialize some general parameters
      *  - Default paths (help, libs, bin)and configuration files names
      *  - Language and locale
@@ -97,7 +110,8 @@ public: WinEDA_App();
 
     bool      SetLanguage( bool first_time = FALSE );
 
-    /** Function AddMenuLanguageList
+    /**
+     * Function AddMenuLanguageList
      *
      * Create menu list for language choice, and add it as submenu to a main
      * menu
@@ -113,7 +127,8 @@ public: WinEDA_App();
     void      SetLanguagePath( void );
     void      InitOnLineHelp();
 
-    /** Function GetSettings
+    /**
+     * Function GetSettings
      * Get application settings
      * @param aReopenLastUsedDirectory = true to switch to last opened
      * directory, false to use current CWD
@@ -130,7 +145,8 @@ public: WinEDA_App();
                                   const wxString&  GroupName,
                                   PARAM_CFG_ARRAY& params );
 
-    /** Function SaveCurrentSetupValues()
+    /**
+     * Function SaveCurrentSetupValues
      * Save the current setup values in m_EDA_Config
      * saved parameters are parameters that have the .m_Setup member set to
      * true
@@ -139,7 +155,8 @@ public: WinEDA_App();
     void      SaveCurrentSetupValues( PARAM_CFG_BASE** aList );
     void      SaveCurrentSetupValues( PARAM_CFG_ARRAY& List );
 
-    /** Function ReadCurrentSetupValues()
+    /**
+     * Function ReadCurrentSetupValues
      * Raed the current setup values previously saved, from m_EDA_Config
      * saved parameters are parameters that have the .m_Setup member set to
      * true
@@ -207,14 +224,16 @@ public: WinEDA_App();
     wxString ReturnFilenameWithRelativePathInLibPath(
         const wxString& aFullFilename );
 
-    /** Function RemoveLibraryPath
+    /**
+     * Function RemoveLibraryPath
      * Removes the given path(s) from the library path list
      * @param aPaths = path or path list to remove. paths must be separated by
      * ";"
      */
     void     RemoveLibraryPath( const wxString& aPaths );
 
-    /** Function InsertLibraryPath
+    /**
+     * Function InsertLibraryPath
      * insert path(s) int lib paths list.
      * @param aPaths = path or path list to add. paths must be separated by ";"
      * @param aIndex = insertion point
@@ -227,6 +246,6 @@ public: WinEDA_App();
  * of the application pointer all over the place or worse yet in a global
  * variable.
  */
-DECLARE_APP( WinEDA_App );
+DECLARE_APP( WinEDA_App )
 
 #endif  /* APPL_WXSTRUCT_H */
