@@ -60,7 +60,9 @@ extern const char* component_select_unit_xpm[];
 extern const char* config_xpm[];
 extern const char* copper_layers_setup_xpm[];
 extern const char* copyblock_xpm[];
+extern const char* copyComponent_xpm[];
 extern const char* copy_button[];
+extern const char* create_cmp_file_xpm[];
 extern const char* cursor_shape_xpm[];
 extern const char* cursor_xpm[];
 extern const char* cut_button[];
@@ -93,6 +95,7 @@ extern const char* delete_xpm[];
 extern const char* directory_xpm[];
 extern const char* display_options_xpm[];
 extern const char* down_xpm[];
+extern const char* ortho_xpm[];
 extern const char* drag_module_xpm[];
 extern const char* drag_outline_segment_xpm[];
 extern const char* drag_pad_xpm[];
@@ -117,6 +120,7 @@ extern const char* erc_xpm[];
 extern const char* erc_green_xpm[];
 extern const char* error_xpm[];
 extern const char* exit_xpm[];
+extern const char* export_footprint_names_xpm[];
 extern const char* export_module_xpm[];
 extern const char* export_options_pad_xpm[];
 extern const char* export_xpm[];
@@ -127,6 +131,14 @@ extern const char* find_xpm[];
 extern const char* flag_xpm[];
 extern const char* fonts_xpm[];
 extern const char* footprint_text_xpm[];
+extern const char* gbr_select_mode0_xpm[];
+extern const char* gbr_select_mode1_xpm[];
+extern const char* gbr_select_mode2_xpm[];
+extern const char* gerbview_drill_file_xpm[];
+extern const char* gerber_file_xpm[];
+extern const char* gerber_recent_files_xpm[];
+extern const char* gerbview_clear_layers_xpm[];
+extern const char* gerber_open_dcode_file_xpm[];
 extern const char* general_deletions_xpm[];
 extern const char* general_ratsnet_xpm[];
 extern const char* glabel2label_xpm[];
@@ -134,6 +146,7 @@ extern const char* glabel2text_xpm[];
 extern const char* gl_change_xpm[];
 extern const char* global_options_pad_xpm[];
 extern const char* green_xpm[];
+extern const char* grid_select_axis_xpm[];
 extern const char* grid_select_xpm[];
 extern const char* grid_xpm[];
 extern const char* hammer_xpm[];
@@ -150,6 +163,8 @@ extern const char* icon_gerbview_xpm[];
 extern const char* icon_modedit_xpm[];
 extern const char* icon_txt_xpm[];
 extern const char* icon_w3d_xpm[];
+extern const char* import_cmp_from_lib_xpm[];
+extern const char* import_footprint_names_xpm[];
 extern const char* import_hierarchical_label_xpm[];
 extern const char* import_module_xpm[];
 extern const char* import_xpm[];
@@ -173,8 +188,10 @@ extern const char* lang_en_xpm[];
 extern const char* lang_es_xpm[];
 extern const char* lang_fr_xpm[];
 extern const char* lang_fi_xpm[];
+extern const char* lang_gr_xpm[];
 extern const char* lang_hu_xpm[];
 extern const char* lang_it_xpm[];
+extern const char* lang_jp_xpm[];
 extern const char* lang_ko_xpm[];
 extern const char* lang_nl_xpm[];
 extern const char* lang_pl_xpm[];
@@ -255,9 +272,10 @@ extern const char* new_txt_xpm[];
 extern const char* new_xpm[];
 extern const char* noconn_button[];
 extern const char* normal_xpm[];
+extern const char* online_help_xpm[];
+extern const char* open_document_xpm[];
 extern const char* open_library_xpm[];
 extern const char* open_project_xpm[];
-extern const char* open_xpm[];
 extern const char* options_all_tracks_and_vias_xpm[];
 extern const char* options_all_tracks_xpm[];
 extern const char* options_all_vias_xpm[];
@@ -292,8 +310,10 @@ extern const char* pinorient_right_xpm[];
 extern const char* pinorient_left_xpm[];
 extern const char* pinorient_up_xpm[];
 extern const char* pinorient_down_xpm[];
+extern const char* pinshape_nonlogic_xpm[];
 extern const char* pinshape_normal_xpm[];
 extern const char* pinshape_invert_xpm[];
+extern const char* pinshape_clock_fall_xpm[];
 extern const char* pinshape_clock_normal_xpm[];
 extern const char* pinshape_clock_invert_xpm[];
 extern const char* pinshape_active_low_input_xpm[];
@@ -328,6 +348,7 @@ extern const char* red_xpm[];
 extern const char* reload2_xpm[];
 extern const char* reload_xpm[];
 extern const char* repaint_xpm[];
+extern const char* reset_text_xpm[];
 extern const char* resize_sheet_xpm[];
 extern const char* right_xpm[];
 extern const char* rotate_field_xpm[];
@@ -335,8 +356,8 @@ extern const char* rotate_glabel_xpm[];
 extern const char* rotate_module_neg_xpm[];
 extern const char* rotate_module_pos_xpm[];
 extern const char* rotate_pin_xpm[];
-extern const char* rotate_neg_xpm[];
-extern const char* rotate_pos_xpm[];
+extern const char* rotate_CW_xpm[];
+extern const char* rotate_CCW_xpm[];
 extern const char* rotate_neg_X_xpm[];
 extern const char* rotate_pos_X_xpm[];
 extern const char* rotate_neg_Y_xpm[];
@@ -344,7 +365,6 @@ extern const char* rotate_pos_Y_xpm[];
 extern const char* rotate_neg_Z_xpm[];
 extern const char* rotate_pos_Z_xpm[];
 extern const char* save_as_xpm[];
-extern const char* save_cmpstuff_xpm[];
 extern const char* save_library_xpm[];
 extern const char* save_netlist_xpm[];
 extern const char* save_part_in_mem_xpm[];
@@ -358,6 +378,7 @@ extern const char* select_w_layer_xpm[];
 extern const char* sheetset_xpm[];
 extern const char* show_3d_xpm[];
 extern const char* show_dcodenumber_xpm[];
+extern const char* show_footprint_xpm[];
 extern const char* show_mod_edge_xpm[];
 extern const char* showtrack_xpm[];
 extern const char* show_zone_xpm[];
@@ -391,19 +412,19 @@ extern const char* width_segment_xpm[];
 extern const char* width_track_via_xpm[];
 extern const char* width_track_xpm[];
 extern const char* width_vias_xpm[];
+extern const char* window_close_xpm[];
 extern const char* zip_tool_xpm[];
 extern const char* zip_xpm[];
-extern const char* zoom_1_xpm[];
-extern const char* zoom_center_xpm[];
+extern const char* zoom_area_xpm[];
+extern const char* zoom_center_on_screen_xpm[];
 extern const char* zoomoins3d_xpm[];
 extern const char* zoom_redraw_xpm[];
-extern const char* zoom_auto_xpm[];
+extern const char* zoom_fit_in_page_xpm[];
 extern const char* zoom_in_xpm[];
 extern const char* zoom_out_xpm[];
 extern const char* zoompage3d_xpm[];
 extern const char* zoom_page_xpm[];
 extern const char* zoomplus3d_xpm[];
 extern const char* zoomrefr3d_xpm[];
-extern const char* zoom_selected_xpm[];
-extern const char* zoom_select_xpm[];
+extern const char* zoom_selection_xpm[];
 extern const char* zoom_xpm[];
