@@ -1,5 +1,5 @@
 /**
- * @file treeprj_frame.cpp
+ * @file tree_project_frame.cpp
  * @brief TODO
  */
 
@@ -94,7 +94,7 @@ END_EVENT_TABLE()
 
 
 /******************************************************************/
-TREE_PROJECT_FRAME::TREE_PROJECT_FRAME( WinEDA_MainFrame* parent ) :
+TREE_PROJECT_FRAME::TREE_PROJECT_FRAME( KICAD_MANAGER_FRAME* parent ) :
     wxSashLayoutWindow( parent,
                         ID_LEFT_FRAME,
                         wxDefaultPosition,
@@ -216,13 +216,11 @@ void TREE_PROJECT_FRAME::OnDragStart( wxTreeEvent& event )
 
     m_TreeProject->SelectItem( curr_item );
     TREEPROJECT_ITEM* data = GetSelectedData();
+
     if( data->GetFileName() == m_Parent->m_ProjectFileName.GetFullPath() )
         return;
 
-    wxTreeItemId id = m_TreeProject->GetSelection();
-
-    wxImage      img =
-        m_TreeProject->GetImageList()->GetBitmap( data->GetType() - 1 ).ConvertToImage();
+    wxImage img = m_TreeProject->GetImageList()->GetBitmap( data->GetType() - 1 ).ConvertToImage();
     m_DragCursor = wxCursor( img );
     m_Parent->wxWindow::SetCursor( (wxCursor &)m_DragCursor );
     event.Allow();
@@ -235,7 +233,6 @@ void TREE_PROJECT_FRAME::OnDragEnd( wxTreeEvent& event )
 {
     m_Parent->SetCursor( wxNullCursor );
 
-    wxTreeItemId     moved = m_TreeProject->GetSelection();
     TREEPROJECT_ITEM* source_data = GetSelectedData();
     wxTreeItemId     dest = event.GetItem();
 
@@ -494,7 +491,8 @@ wxString TREE_PROJECT_FRAME::GetFileWildcard( TreeFileType type )
 }
 
 
-/** function AddFile
+/**
+ * Function AddFile
  * @brief  Add filename "name" to the tree \n
  *         if name is a directory, add the sub directory file names
  * @param aName = the filename or the dirctory name to add
@@ -659,7 +657,6 @@ bool TREE_PROJECT_FRAME::AddFile( const wxString& aName,
 
 /**
  * @brief  Create or modify the tree showing project file names
- * @return TODO
  */
 /*****************************************************************************/
 void TREE_PROJECT_FRAME::ReCreateTreePrj()
@@ -698,19 +695,6 @@ void TREE_PROJECT_FRAME::ReCreateTreePrj()
                                                      wxEmptyString,
                                                      m_TreeProject ) );
 
-    fn.SetExt( SchematicFileExtension );
-
-    // Add at least a .sch / .brd if not existing:
-    if( !fn.FileExists() )
-        AddFile( fn.GetFullName(), m_root );
-
-    fn.SetExt( PcbFileExtension );
-
-    if( !fn.FileExists( ) )
-        AddFile( fn.GetFullName(), m_root );
-
-    fn.SetExt( ProjectFileExtension );
-
     // Now adding all current files if available
     if( prjOpened )
     {
@@ -726,7 +710,11 @@ void TREE_PROJECT_FRAME::ReCreateTreePrj()
 
             cont = dir.GetNext( &filename );
         }
-    }
+   }
+   else
+   {
+      m_TreeProject->AppendItem( m_root, wxT("Empty project") );
+   }
 
     m_TreeProject->Expand( rootcellule );
 
@@ -853,8 +841,15 @@ void TREE_PROJECT_FRAME::OnRenameFile( wxCommandEvent& )
     wxString buffer = m_TreeProject->GetItemText( curr_item );
     wxString msg    = _( "Change filename: " ) + tree_data->m_FileName;
 
-    if( Get_Message( msg, _( "Change filename" ), buffer, this ) != 0 )
-        return; //Abort command
+    wxTextEntryDialog dlg( this, msg, _( "Change filename" ), buffer );
+    if( dlg.ShowModal() != wxID_OK )
+        return; // cancelled by user
+
+    buffer = dlg.GetValue( );
+    buffer.Trim( true );
+    buffer.Trim( false );
+    if( buffer.IsEmpty() )
+        return;         // empty file name not allowed
 
     if( tree_data->Rename( buffer, true ) )
         m_TreeProject->SetItemText( curr_item, buffer );
@@ -957,7 +952,8 @@ void TREE_PROJECT_FRAME::OnExpand( wxTreeEvent& Event )
     }
 }
 
-/** function GetSelectedData
+/**
+ * Function GetSelectedData
  * return the item data from item currently selected (highlighted)
  * Note this is not necessary the "clicked" item,
  * because when expanding, collapsing an item this item is not selected
@@ -967,7 +963,8 @@ TREEPROJECT_ITEM* TREE_PROJECT_FRAME::GetSelectedData()
     return dynamic_cast<TREEPROJECT_ITEM*>( m_TreeProject->GetItemData( m_TreeProject->GetSelection() ) );
 }
 
-/** function GetItemIdData
+/**
+ * Function GetItemIdData
  * return the item data corresponding to a wxTreeItemId identifier
  * @param  aId = the wxTreeItemId identifier.
  * @return a TREEPROJECT_ITEM pointer correspondinfg to item id aId
