@@ -31,6 +31,8 @@ extern int E_scale;     /* Scaling factor of distance tables. */
 #define ONE_SIDE  0
 #define TWO_SIDES 1
 
+#define MAX_SIDES_COUNT 2
+
 extern int Nb_Sides;    /* Number of layers for autorouting (0 or 1) */
 
 #define FORCE_PADS 1  /* Force placement of pads for any Netcode */
@@ -46,32 +48,36 @@ extern int ClosNodes;   /* total number of nodes closed */
 extern int MoveNodes;   /* total number of nodes moved */
 extern int MaxNodes;    /* maximum number of nodes opened at one time */
 
+
 /* Structures useful to the generation of board as bitmap. */
+typedef char MATRIX_CELL;
+typedef int  DIST_CELL;
+typedef char  DIR_CELL;
 
-typedef char BoardCell;
-typedef int  DistCell;
-
-class BOARDHEAD  /* header of blocks of BoardCell */
+class MATRIX_ROUTING_HEAD  /* header of blocks of MATRIX_CELL */
 {
 public:
-    BoardCell* m_BoardSide[2];  /* ptr to block of memory: 2-sided board */
-    DistCell*  m_DistSide[2];   /* ptr to block of memory: path distance to
-                                 * cells */
-    char*      m_DirSide[2];    /* header of blocks of chars:pointers back to
-                                 * source */
+    MATRIX_CELL* m_BoardSide[MAX_SIDES_COUNT];  /* ptr to block of memory: 2-sided board */
+    DIST_CELL*   m_DistSide[MAX_SIDES_COUNT];   /* ptr to block of memory: path distance to
+                                                * cells */
+    DIR_CELL*   m_DirSide[MAX_SIDES_COUNT];    /* header of blocks of chars:pointers back to
+                                                * source */
     bool       m_InitBoardDone;
     int        m_Layers;
+    int        m_GridRouting;                   // Size of grid for autoplace/autoroute
+    EDA_RECT   m_BrdBox;                        // Actual board bouding box
     int        m_Nrows, m_Ncols;
     int        m_MemSize;
 
 public:
-    BOARDHEAD();
-    ~BOARDHEAD();
+    MATRIX_ROUTING_HEAD();
+    ~MATRIX_ROUTING_HEAD();
+    bool    ComputeMatrixSize( BOARD* aPcb );
     int     InitBoard();
     void    UnInitBoard();
 };
 
-extern BOARDHEAD Board;        /* 2-sided board */
+extern MATRIX_ROUTING_HEAD Board;        /* 2-sided board */
 
 
 /* Constants used to trace the cells on the BOARD */
