@@ -11,10 +11,11 @@
 #include "common.h"
 #include "confirm.h"
 #include "appl_wxstruct.h"
+#include "dialog_helpers.h"
+#include "kicad_device_context.h"
 
 #include "pcbnew.h"
 #include "bitmaps.h"
-#include "protos.h"
 #include "pcbnew_id.h"
 #include "class_board_design_settings.h"
 
@@ -33,24 +34,33 @@ static const wxString DisplayModuleEdgeEntry( wxT( "DiModEd" ) );
 static const wxString DisplayModuleTextEntry( wxT( "DiModTx" ) );
 
 
-/*******************************/
-/* class WinEDA_BasePcbFrame */
-/*******************************/
+/****************************/
+/* class PCB_BASE_FRAME */
+/****************************/
 
-BEGIN_EVENT_TABLE( WinEDA_BasePcbFrame, WinEDA_DrawFrame )
-    EVT_MENU_RANGE( ID_POPUP_PCB_ITEM_SELECTION_START,
-                    ID_POPUP_PCB_ITEM_SELECTION_END,
-                    WinEDA_BasePcbFrame::ProcessItemSelection )
+BEGIN_EVENT_TABLE( PCB_BASE_FRAME, EDA_DRAW_FRAME )
+    EVT_MENU_RANGE( ID_POPUP_PCB_ITEM_SELECTION_START, ID_POPUP_PCB_ITEM_SELECTION_END,
+                    PCB_BASE_FRAME::ProcessItemSelection )
+
+    EVT_TOOL( ID_TB_OPTIONS_SHOW_POLAR_COORD, PCB_BASE_FRAME::OnTogglePolarCoords )
+    EVT_TOOL( ID_TB_OPTIONS_SHOW_PADS_SKETCH, PCB_BASE_FRAME::OnTogglePadDrawMode )
+
+    EVT_UPDATE_UI( ID_TB_OPTIONS_SHOW_POLAR_COORD, PCB_BASE_FRAME::OnUpdateCoordType )
+    EVT_UPDATE_UI( ID_TB_OPTIONS_SHOW_PADS_SKETCH, PCB_BASE_FRAME::OnUpdatePadDrawMode )
+    EVT_UPDATE_UI( ID_ON_GRID_SELECT, PCB_BASE_FRAME::OnUpdateSelectGrid )
+    EVT_UPDATE_UI( ID_ON_ZOOM_SELECT, PCB_BASE_FRAME::OnUpdateSelectZoom )
+
+    EVT_UPDATE_UI_RANGE( ID_ZOOM_IN, ID_ZOOM_PAGE, PCB_BASE_FRAME::OnUpdateSelectZoom )
 END_EVENT_TABLE()
 
 
-WinEDA_BasePcbFrame::WinEDA_BasePcbFrame( wxWindow*       father,
-                                          int             idtype,
-                                          const wxString& title,
-                                          const wxPoint&  pos,
-                                          const wxSize&   size,
-                                          long style) :
-    WinEDA_DrawFrame( father, idtype, title, pos, size, style )
+PCB_BASE_FRAME::PCB_BASE_FRAME( wxWindow*       father,
+                                int             idtype,
+                                const wxString& title,
+                                const wxPoint&  pos,
+                                const wxSize&   size,
+                                long style) :
+    EDA_DRAW_FRAME( father, idtype, title, pos, size, style )
 {
     m_InternalUnits       = PCB_INTERNAL_UNIT;  // Internal unit = 1/10000 inch
     m_Pcb                 = NULL;
@@ -66,27 +76,22 @@ WinEDA_BasePcbFrame::WinEDA_BasePcbFrame( wxWindow*       father,
     m_ModuleEditFrame     = NULL;   // Frame for footprint edition
 
     m_UserGridSize        = wxRealPoint( 100.0, 100.0 );
-    m_UserGridUnits       = INCHES;
+    m_UserGridUnit        = INCHES;
     m_Collector           = new GENERAL_COLLECTOR();
 }
 
 
-WinEDA_BasePcbFrame::~WinEDA_BasePcbFrame()
+PCB_BASE_FRAME::~PCB_BASE_FRAME()
 {
     delete m_Collector;
 }
 
 
-BASE_SCREEN* WinEDA_BasePcbFrame::GetBaseScreen() const
-{
-    return GetScreen();
-}
-
-
-void WinEDA_BasePcbFrame::SetBoard( BOARD* aBoard )
+void PCB_BASE_FRAME::SetBoard( BOARD* aBoard )
 {
     if( m_Pcb != g_ModuleEditor_Pcb )
         delete m_Pcb;
+
     m_Pcb = aBoard;
 }
 
@@ -94,7 +99,7 @@ void WinEDA_BasePcbFrame::SetBoard( BOARD* aBoard )
 /**
  * Return the "best" zoom, i.e. the zoom which shows the entire board on screen
  */
-int WinEDA_BasePcbFrame::BestZoom( void )
+int PCB_BASE_FRAME::BestZoom( void )
 {
     int    dx, dy, ii, jj;
     int    bestzoom;
@@ -103,28 +108,30 @@ int WinEDA_BasePcbFrame::BestZoom( void )
     if( m_Pcb == NULL )
         return 32 * GetScreen()->m_ZoomScalar;
 
-    m_Pcb->ComputeBoundaryBox();
+    m_Pcb->ComputeBoundingBox();
 
     dx = m_Pcb->m_BoundaryBox.GetWidth();
     dy = m_Pcb->m_BoundaryBox.GetHeight();
+    size = DrawPanel->GetClientSize();
 
-    size     = DrawPanel->GetClientSize();
     if( size.x )
-        ii       = ( dx + (size.x / 2) ) / size.x;
+        ii = wxRound( ( (double) dx + ((double) size.x / 2.0) ) / (double) size.x );
     else
         ii = 31;
+
     if ( size.y )
-        jj       = ( dy + (size.y / 2) ) / size.y;
+        jj = wxRound( ( (double) dy + ((double) size.y / 2.0) ) / (double) size.y );
     else
         jj = 31;
+
     bestzoom = MAX( ii, jj ) + 1;
-    GetScreen()->m_Curseur = m_Pcb->m_BoundaryBox.Centre();
+    GetScreen()->SetScrollCenterPosition( m_Pcb->m_BoundaryBox.Centre() );
 
     return bestzoom * GetScreen()->m_ZoomScalar;
 }
 
 
-void WinEDA_BasePcbFrame::CursorGoto(  const wxPoint& aPos )
+void PCB_BASE_FRAME::CursorGoto(  const wxPoint& aPos )
 {
     // factored out of pcbnew/find.cpp
 
@@ -135,35 +142,34 @@ void WinEDA_BasePcbFrame::CursorGoto(  const wxPoint& aPos )
     /* There may be need to reframe the drawing. */
     if( !DrawPanel->IsPointOnDisplay( aPos ) )
     {
-        screen->m_Curseur = aPos;
-        Recadre_Trace( true );
+        screen->SetCrossHairPosition( aPos );
+        RedrawScreen( aPos, true );
     }
     else
     {
         // Put cursor on item position
-        DrawPanel->CursorOff( &dc );
-        screen->m_Curseur = aPos;
-        DrawPanel->MouseToCursorSchema();
-        DrawPanel->CursorOn( &dc );
+        DrawPanel->CrossHairOff( &dc );
+        screen->SetCrossHairPosition( aPos );
+        DrawPanel->MoveCursorToCrossHair();
+        DrawPanel->CrossHairOn( &dc );
     }
 }
 
 
 // Virtual function
-void WinEDA_BasePcbFrame::ReCreateMenuBar( void )
+void PCB_BASE_FRAME::ReCreateMenuBar( void )
 {
 }
 
 
-/* Virtual functions: Do nothing for WinEDA_BasePcbFrame window */
-void WinEDA_BasePcbFrame::Show3D_Frame( wxCommandEvent& event )
+/* Virtual functions: Do nothing for PCB_BASE_FRAME window */
+void PCB_BASE_FRAME::Show3D_Frame( wxCommandEvent& event )
 {
 }
 
 
-
-// Note: virtual, overridden in WinEDA_PcbFrame;
-void WinEDA_BasePcbFrame::SwitchLayer( wxDC* DC, int layer )
+// Note: virtual, overridden in PCB_EDIT_FRAME;
+void PCB_BASE_FRAME::SwitchLayer( wxDC* DC, int layer )
 {
     int preslayer = ((PCB_SCREEN*)GetScreen())->m_Active_Layer;
 
@@ -208,21 +214,97 @@ void WinEDA_BasePcbFrame::SwitchLayer( wxDC* DC, int layer )
     GetScreen()->m_Active_Layer = layer;
 
     if( DisplayOpt.ContrastModeDisplay )
-        GetScreen()->SetRefreshReq();
+        DrawPanel->Refresh();
 }
 
 
-/**********************************************************************/
-void WinEDA_BasePcbFrame::ProcessItemSelection( wxCommandEvent& event )
-/**********************************************************************/
+void PCB_BASE_FRAME::OnTogglePolarCoords( wxCommandEvent& aEvent )
 {
-    int id = event.GetId();
+    SetStatusText( wxEmptyString );
+    DisplayOpt.DisplayPolarCood = !DisplayOpt.DisplayPolarCood;
+    UpdateStatusBar();
+}
+
+
+void PCB_BASE_FRAME::OnTogglePadDrawMode( wxCommandEvent& aEvent )
+{
+    m_DisplayPadFill = DisplayOpt.DisplayPadFill = !m_DisplayPadFill;
+    DrawPanel->Refresh();
+}
+
+
+void PCB_BASE_FRAME::OnUpdateCoordType( wxUpdateUIEvent& aEvent )
+{
+    aEvent.Check( DisplayOpt.DisplayPolarCood );
+    m_OptionsToolBar->SetToolShortHelp( ID_TB_OPTIONS_SHOW_POLAR_COORD,
+                                        DisplayOpt.DisplayPolarCood ?
+                                        _( "Display rectangular coordinates" ) :
+                                        _( "Display polar coordinates" ) );
+}
+
+
+void PCB_BASE_FRAME::OnUpdatePadDrawMode( wxUpdateUIEvent& aEvent )
+{
+    aEvent.Check( !m_DisplayPadFill );
+    m_OptionsToolBar->SetToolShortHelp( ID_TB_OPTIONS_SHOW_PADS_SKETCH,
+                                        m_DisplayPadFill ?
+                                        _( "Show pads in outline mode" ) :
+                                        _( "Show pads in fill mode" ) );
+}
+
+
+void PCB_BASE_FRAME::OnUpdateSelectGrid( wxUpdateUIEvent& aEvent )
+{
+    // No need to update the grid select box if it doesn't exist or the grid setting change
+    // was made using the select box.
+    if( m_SelGridBox == NULL || m_AuxiliaryToolBar == NULL )
+        return;
+
+    int select = wxNOT_FOUND;
+
+    for( size_t i = 0; i < GetScreen()->GetGridCount(); i++ )
+    {
+        if( GetScreen()->GetGridId() == GetScreen()->GetGrid( i ).m_Id )
+        {
+            select = (int) i;
+            break;
+        }
+    }
+
+    if( select != m_SelGridBox->GetSelection() )
+        m_SelGridBox->SetSelection( select );
+}
+
+
+void PCB_BASE_FRAME::OnUpdateSelectZoom( wxUpdateUIEvent& aEvent )
+{
+    if( m_SelZoomBox == NULL || m_AuxiliaryToolBar == NULL )
+        return;
+
+    int current = 0;
+
+    for( size_t i = 0; i < GetScreen()->m_ZoomList.GetCount(); i++ )
+    {
+        if( GetScreen()->GetZoom() == GetScreen()->m_ZoomList[i] )
+        {
+            current = i + 1;
+            break;
+        }
+    }
+
+    if( current != m_SelZoomBox->GetSelection() )
+        m_SelZoomBox->SetSelection( current );
+}
+
+
+void PCB_BASE_FRAME::ProcessItemSelection( wxCommandEvent& aEvent )
+{
+    int id = aEvent.GetId();
 
     // index into the collector list:
     int itemNdx = id - ID_POPUP_PCB_ITEM_SELECTION_START;
 
-    if( id >= ID_POPUP_PCB_ITEM_SELECTION_START
-     && id <= ID_POPUP_PCB_ITEM_SELECTION_END )
+    if( id >= ID_POPUP_PCB_ITEM_SELECTION_START && id <= ID_POPUP_PCB_ITEM_SELECTION_END )
     {
         BOARD_ITEM* item = (*m_Collector)[itemNdx];
         DrawPanel->m_AbortRequest = false;
@@ -236,7 +318,7 @@ void WinEDA_BasePcbFrame::ProcessItemSelection( wxCommandEvent& event )
 }
 
 
-void WinEDA_BasePcbFrame::SetCurItem( BOARD_ITEM* aItem, bool aDisplayInfo )
+void PCB_BASE_FRAME::SetCurItem( BOARD_ITEM* aItem, bool aDisplayInfo )
 {
     GetScreen()->SetCurItem( aItem );
 
@@ -265,13 +347,13 @@ void WinEDA_BasePcbFrame::SetCurItem( BOARD_ITEM* aItem, bool aDisplayInfo )
 }
 
 
-BOARD_ITEM* WinEDA_BasePcbFrame::GetCurItem()
+BOARD_ITEM* PCB_BASE_FRAME::GetCurItem()
 {
     return GetScreen()->GetCurItem();
 }
 
 
-GENERAL_COLLECTORS_GUIDE WinEDA_BasePcbFrame::GetCollectorsGuide()
+GENERAL_COLLECTORS_GUIDE PCB_BASE_FRAME::GetCollectorsGuide()
 {
     GENERAL_COLLECTORS_GUIDE guide( m_Pcb->GetVisibleLayers(),
                                     ( (PCB_SCREEN*)GetScreen())->m_Active_Layer );
@@ -288,19 +370,18 @@ GENERAL_COLLECTORS_GUIDE WinEDA_BasePcbFrame::GetCollectorsGuide()
     return guide;
 }
 
-void WinEDA_BasePcbFrame::SetToolID( int id, int new_cursor_id,
-                                     const wxString& title )
+void PCB_BASE_FRAME::SetToolID( int aId, int aCursor, const wxString& aToolMsg )
 {
     bool redraw = false;
 
-    WinEDA_DrawFrame::SetToolID( id, new_cursor_id, title );
+    EDA_DRAW_FRAME::SetToolID( aId, aCursor, aToolMsg );
 
-    if( id < 0 )
+    if( aId < 0 )
         return;
 
     // handle color changes for transitions in and out of ID_TRACK_BUTT
-    if( ( m_ID_current_state == ID_TRACK_BUTT && id != ID_TRACK_BUTT )
-        || ( m_ID_current_state != ID_TRACK_BUTT && id == ID_TRACK_BUTT ) )
+    if( ( GetToolId() == ID_TRACK_BUTT && aId != ID_TRACK_BUTT )
+        || ( GetToolId() != ID_TRACK_BUTT && aId== ID_TRACK_BUTT ) )
     {
         if( DisplayOpt.ContrastModeDisplay )
             redraw = true;
@@ -316,21 +397,22 @@ void WinEDA_BasePcbFrame::SetToolID( int id, int new_cursor_id,
 /*
  * Update the status bar information.
  */
-void WinEDA_BasePcbFrame::UpdateStatusBar()
+void PCB_BASE_FRAME::UpdateStatusBar()
 {
-    WinEDA_DrawFrame::UpdateStatusBar();
+    EDA_DRAW_FRAME::UpdateStatusBar();
 
     if( DisplayOpt.DisplayPolarCood )  // display polar coordinates
     {
-        BASE_SCREEN*    screen = GetBaseScreen();
+        PCB_SCREEN* screen = GetScreen();
+
         if( !screen )
             return;
 
-        wxString        Line;
-        double          theta, ro;
+        wxString     Line;
+        double       theta, ro;
 
-        int dx = screen->m_Curseur.x - screen->m_O_Curseur.x;
-        int dy = screen->m_Curseur.y - screen->m_O_Curseur.y;
+        int dx = screen->GetCrossHairPosition().x - screen->m_O_Curseur.x;
+        int dy = screen->GetCrossHairPosition().y - screen->m_O_Curseur.y;
 
         if( dx==0 && dy==0 )
             theta = 0.0;
@@ -340,21 +422,35 @@ void WinEDA_BasePcbFrame::UpdateStatusBar()
         theta = theta * 180.0 / M_PI;
 
         ro = sqrt( ( (double) dx * dx ) + ( (double) dy * dy ) );
-        Line.Printf( g_UnitMetric ? wxT( "Ro %.3f Th %.1f" ) :
-                     wxT( "Ro %.4f Th %.1f" ),
-                     To_User_Unit( g_UnitMetric, ro, m_InternalUnits ),
-                     theta );
+        wxString formatter;
+        switch( g_UserUnit )
+        {
+        case INCHES:
+            formatter = wxT( "Ro %.4f Th %.1f" );
+            break;
+
+        case MILLIMETRES:
+            formatter = wxT( "Ro %.3f Th %.1f" );
+            break;
+
+        case UNSCALED_UNITS:
+            formatter = wxT( "Ro %f Th %f" );
+            break;
+        }
+
+        Line.Printf( formatter, To_User_Unit( g_UserUnit, ro, m_InternalUnits ), theta );
 
         // overwrite the absolute cartesian coordinates
         SetStatusText( Line, 2 );
     }
+}
 
-    /*  not this, because status field no. 0 is reserved for actual fleeting
-        status information.  If this is enabled, then that text is erased on
-        every DrawPanel redraw.  Field no. 0 is set with Affiche_Message() and it
-        should persist until called again.
-    SetStatusText( Line, 0 );
-    */
+
+void PCB_BASE_FRAME::unitsChangeRefresh()
+{
+    EDA_DRAW_FRAME::unitsChangeRefresh();    // Update the status bar.
+
+    updateGridSelectBox();
 }
 
 
@@ -364,13 +460,14 @@ void WinEDA_BasePcbFrame::UpdateStatusBar()
  * Don't forget to call this base method from any derived classes or the
  * settings will not get loaded.
  */
-void WinEDA_BasePcbFrame::LoadSettings()
+void PCB_BASE_FRAME::LoadSettings()
 {
     wxASSERT( wxGetApp().m_EDA_Config != NULL );
 
     wxConfig* cfg = wxGetApp().m_EDA_Config;
 
-    WinEDA_DrawFrame::LoadSettings();
+    EDA_DRAW_FRAME::LoadSettings();
+
     // Ensure grid id is an existent grid id:
     if( (m_LastGridSizeId <= 0) ||
         (m_LastGridSizeId > (ID_POPUP_GRID_USER - ID_POPUP_GRID_LEVEL_1000)) )
@@ -378,19 +475,27 @@ void WinEDA_BasePcbFrame::LoadSettings()
 
     cfg->Read( m_FrameName + UserGridSizeXEntry, &m_UserGridSize.x, 0.01 );
     cfg->Read( m_FrameName + UserGridSizeYEntry, &m_UserGridSize.y, 0.01 );
-    cfg->Read( m_FrameName + UserGridUnitsEntry, &m_UserGridUnits,
-               ( long )INCHES );
+
+    long itmp;
+    cfg->Read( m_FrameName + UserGridUnitsEntry, &itmp, ( long )INCHES );
+    m_UserGridUnit = (UserUnitType) itmp;
     cfg->Read( m_FrameName + DisplayPadFillEntry, &m_DisplayPadFill, true );
     cfg->Read( m_FrameName + DisplayViaFillEntry, &m_DisplayViaFill, true );
     cfg->Read( m_FrameName + DisplayPadNumberEntry, &m_DisplayPadNum, true );
-    cfg->Read( m_FrameName + DisplayModuleEdgeEntry, &m_DisplayModEdge,
-               ( long )FILLED );
+    cfg->Read( m_FrameName + DisplayModuleEdgeEntry, &m_DisplayModEdge, ( long )FILLED );
+
     if( m_DisplayModEdge < FILAIRE || m_DisplayModEdge > SKETCH )
         m_DisplayModEdge = FILLED;
-    cfg->Read( m_FrameName + DisplayModuleTextEntry, &m_DisplayModText,
-               ( long )FILLED );
+
+    cfg->Read( m_FrameName + DisplayModuleTextEntry, &m_DisplayModText, ( long )FILLED );
+
     if( m_DisplayModText < FILAIRE || m_DisplayModText > SKETCH )
         m_DisplayModText = FILLED;
+
+    // WxWidgets 2.9.1 seems call setlocale( LC_NUMERIC, "" )
+    // when reading doubles in config,
+    // but forget to back to current locale. So we call SetLocaleTo_Default
+    SetLocaleTo_Default( );
 }
 
 
@@ -400,16 +505,16 @@ void WinEDA_BasePcbFrame::LoadSettings()
  * Don't forget to call this base method from any derived classes or the
  * settings will not get saved.
  */
-void WinEDA_BasePcbFrame::SaveSettings()
+void PCB_BASE_FRAME::SaveSettings()
 {
     wxASSERT( wxGetApp().m_EDA_Config != NULL );
 
     wxConfig* cfg = wxGetApp().m_EDA_Config;
 
-    WinEDA_DrawFrame::SaveSettings();
+    EDA_DRAW_FRAME::SaveSettings();
     cfg->Write( m_FrameName + UserGridSizeXEntry, m_UserGridSize.x );
     cfg->Write( m_FrameName + UserGridSizeYEntry, m_UserGridSize.y );
-    cfg->Write( m_FrameName + UserGridUnitsEntry, ( long )m_UserGridUnits );
+    cfg->Write( m_FrameName + UserGridUnitsEntry, ( long )m_UserGridUnit );
     cfg->Write( m_FrameName + DisplayPadFillEntry, m_DisplayPadFill );
     cfg->Write( m_FrameName + DisplayViaFillEntry, m_DisplayViaFill );
     cfg->Write( m_FrameName + DisplayPadNumberEntry, m_DisplayPadNum );
@@ -418,16 +523,110 @@ void WinEDA_BasePcbFrame::SaveSettings()
 }
 
 
-
-/** Function OnModify()
+/**
+ * Function OnModify
  * Must be called after a schematic change
  * in order to set the "modify" flag of the current screen
  * and update the date in frame reference
+ * do not forget to call this basic OnModify function to update info
+ * in derived OnModify functions
  */
-void WinEDA_BasePcbFrame::OnModify( )
+void PCB_BASE_FRAME::OnModify( )
 {
     GetScreen()->SetModify( );
 
     wxString       date = GenDate();
     GetScreen()->m_Date = date;
 }
+
+
+void PCB_BASE_FRAME::updateGridSelectBox()
+{
+    UpdateStatusBar();
+    DisplayUnitsMsg();
+
+    if( m_SelGridBox == NULL )
+        return;
+
+    // Update grid values with the current units setting.
+    m_SelGridBox->Clear();
+
+    wxString msg;
+    wxString format = _( "Grid");
+
+    switch( g_UserUnit )
+    {
+    case INCHES:
+        format += wxT( " %.1f" );
+        break;
+
+    case MILLIMETRES:
+        format += wxT( " %.3f" );
+        break;
+
+    case UNSCALED_UNITS:
+        format += wxT( " %f" );
+        break;
+    }
+
+    for( size_t i = 0; i < GetScreen()->GetGridCount(); i++ )
+    {
+        GRID_TYPE& grid = GetScreen()->GetGrid( i );
+        double value = To_User_Unit( g_UserUnit, grid.m_Size.x, m_InternalUnits );
+
+        if( grid.m_Id != ID_POPUP_GRID_USER )
+        {
+            switch( g_UserUnit )
+            {
+            case INCHES:
+                msg.Printf( format.GetData(), value * 1000 );
+                break;
+
+            case MILLIMETRES:
+            case UNSCALED_UNITS:
+                msg.Printf( format.GetData(), value );
+                break;
+            }
+        }
+        else
+            msg = _( "User Grid" );
+
+        m_SelGridBox->Append( msg, (void*) &grid.m_Id );
+
+        if( ( m_LastGridSizeId + ID_POPUP_GRID_LEVEL_1000 ) == GetScreen()->GetGrid( i ).m_Id )
+            m_SelGridBox->SetSelection( i );
+    }
+}
+
+
+void PCB_BASE_FRAME::updateZoomSelectBox()
+{
+    if( m_SelZoomBox == NULL )
+        return;
+
+    wxString msg;
+
+    m_SelZoomBox->Clear();
+    m_SelZoomBox->Append( _( "Auto" ) );
+    m_SelZoomBox->SetSelection( 0 );
+
+    for( int i = 0; i < (int)GetScreen()->m_ZoomList.GetCount(); i++ )
+    {
+        msg = _( "Zoom " );
+
+        if ( ( GetScreen()->m_ZoomList[i] % GetScreen()->m_ZoomScalar ) == 0 )
+            msg << GetScreen()->m_ZoomList[i] / GetScreen()->m_ZoomScalar;
+        else
+        {
+            wxString value;
+            value.Printf( wxT( "%.1f" ),
+                          (float)GetScreen()->m_ZoomList[i] / GetScreen()->m_ZoomScalar );
+            msg += value;
+        }
+
+        m_SelZoomBox->Append( msg );
+
+        if( GetScreen()->GetZoom() == GetScreen()->m_ZoomList[i] )
+            m_SelZoomBox->SetSelection( i + 1 );
+    }
+}
