@@ -1,6 +1,6 @@
 /****************************************************/
-/*	block_module_editor.cpp							*/
-/* Handle block commands for the footprint editor	*/
+/* block_module_editor.cpp                          */
+/* Handle block commands for the footprint editor   */
 /****************************************************/
 
 #include "fctsys.h"
@@ -12,7 +12,8 @@
 #include "block_commande.h"
 
 #include "pcbnew.h"
-#include "autorout.h"
+#include "wxPcbStruct.h"
+#include "module_editor_frame.h"
 #include "pcbplot.h"
 #include "trigo.h"
 
@@ -22,16 +23,10 @@
 #define BLOCK_COLOR BROWN
 #define IS_SELECTED 1
 
-/* Variables Locales */
 
-/* Fonctions exportees */
-
-/* Fonctions Locales */
-static void DrawMovingBlockOutlines( WinEDA_DrawPanel* panel,
-                                     wxDC*             DC,
-                                     bool              erase );
-static int  MarkItemsInBloc( MODULE*   module,
-                             EDA_Rect& Rect );
+static void DrawMovingBlockOutlines( EDA_DRAW_PANEL* aPanel, wxDC* aDC, const wxPoint& aPosition,
+                                     bool aErase );
+static int  MarkItemsInBloc( MODULE* module, EDA_RECT& Rect );
 
 static void ClearMarkItems( MODULE* module );
 static void CopyMarkedItems( MODULE* module, wxPoint offset );
@@ -41,14 +36,11 @@ static void RotateMarkedItems( MODULE* module, wxPoint offset );
 static void DeleteMarkedItems( MODULE* module );
 
 
-/*************************************************************************/
-int WinEDA_ModuleEditFrame::ReturnBlockCommand( int key )
-/*************************************************************************/
-
 /* Return the block command (BLOCK_MOVE, BLOCK_COPY...) corresponding to
- *  the key (ALT, SHIFT ALT ..) pressed when dragging mouse and left or middle button
- *  pressed
+ * the key (ALT, SHIFT ALT ..) pressed when dragging mouse and left or
+ * middle button pressed
  */
+int WinEDA_ModuleEditFrame::ReturnBlockCommand( int key )
 {
     int cmd;
 
@@ -91,34 +83,36 @@ int WinEDA_ModuleEditFrame::ReturnBlockCommand( int key )
 }
 
 
-/****************************************************/
-int WinEDA_ModuleEditFrame::HandleBlockEnd( wxDC* DC )
-/****************************************************/
-
-/* Command BLOCK END (end of block sizing)
- *  return :
- *  0 if command finished (zoom, delete ...)
- *  1 if HandleBlockPlace must follow (items found, and a block place command must follow)
+/**
+ * Function HandleBlockEnd( )
+ * Handle the "end"  of a block command,
+ * i.e. is called at the end of the definition of the area of a block.
+ * depending on the current block command, this command is executed
+ * or parameters are initialized to prepare a call to HandleBlockPlace
+ * in GetScreen()->m_BlockLocate
+ * @return false if no item selected, or command finished,
+ * true if some items found and HandleBlockPlace must be called later
  */
+bool WinEDA_ModuleEditFrame::HandleBlockEnd( wxDC* DC )
 {
-    int     ItemsCount    = 0, MustDoPlace = 0;
-    MODULE* Currentmodule = GetBoard()->m_Modules;
+    int  itemsCount    = 0;
+    bool nextcmd = false;
+    MODULE* currentModule = GetBoard()->m_Modules;
 
-    if( GetScreen()->BlockLocate.m_BlockDrawStruct )
+    if( GetScreen()->m_BlockLocate.GetCount() )
     {
-        BlockState   state   = GetScreen()->BlockLocate.m_State;
-        CmdBlockType command = GetScreen()->BlockLocate.m_Command;
-        DrawPanel->ForceCloseManageCurseur( DrawPanel, DC );
-        GetScreen()->BlockLocate.m_State   = state;
-        GetScreen()->BlockLocate.m_Command = command;
-        DrawPanel->ManageCurseur = DrawAndSizingBlockOutlines;
-        DrawPanel->ForceCloseManageCurseur = AbortBlockCurrentCommand;
-        GetScreen()->m_Curseur.x = GetScreen()->BlockLocate.GetRight();
-        GetScreen()->m_Curseur.y = GetScreen()->BlockLocate.GetBottom();
-        DrawPanel->MouseToCursorSchema();
+        BlockState   state   = GetScreen()->m_BlockLocate.m_State;
+        CmdBlockType command = GetScreen()->m_BlockLocate.m_Command;
+        DrawPanel->m_endMouseCaptureCallback( DrawPanel, DC );
+        GetScreen()->m_BlockLocate.m_State   = state;
+        GetScreen()->m_BlockLocate.m_Command = command;
+        DrawPanel->SetMouseCapture( DrawAndSizingBlockOutlines, AbortBlockCurrentCommand );
+        GetScreen()->SetCrossHairPosition( wxPoint(  GetScreen()->m_BlockLocate.GetRight(),
+                                                     GetScreen()->m_BlockLocate.GetBottom() ) );
+        DrawPanel->MoveCursorToCrossHair();
     }
 
-    switch( GetScreen()->BlockLocate.m_Command )
+    switch( GetScreen()->m_BlockLocate.m_Command )
     {
     case  BLOCK_IDLE:
         DisplayError( this, wxT( "Error in HandleBlockPLace" ) );
@@ -127,32 +121,35 @@ int WinEDA_ModuleEditFrame::HandleBlockEnd( wxDC* DC )
     case BLOCK_DRAG:        /* Drag */
     case BLOCK_MOVE:        /* Move */
     case BLOCK_COPY:        /* Copy */
-        ItemsCount = MarkItemsInBloc( Currentmodule, GetScreen()->BlockLocate );
-        if( ItemsCount )
+        itemsCount = MarkItemsInBloc( currentModule,
+                                      GetScreen()->m_BlockLocate );
+        if( itemsCount )
         {
-            MustDoPlace = 1;
-            if( DrawPanel->ManageCurseur != NULL )
+            nextcmd = true;
+
+            if( DrawPanel->IsMouseCaptured() )
             {
-                DrawPanel->ManageCurseur( DrawPanel, DC, FALSE );
-                DrawPanel->ManageCurseur = DrawMovingBlockOutlines;
-                DrawPanel->ManageCurseur( DrawPanel, DC, FALSE );
+                DrawPanel->m_mouseCaptureCallback( DrawPanel, DC, wxDefaultPosition, FALSE );
+                DrawPanel->m_mouseCaptureCallback = DrawMovingBlockOutlines;
+                DrawPanel->m_mouseCaptureCallback( DrawPanel, DC, wxDefaultPosition, FALSE );
             }
-            GetScreen()->BlockLocate.m_State = STATE_BLOCK_MOVE;
+
+            GetScreen()->m_BlockLocate.m_State = STATE_BLOCK_MOVE;
             DrawPanel->Refresh( TRUE );
         }
         break;
 
     case BLOCK_PRESELECT_MOVE:     /* Move with preselection list*/
-        MustDoPlace = 1;
-        DrawPanel->ManageCurseur = DrawMovingBlockOutlines;
-        GetScreen()->BlockLocate.m_State = STATE_BLOCK_MOVE;
+        nextcmd = true;
+        DrawPanel->m_mouseCaptureCallback = DrawMovingBlockOutlines;
+        GetScreen()->m_BlockLocate.m_State = STATE_BLOCK_MOVE;
         break;
 
     case BLOCK_DELETE:     /* Delete */
-        ItemsCount = MarkItemsInBloc( Currentmodule, GetScreen()->BlockLocate );
-        if( ItemsCount )
-            SaveCopyInUndoList( Currentmodule );
-        DeleteMarkedItems( Currentmodule );
+        itemsCount = MarkItemsInBloc( currentModule, GetScreen()->m_BlockLocate );
+        if( itemsCount )
+            SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        DeleteMarkedItems( currentModule );
         break;
 
     case BLOCK_SAVE:     /* Save */
@@ -160,24 +157,24 @@ int WinEDA_ModuleEditFrame::HandleBlockEnd( wxDC* DC )
         break;
 
     case BLOCK_ROTATE:
-        ItemsCount = MarkItemsInBloc( Currentmodule, GetScreen()->BlockLocate );
-        if( ItemsCount )
-            SaveCopyInUndoList( Currentmodule );
-        RotateMarkedItems( Currentmodule, GetScreen()->BlockLocate.Centre() );
+        itemsCount = MarkItemsInBloc( currentModule, GetScreen()->m_BlockLocate );
+        if( itemsCount )
+            SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        RotateMarkedItems( currentModule, GetScreen()->m_BlockLocate.Centre() );
         break;
 
 
     case BLOCK_MIRROR_X:
     case BLOCK_MIRROR_Y:
-    case BLOCK_INVERT:     /* mirror */
-        ItemsCount = MarkItemsInBloc( Currentmodule, GetScreen()->BlockLocate );
-        if( ItemsCount )
-            SaveCopyInUndoList( Currentmodule );
-        MirrorMarkedItems( Currentmodule, GetScreen()->BlockLocate.Centre() );
+    case BLOCK_FLIP:     /* mirror */
+        itemsCount = MarkItemsInBloc( currentModule, GetScreen()->m_BlockLocate );
+        if( itemsCount )
+            SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        MirrorMarkedItems( currentModule, GetScreen()->m_BlockLocate.Centre() );
         break;
 
     case BLOCK_ZOOM:     /* Window Zoom */
-        Window_Zoom( GetScreen()->BlockLocate );
+        Window_Zoom( GetScreen()->m_BlockLocate );
         break;
 
     case BLOCK_ABORT:
@@ -187,26 +184,21 @@ int WinEDA_ModuleEditFrame::HandleBlockEnd( wxDC* DC )
         break;
     }
 
-    if( MustDoPlace <= 0 )
+    if( !nextcmd )
     {
-        if( GetScreen()->BlockLocate.m_Command  != BLOCK_SELECT_ITEMS_ONLY )
+        if( GetScreen()->m_BlockLocate.m_Command  != BLOCK_SELECT_ITEMS_ONLY )
         {
-            ClearMarkItems( Currentmodule );
+            ClearMarkItems( currentModule );
         }
-        GetScreen()->BlockLocate.m_Flags   = 0;
-        GetScreen()->BlockLocate.m_State   = STATE_NO_BLOCK;
-        GetScreen()->BlockLocate.m_Command = BLOCK_IDLE;
-        DrawPanel->ManageCurseur = NULL;
-        DrawPanel->ForceCloseManageCurseur = NULL;
+
+        GetScreen()->ClearBlockCommand();
         SetCurItem( NULL );
-        SetToolID( m_ID_current_state,
-                   DrawPanel->m_PanelDefaultCursor,
-                   wxEmptyString );
-        DrawPanel->Refresh( TRUE );
+        DrawPanel->SetMouseCapture( NULL, NULL );
+        SetToolID( GetToolId(), DrawPanel->GetCurrentCursor(), wxEmptyString );
+        DrawPanel->Refresh( true );
     }
 
-
-    return MustDoPlace;
+    return nextcmd;
 }
 
 
@@ -214,58 +206,55 @@ int WinEDA_ModuleEditFrame::HandleBlockEnd( wxDC* DC )
 void WinEDA_ModuleEditFrame::HandleBlockPlace( wxDC* DC )
 /******************************************************/
 
-/* Routine to handle the BLOCK PLACE commande
+/* Routine to handle the BLOCK PLACE command
  *  Last routine for block operation for:
  *  - block move & drag
- *  - block copie & paste
+ *  - block copy & paste
  */
 {
-    bool    err = FALSE;
-    MODULE* Currentmodule = GetBoard()->m_Modules;
+    MODULE* currentModule = GetBoard()->m_Modules;
 
-    if( DrawPanel->ManageCurseur == NULL )
+    if( !DrawPanel->IsMouseCaptured() )
     {
-        err = TRUE;
-        DisplayError( this, wxT( "HandleBlockPLace : ManageCurseur = NULL" ) );
+        DisplayError( this, wxT( "HandleBlockPLace : m_mouseCaptureCallback = NULL" ) );
     }
 
-    GetScreen()->BlockLocate.m_State = STATE_BLOCK_STOP;
+    GetScreen()->m_BlockLocate.m_State = STATE_BLOCK_STOP;
 
-    switch( GetScreen()->BlockLocate.m_Command )
+    switch( GetScreen()->m_BlockLocate.m_Command )
     {
     case  BLOCK_IDLE:
-        err = TRUE;
         break;
 
     case BLOCK_DRAG:                /* Drag */
     case BLOCK_MOVE:                /* Move */
     case BLOCK_PRESELECT_MOVE:      /* Move with preselection list*/
-        GetScreen()->BlockLocate.m_BlockDrawStruct = NULL;
-        SaveCopyInUndoList( Currentmodule );
-        MoveMarkedItems( Currentmodule, GetScreen()->BlockLocate.m_MoveVector );
+        GetScreen()->m_BlockLocate.ClearItemsList();
+        SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        MoveMarkedItems( currentModule, GetScreen()->m_BlockLocate.m_MoveVector );
         DrawPanel->Refresh( TRUE );
         break;
 
     case BLOCK_COPY:     /* Copy */
-        GetScreen()->BlockLocate.m_BlockDrawStruct = NULL;
-        SaveCopyInUndoList( Currentmodule );
-        CopyMarkedItems( Currentmodule, GetScreen()->BlockLocate.m_MoveVector );
+        GetScreen()->m_BlockLocate.ClearItemsList();
+        SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        CopyMarkedItems( currentModule, GetScreen()->m_BlockLocate.m_MoveVector );
         break;
 
-    case BLOCK_PASTE:     /* Paste (recopie du dernier bloc sauve */
-        GetScreen()->BlockLocate.m_BlockDrawStruct = NULL;
+    case BLOCK_PASTE:     /* Paste */
+        GetScreen()->m_BlockLocate.ClearItemsList();
         break;
 
     case BLOCK_MIRROR_X:
     case BLOCK_MIRROR_Y:
-    case BLOCK_INVERT:      /* Mirror by popup menu, from block move */
-        SaveCopyInUndoList( Currentmodule );
-        MirrorMarkedItems( Currentmodule, GetScreen()->BlockLocate.Centre() );
+    case BLOCK_FLIP:      /* Mirror by popup menu, from block move */
+        SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        MirrorMarkedItems( currentModule, GetScreen()->m_BlockLocate.Centre() );
         break;
 
     case BLOCK_ROTATE:
-        SaveCopyInUndoList( Currentmodule );
-        RotateMarkedItems( Currentmodule, GetScreen()->BlockLocate.Centre() );
+        SaveCopyInUndoList( currentModule, UR_MODEDIT );
+        RotateMarkedItems( currentModule, GetScreen()->m_BlockLocate.Centre() );
         break;
 
     case BLOCK_ZOOM:        // Handled by HandleBlockEnd
@@ -276,53 +265,44 @@ void WinEDA_ModuleEditFrame::HandleBlockPlace( wxDC* DC )
         break;
     }
 
-    GetScreen()->SetModify();
+    OnModify();
 
-    DrawPanel->ManageCurseur = NULL;
-    DrawPanel->ForceCloseManageCurseur = NULL;
-    GetScreen()->BlockLocate.m_Flags   = 0;
-    GetScreen()->BlockLocate.m_State   = STATE_NO_BLOCK;
-    GetScreen()->BlockLocate.m_Command = BLOCK_IDLE;
+    GetScreen()->m_BlockLocate.m_Flags   = 0;
+    GetScreen()->m_BlockLocate.m_State   = STATE_NO_BLOCK;
+    GetScreen()->m_BlockLocate.m_Command = BLOCK_IDLE;
     SetCurItem( NULL );
-    DrawPanel->Refresh( TRUE );
-
-    SetToolID( m_ID_current_state,
-               DrawPanel->m_PanelDefaultCursor,
-               wxEmptyString );
+    DrawPanel->SetMouseCapture( NULL, NULL );
+    DrawPanel->Refresh( true );
+    SetToolID( GetToolId(), DrawPanel->GetCurrentCursor(), wxEmptyString );
 }
 
 
-/************************************************************************/
-static void DrawMovingBlockOutlines( WinEDA_DrawPanel* panel, wxDC* DC,
-                                     bool erase )
-/************************************************************************/
-
-/* Retrace le contour du block de recherche de structures
- *  L'ensemble du block suit le curseur
+/* Traces the outline of the search block structures
+ * The entire block follows the cursor
  */
+static void DrawMovingBlockOutlines( EDA_DRAW_PANEL* aPanel, wxDC* aDC, const wxPoint& aPosition,
+                                     bool aErase )
 {
-    DrawBlockStruct* PtBlock;
-    BASE_SCREEN*     screen = panel->GetScreen();
+    BLOCK_SELECTOR*  PtBlock;
+    BASE_SCREEN*     screen = aPanel->GetScreen();
     BOARD_ITEM*      item;
     wxPoint          move_offset;
-    MODULE*          Currentmodule =
-        ( (WinEDA_BasePcbFrame*) wxGetApp().GetTopWindow() )->m_ModuleEditFrame->GetBoard()->m_Modules;
+    MODULE*          currentModule =
+        ( (PCB_BASE_FRAME*) wxGetApp().GetTopWindow() )->m_ModuleEditFrame->GetBoard()->m_Modules;
 
-    PtBlock = &screen->BlockLocate;
-    GRSetDrawMode( DC, g_XorMode );
+    PtBlock = &screen->m_BlockLocate;
+    GRSetDrawMode( aDC, g_XorMode );
 
-    /* Effacement ancien cadre */
-    if( erase )
+    if( aErase )
     {
-        PtBlock->Offset( PtBlock->m_MoveVector );
-        PtBlock->Draw( panel, DC );
-        PtBlock->Offset( -PtBlock->m_MoveVector.x, -PtBlock->m_MoveVector.y );
+        PtBlock->Draw( aPanel, aDC, PtBlock->m_MoveVector, g_XorMode, PtBlock->m_Color );
 
-        if( Currentmodule )
+        if( currentModule )
         {
             move_offset.x = -PtBlock->m_MoveVector.x;
             move_offset.y = -PtBlock->m_MoveVector.y;
-            item = Currentmodule->m_Drawings;
+            item = currentModule->m_Drawings;
+
             for( ; item != NULL; item = item->Next() )
             {
                 if( item->m_Selected == 0 )
@@ -332,7 +312,7 @@ static void DrawMovingBlockOutlines( WinEDA_DrawPanel* panel, wxDC* DC,
                 {
                 case TYPE_TEXTE_MODULE:
                 case TYPE_EDGE_MODULE:
-                    item->Draw( panel, DC, g_XorMode, move_offset );
+                    item->Draw( aPanel, aDC, g_XorMode, move_offset );
                     break;
 
                 default:
@@ -340,33 +320,27 @@ static void DrawMovingBlockOutlines( WinEDA_DrawPanel* panel, wxDC* DC,
                 }
             }
 
-            D_PAD* pad = Currentmodule->m_Pads;
+            D_PAD* pad = currentModule->m_Pads;
+
             for( ; pad != NULL; pad = pad->Next() )
             {
                 if( pad->m_Selected == 0 )
                     continue;
-                pad->Draw( panel, DC, g_XorMode, move_offset );
+                pad->Draw( aPanel, aDC, g_XorMode, move_offset );
             }
         }
     }
 
-    /* Redessin nouvel affichage */
-    PtBlock->m_MoveVector.x = screen->m_Curseur.x -
-                              PtBlock->m_BlockLastCursorPosition.x;
-    PtBlock->m_MoveVector.y = screen->m_Curseur.y -
-                              PtBlock->m_BlockLastCursorPosition.y;
+    /* Repaint new view. */
+    PtBlock->m_MoveVector = screen->GetCrossHairPosition() - PtBlock->m_BlockLastCursorPosition;
 
-    GRSetDrawMode( DC, g_XorMode );
-    PtBlock->Offset( PtBlock->m_MoveVector );
-    PtBlock->Draw( panel, DC );
-    PtBlock->Offset( -PtBlock->m_MoveVector.x, -PtBlock->m_MoveVector.y );
+    PtBlock->Draw( aPanel, aDC, PtBlock->m_MoveVector, g_XorMode, PtBlock->m_Color );
 
-
-    if( Currentmodule )
+    if( currentModule )
     {
-        item = Currentmodule->m_Drawings;
-        move_offset.x = -PtBlock->m_MoveVector.x;
-        move_offset.y = -PtBlock->m_MoveVector.y;
+        item = currentModule->m_Drawings;
+        move_offset = - PtBlock->m_MoveVector;
+
         for( ; item != NULL; item = item->Next() )
         {
             if( item->m_Selected == 0 )
@@ -376,7 +350,7 @@ static void DrawMovingBlockOutlines( WinEDA_DrawPanel* panel, wxDC* DC,
             {
             case TYPE_TEXTE_MODULE:
             case TYPE_EDGE_MODULE:
-                item->Draw( panel, DC, g_XorMode, move_offset );
+                item->Draw( aPanel, aDC, g_XorMode, move_offset );
                 break;
 
             default:
@@ -384,23 +358,22 @@ static void DrawMovingBlockOutlines( WinEDA_DrawPanel* panel, wxDC* DC,
             }
         }
 
-        D_PAD* pad = Currentmodule->m_Pads;
+        D_PAD* pad = currentModule->m_Pads;
+
         for( ; pad != NULL; pad = pad->Next() )
         {
             if( pad->m_Selected == 0 )
                 continue;
-            pad->Draw( panel, DC, g_XorMode, move_offset );
+
+            pad->Draw( aPanel, aDC, g_XorMode, move_offset );
         }
     }
 }
 
 
-/****************************************************************************/
-void CopyMarkedItems( MODULE* module, wxPoint offset )
-/****************************************************************************/
-
 /* Copy marked items, at new position = old position + offset
  */
+void CopyMarkedItems( MODULE* module, wxPoint offset )
 {
     if( module == NULL )
         return;
@@ -442,8 +415,7 @@ void CopyMarkedItems( MODULE* module, wxPoint offset )
             break;
 
         default:
-            DisplayError( NULL,
-                          wxT( "Internal Err: CopyMarkedItems: type indefini" ) );
+            DisplayError( NULL, wxT( "CopyMarkedItems: type undefined" ) );
             break;
         }
     }
@@ -452,14 +424,11 @@ void CopyMarkedItems( MODULE* module, wxPoint offset )
 }
 
 
-/****************************************************/
-void MoveMarkedItems( MODULE* module, wxPoint offset )
-/****************************************************/
-
 /* Move marked items, at new position = old position + offset
  */
+void MoveMarkedItems( MODULE* module, wxPoint offset )
 {
-    EDA_BaseStruct* item;
+    EDA_ITEM* item;
 
     if( module == NULL )
         return;
@@ -503,12 +472,9 @@ void MoveMarkedItems( MODULE* module, wxPoint offset )
 }
 
 
-/******************************************************/
-void DeleteMarkedItems( MODULE* module )
-/******************************************************/
-
 /* Delete marked items
  */
+void DeleteMarkedItems( MODULE* module )
 {
     BOARD_ITEM* item;
     BOARD_ITEM* next_item;
@@ -538,15 +504,12 @@ void DeleteMarkedItems( MODULE* module )
 }
 
 
-/******************************************************/
-void MirrorMarkedItems( MODULE* module, wxPoint offset )
-/******************************************************/
-
 /* Mirror marked items, refer to a Vertical axis at position offset
  */
+void MirrorMarkedItems( MODULE* module, wxPoint offset )
 {
 #define SETMIRROR( z ) (z) -= offset.x; (z) = -(z); (z) += offset.x;
-    EDA_BaseStruct* item;
+    EDA_ITEM* item;
 
     if( module == NULL )
         return;
@@ -558,10 +521,10 @@ void MirrorMarkedItems( MODULE* module, wxPoint offset )
             continue;
         SETMIRROR( pad->GetPosition().x );
         pad->m_Pos0.x = pad->GetPosition().x;
-        pad->m_Offset.x    = -pad->m_Offset.x;
-        pad->m_DeltaSize.x = -pad->m_DeltaSize.x;
+        NEGATE( pad->m_Offset.x );
+        NEGATE( pad->m_DeltaSize.x );
         pad->m_Orient      = 1800 - pad->m_Orient;
-        NORMALIZE_ANGLE( pad->m_Orient );
+        NORMALIZE_ANGLE_POS( pad->m_Orient );
     }
 
     item = module->m_Drawings;
@@ -573,14 +536,13 @@ void MirrorMarkedItems( MODULE* module, wxPoint offset )
         switch( item->Type() )
         {
         case TYPE_EDGE_MODULE:
-            SETMIRROR( ( (EDGE_MODULE*) item )->m_Start.x );
-            ( (EDGE_MODULE*) item )->m_Start0.x =
-                ( (EDGE_MODULE*) item )->m_Start.x;
-            SETMIRROR( ( (EDGE_MODULE*) item )->m_End.x );
-            ( (EDGE_MODULE*) item )->m_End0.x =
-                ( (EDGE_MODULE*) item )->m_End.x;
-            ( (EDGE_MODULE*) item )->m_Angle =
-                -( (EDGE_MODULE*) item )->m_Angle;
+        {  EDGE_MODULE * edge =  (EDGE_MODULE*) item;
+            SETMIRROR( edge->m_Start.x );
+            edge->m_Start0.x = edge->m_Start.x;
+            SETMIRROR( edge->m_End.x );
+            edge->m_End0.x = edge->m_End.x;
+            NEGATE( edge->m_Angle );
+        }
             break;
 
         case TYPE_TEXTE_MODULE:
@@ -590,23 +552,21 @@ void MirrorMarkedItems( MODULE* module, wxPoint offset )
             break;
 
         default:
-            ;
+            break;
         }
 
-        item->m_Flags = item->m_Selected = 0;
+        item->m_Flags = 0;
+        item->m_Selected = 0;
     }
 }
 
 
-/******************************************************/
-void RotateMarkedItems( MODULE* module, wxPoint offset )
-/******************************************************/
-
 /* Rotate marked items, refer to a Vertical axis at position offset
  */
+void RotateMarkedItems( MODULE* module, wxPoint offset )
 {
 #define ROTATE( z ) RotatePoint( (&z), offset, 900 )
-    EDA_BaseStruct* item;
+    EDA_ITEM* item;
 
     if( module == NULL )
         return;
@@ -619,7 +579,7 @@ void RotateMarkedItems( MODULE* module, wxPoint offset )
         ROTATE( pad->GetPosition() );
         pad->m_Pos0    = pad->GetPosition();
         pad->m_Orient += 900;
-        NORMALIZE_ANGLE( pad->m_Orient );
+        NORMALIZE_ANGLE_POS( pad->m_Orient );
     }
 
     item = module->m_Drawings;
@@ -654,11 +614,9 @@ void RotateMarkedItems( MODULE* module, wxPoint offset )
 }
 
 
-/*********************************************************/
 void ClearMarkItems( MODULE* module )
-/*********************************************************/
 {
-    EDA_BaseStruct* item;
+    EDA_ITEM* item;
 
     if( module == NULL )
         return;
@@ -673,18 +631,15 @@ void ClearMarkItems( MODULE* module )
 }
 
 
-/***************************************************************/
-int MarkItemsInBloc( MODULE* module, EDA_Rect& Rect )
-/***************************************************************/
-
 /* Mark items inside rect.
  *  Items are inside rect when an end point is inside rect
  */
+int MarkItemsInBloc( MODULE* module, EDA_RECT& Rect )
 {
-    EDA_BaseStruct* item;
-    int             ItemsCount = 0;
-    wxPoint         pos;
-    D_PAD*          pad;
+    EDA_ITEM* item;
+    int       ItemsCount = 0;
+    wxPoint   pos;
+    D_PAD*    pad;
 
     if( module == NULL )
         return 0;
@@ -694,7 +649,7 @@ int MarkItemsInBloc( MODULE* module, EDA_Rect& Rect )
     {
         pad->m_Selected = 0;
         pos = pad->GetPosition();
-        if( Rect.Inside( pos ) )
+        if( Rect.Contains( pos ) )
         {
             pad->m_Selected = IS_SELECTED;
             ItemsCount++;
@@ -709,14 +664,7 @@ int MarkItemsInBloc( MODULE* module, EDA_Rect& Rect )
         switch( item->Type() )
         {
         case TYPE_EDGE_MODULE:
-            pos = ( (EDGE_MODULE*) item )->m_Start;
-            if( Rect.Inside( pos ) )
-            {
-                item->m_Selected = IS_SELECTED;
-                ItemsCount++;
-            }
-            pos = ( (EDGE_MODULE*) item )->m_End;
-            if( Rect.Inside( pos ) )
+            if( ((EDGE_MODULE*)item )->HitTest( Rect ) )
             {
                 item->m_Selected = IS_SELECTED;
                 ItemsCount++;
@@ -725,7 +673,7 @@ int MarkItemsInBloc( MODULE* module, EDA_Rect& Rect )
 
         case TYPE_TEXTE_MODULE:
             pos = ( (TEXTE_MODULE*) item )->GetPosition();
-            if( Rect.Inside( pos ) )
+            if( Rect.Contains( pos ) )
             {
                 item->m_Selected = IS_SELECTED;
                 ItemsCount++;
