@@ -6,13 +6,15 @@
 #ifndef TEXT_MODULE_H
 #define TEXT_MODULE_H
 
+#include "richio.h"
 
 #define TEXT_is_REFERENCE 0
 #define TEXT_is_VALUE     1
 #define TEXT_is_DIVERS    2
 
+#define UMBILICAL_COLOR   LIGHTBLUE
 
-class TEXTE_MODULE : public BOARD_ITEM, public EDA_TextStruct
+class TEXTE_MODULE : public BOARD_ITEM, public EDA_TEXT
 {
 /* Note: orientation in 1/10 deg relative to the footprint
  * Physical orient is m_Orient + m_Parent->m_Orient
@@ -45,23 +47,24 @@ public: TEXTE_MODULE( MODULE* parent, int text_type = TEXT_is_DIVERS );
     void     Copy( TEXTE_MODULE* source ); // copy structure
 
     /* Gestion du texte */
-    void     SetWidth( int new_width );
-    int      GetLength();           /* text length */
-    int      GetDrawRotation();     // Return text rotation for drawings and
-                                    // plotting
 
-    /** Function GetTextRect
-     * @return an EDA_Rect which gives the position and size of the text area
+    int      GetLength() const;        /* text length */
+
+    int      GetDrawRotation() const;  // Return text rotation for drawings and plotting
+
+    /**
+     * Function GetTextRect
+     * @return an EDA_RECT which gives the position and size of the text area
      * (for the 0 orient text and footprint)
      */
-    EDA_Rect GetTextRect( void );
+    EDA_RECT GetTextRect( void ) const;
 
     /**
      * Function GetBoundingBox
      * returns the bounding box of this Text (according to text and footprint
      * orientation)
      */
-    EDA_Rect GetBoundingBox();
+    EDA_RECT GetBoundingBox() const;
 
     void     SetDrawCoord();        // Set absolute coordinates.
 
@@ -77,40 +80,50 @@ public: TEXTE_MODULE( MODULE* parent, int text_type = TEXT_is_DIVERS );
     bool     Save( FILE* aFile ) const;
 
     /**
-     * Function ReadLineDescr
+     * Function ReadDescr
      * Read description from a given line in "*.brd" format.
-     * @param aLine The current line which contains the first line of
-     *              description.
-     * @param aLine The FILE to read next lines (currently not used).
-     * @param LineNum a point to the line count (currently not used).
+     * @param aReader is a pointer to a LINE_READER to read from.
      * @return int - > 0 if success reading else 0.
      */
-    int      ReadDescr( char* aLine, FILE* aFile, int* aLineNum = NULL );
+    int      ReadDescr( LINE_READER* aReader );
 
     /* drawing functions */
-    void     Draw( WinEDA_DrawPanel* panel,
-                   wxDC*             DC,
-                   int               aDrawMode,
-                   const wxPoint&    offset = ZeroOffset );
+    void     Draw( EDA_DRAW_PANEL* panel,
+                   wxDC*           DC,
+                   int             aDrawMode,
+                   const wxPoint&  offset = ZeroOffset );
 
+    /**
+     * Function DrawUmbilical
+     * draws a line from the TEXTE_MODULE origin
+     * to parent MODULE origin.
+     * @param aPanel = the current DrawPanel
+     * @param aDC = the current device context
+     * @param aDrawMode = drawing mode, typically GR_XOR
+     * @param aOffset = offset for TEXTE_MODULE
+     */
+    void     DrawUmbilical( EDA_DRAW_PANEL* aPanel,
+                            wxDC*           aDC,
+                            int             aDrawMode,
+                            const wxPoint&  aOffset = ZeroOffset );
 
     /**
      * Function DisplayInfo
      * has knowledge about the frame and how and where to put status
      * information about this object into the frame's message panel.
-     * Is virtual from EDA_BaseStruct.
-     * @param frame A WinEDA_DrawFrame in which to print status information.
+     * Is virtual from EDA_ITEM.
+     * @param frame A EDA_DRAW_FRAME in which to print status information.
      */
-    void DisplayInfo( WinEDA_DrawFrame* frame );
+    void DisplayInfo( EDA_DRAW_FRAME* frame );
 
 
     /**
      * Function HitTest
      * tests if the given wxPoint is within the bounds of this object.
-     * @param posref A wxPoint to test
+     * @param aRefPos A wxPoint to test
      * @return bool - true if a hit, else false
      */
-    bool HitTest( const wxPoint& posref );
+    bool HitTest( const wxPoint& aRefPos );
 
     /**
      * Function IsOnLayer
@@ -123,12 +136,12 @@ public: TEXTE_MODULE( MODULE* parent, int text_type = TEXT_is_DIVERS );
      */
     bool IsOnLayer( int aLayer ) const;
 
-    /**
+    /*
      * Function IsOnOneOfTheseLayers
      * returns true if this object is on one of the given layers.  Is virtual
      * so objects like D_PAD, which reside on multiple layers, can do their own
      * form of testing.
-     * virtual inheritance from BOARD_ITEM.
+     * virtual inheritance from BOARD_ITEM. (not yet written)
      * @param aLayerMask The bit-mapped set of layers to test for.
      * @return bool - true if on one of the given layers, else false.
      * bool IsOnOneOfTheseLayers( int aLayerMask ) const;
@@ -138,7 +151,7 @@ public: TEXTE_MODULE( MODULE* parent, int text_type = TEXT_is_DIVERS );
     /**
      * Function GetClass
      * returns the class name.
-     * @return wxString
+     * @return wxString = "MTEXT"
      */
     virtual wxString GetClass() const
     {
