@@ -27,7 +27,7 @@
 
 
 /*  This module contains a number of COLLECTOR implementations which are used
-    to augment the functionality of class WinEDA_PcbFrame.
+    to augment the functionality of class PCB_EDIT_FRAME.
 */
 
 
@@ -137,16 +137,36 @@ public:
 
     /**
      * Function IgnoreModulesOnCu
-     * @return bool - true if should ignore MODULEs on copper layer.
+     * @return bool - true if should ignore MODULEs on Back Side.
      */
     virtual     bool IgnoreModulesOnCu() const = 0;
 
     /**
      * Function IgnoreModulesOnCmp
-     * @return bool - ture if should ignore MODULEs on component layer.
+     * @return bool - ture if should ignore MODULEs on Front Side.
      */
     virtual     bool IgnoreModulesOnCmp() const = 0;
 
+    /**
+     * Function IgnorePadsOnBack
+     * @return bool - true if should ignore Pads on Back Side.
+     */
+    virtual     bool IgnorePadsOnBack() const = 0;
+
+    /**
+     * Function IgnorePadsOnFront
+     * @return bool - ture if should ignore PADSs on Front Side.
+     */
+    virtual     bool IgnorePadsOnFront() const = 0;
+
+    /**
+     * Function IgnorePads
+     * @return bool - true if should ignore PADSs on Front side and Back side.
+     */
+    virtual     bool IgnorePads() const
+    {
+        return IgnorePadsOnFront() && IgnorePadsOnBack();
+    }
 
     /**
      * Function UseHitTesting
@@ -162,12 +182,12 @@ public:
  * Class GENERAL_COLLECTOR
  * is intended for use when the right click button is pressed, or when the
  * plain "arrow" tool is in effect.  This class can be used by window classes
- * such as WinEDA_PcbFrame.
+ * such as PCB_EDIT_FRAME.
  *
  * Philosophy: this class knows nothing of the context in which a BOARD is used
  * and that means it knows nothing about which layers are visible or current,
  * but can handle those concerns by the SetPreferredLayer() function and the
- * SetLayerMask() fuction.
+ * SetLayerMask() function.
  */
 class GENERAL_COLLECTOR : public COLLECTOR
 {
@@ -207,6 +227,11 @@ public:
      */
     static const KICAD_T AllButZones[];
 
+    /**
+     * A scan list for zones outlines only
+     */
+    static const KICAD_T Zones[];
+
 
     /**
      * A scan list for all primary board items, omitting items which are subordinate to
@@ -274,7 +299,7 @@ public:
     /**
      * Function operator[int]
      * overloads COLLECTOR::operator[](int) to return a BOARD_ITEM* instead of
-     * an EDA_BaseStruct* type.
+     * an EDA_ITEM* type.
      * @param ndx The index into the list.
      * @return BOARD_ITEM* - or something derived from it, or NULL.
      */
@@ -298,12 +323,12 @@ public:
      * is the examining function within the INSPECTOR which is passed to the
      * Iterate function.
      *
-     * @param testItem An EDA_BaseStruct to examine.
+     * @param testItem An EDA_ITEM to examine.
      * @param testData is not used in this class.
      * @return SEARCH_RESULT - SEARCH_QUIT if the Iterator is to stop the scan,
      *   else SCAN_CONTINUE;
      */
-    SEARCH_RESULT Inspect( EDA_BaseStruct* testItem, const void* testData );
+    SEARCH_RESULT Inspect( EDA_ITEM* testItem, const void* testData );
 
 
     /**
@@ -349,6 +374,8 @@ private:
     bool    m_IgnoreMTextsOnCmp;
     bool    m_IgnoreModulesOnCu;
     bool    m_IgnoreModulesOnCmp;
+    bool    m_IgnorePadsOnFront;
+    bool    m_IgnorePadsOnBack;
 
 public:
 
@@ -356,11 +383,12 @@ public:
      * Constructor GENERAL_COLLECTORS_GUIDE
      * grabs stuff from global preferences and uses reasonable defaults.
      * Add more constructors as needed.
-     * @param settings The EDA_BoardDesignSettings to reference.
+     * @param aVisibleLayerMask = current visible layers (bit mask)
+     * @param aPreferredLayer = the layer to search first
      */
     GENERAL_COLLECTORS_GUIDE( int aVisibleLayerMask, int aPreferredLayer )
     {
-        m_PreferredLayer            = LAYER_CMP_N;
+        m_PreferredLayer            = LAYER_N_FRONT;
         m_IgnorePreferredLayer      = false;
         m_LayerLocked               = 0;
         m_LayerVisible              = aVisibleLayerMask;
@@ -381,6 +409,9 @@ public:
         m_IgnoreMTextsOnCmp         = false;
         m_IgnoreModulesOnCu         = true; // !Show_Modules_Cmp;
         m_IgnoreModulesOnCmp        = false;
+
+        m_IgnorePadsOnFront         = false;
+        m_IgnorePadsOnBack          = false;
     }
 
 
@@ -494,10 +525,24 @@ public:
 
     /**
      * Function IgnoreModulesOnCmp
-     * @return bool - ture if should ignore MODULEs on component layer.
+     * @return bool - true if should ignore MODULEs on component layer.
      */
     bool IgnoreModulesOnCmp() const { return m_IgnoreModulesOnCmp; }
     void SetIgnoreModulesOnCmp( bool ignore ) { m_IgnoreModulesOnCmp = ignore; }
+
+    /**
+     * Function IgnorePadsOnBack
+     * @return bool - true if should ignore Pads on Back Side.
+     */
+    bool IgnorePadsOnBack() const { return m_IgnorePadsOnBack; }
+    void SetIgnorePadsOnBack(bool ignore) { m_IgnorePadsOnBack = ignore; }
+
+    /**
+     * Function IgnorePadsOnFront
+     * @return bool - true if should ignore PADSs on Front Side.
+     */
+    bool IgnorePadsOnFront() const { return m_IgnorePadsOnFront; }
+    void SetIgnorePadsOnFront(bool ignore) { m_IgnorePadsOnFront = ignore; }
 };
 
 
@@ -514,7 +559,7 @@ public:
     /**
      * Function operator[int]
      * overloads COLLECTOR::operator[](int) to return a BOARD_ITEM* instead of
-     * an EDA_BaseStruct* type.
+     * an EDA_ITEM* type.
      * @param ndx The index into the list.
      * @return BOARD_ITEM* - or something derived from it, or NULL.
      */
@@ -531,12 +576,12 @@ public:
      * is the examining function within the INSPECTOR which is passed to the
      * Iterate function.
      *
-     * @param testItem An EDA_BaseStruct to examine.
+     * @param testItem An EDA_ITEM to examine.
      * @param testData is not used in this class.
      * @return SEARCH_RESULT - SEARCH_QUIT if the Iterator is to stop the scan,
      *   else SCAN_CONTINUE;
      */
-    SEARCH_RESULT Inspect( EDA_BaseStruct* testItem, const void* testData );
+    SEARCH_RESULT Inspect( EDA_ITEM* testItem, const void* testData );
 
 
     /**
