@@ -7,7 +7,6 @@
 
 #include "common.h"
 #include "pcbnew.h"
-#include "autorout.h"
 
 #include "protos.h"
 
@@ -28,7 +27,8 @@ static void RebuildTrackChain( BOARD* pcb );
 static int Merge_Two_SubNets( TRACK* pt_start_conn, TRACK* pt_end_conn, int old_val, int new_val )
 /**************************************************************************************************/
 
-/** Function Merge_Two_SubNets()
+/**
+ * Function Merge_Two_SubNets
  * Used by Propagate_SubNet()
  * Change a subnet value to a new value, for tracks ans pads which are connected to corresponding track
  * for pads and tracks, this is the .m_Subnet member that is tested and modified
@@ -90,7 +90,8 @@ static int Merge_Two_SubNets( TRACK* pt_start_conn, TRACK* pt_end_conn, int old_
 static void Propagate_SubNet( TRACK* pt_start_conn, TRACK* pt_end_conn )
 /******************************************************************/
 
-/** Function Propagate_SubNet
+/**
+ * Function Propagate_SubNet
  * Test a list of track segment, to create or propagate a sub netcode to pads and segments connected together
  * the track list must be sorted by nets, and all segments from pt_start_conn to pt_end_conn have the same net
  * When 2 items are connected (a track to a pad, or a track to an other track) they are grouped in a cluster.
@@ -265,10 +266,11 @@ static void Propagate_SubNet( TRACK* pt_start_conn, TRACK* pt_end_conn )
 
 
 /***************************************************/
-void WinEDA_BasePcbFrame::test_connexions( wxDC* DC )
+void PCB_BASE_FRAME::test_connexions( wxDC* DC )
 /***************************************************/
 
-/** Function testing the connections relative to all nets
+/**
+ * Function testing the connections relative to all nets
  *  This function update the status of the ratsnest ( flag CH_ACTIF = 0 if a connection is found, = 1 else)
  * track segments are assumed to be sorted by net codes.
  * This is the case because when a new track is added, it is inserted in the linked list according to its net code.
@@ -277,9 +279,9 @@ void WinEDA_BasePcbFrame::test_connexions( wxDC* DC )
  */
 {
     // Clear the cluster identifier for all pads
-    for( unsigned i = 0;  i< m_Pcb->m_Pads.size();  ++i )
+    for( unsigned i = 0;  i< m_Pcb->GetPadsCount();  ++i )
     {
-        D_PAD* pad = m_Pcb->m_Pads[i];
+        D_PAD* pad = m_Pcb->m_NetInfo->GetPad(i);
 
         pad->SetZoneSubNet( 0 );
         pad->SetSubNet( 0 );
@@ -308,10 +310,11 @@ void WinEDA_BasePcbFrame::test_connexions( wxDC* DC )
 
 
 /*************************************************************************/
-void WinEDA_BasePcbFrame::test_1_net_connexion( wxDC* DC, int net_code )
+void PCB_BASE_FRAME::test_1_net_connexion( wxDC* DC, int net_code )
 /*************************************************************************/
 
-/** Function testing the connections relative to a given net
+/**
+ * Function testing the connections relative to a given net
  * track segments are assumed to be sorted by net codes
  * @param DC = current Device Context
  * @param net_code = net code to test
@@ -322,12 +325,12 @@ void WinEDA_BasePcbFrame::test_1_net_connexion( wxDC* DC, int net_code )
     if( net_code == 0 )
         return;
 
-    if( (m_Pcb->m_Status_Pcb & LISTE_CHEVELU_OK) == 0 )
+    if( (m_Pcb->m_Status_Pcb & LISTE_RATSNEST_ITEM_OK) == 0 )
         Compile_Ratsnest( DC, TRUE );
 
-    for( unsigned i = 0;  i<m_Pcb->m_Pads.size();  ++i )
+    for( unsigned i = 0;  i<m_Pcb->GetPadsCount();  ++i )
     {
-        D_PAD* pad = m_Pcb->m_Pads[i];
+        D_PAD* pad = m_Pcb->m_NetInfo->GetPad(i);
 
         int    pad_net_code = pad->GetNet();
 
@@ -364,10 +367,10 @@ void WinEDA_BasePcbFrame::test_1_net_connexion( wxDC* DC, int net_code )
 
     /* Display results */
     msg.Printf( wxT( "links %d nc %d  net:nc %d" ),
-                m_Pcb->m_NbLinks, m_Pcb->GetNumNoconnect(),
+                m_Pcb->GetRatsnestsCount(), m_Pcb->GetNoconnectCount(),
                 nb_net_noconnect );
 
-    Affiche_Message( msg );
+    SetStatusText( msg );
     return;
 }
 
@@ -473,7 +476,7 @@ static D_PAD* SuperFast_Locate_Pad_Connecte( BOARD* aPcb, LISTE_PAD* pt_liste,
     D_PAD*     pad;
     int        ii;
 
-    int        nb_pad  = aPcb->m_Pads.size();
+    int        nb_pad  = aPcb->GetPadsCount();
     LISTE_PAD* ptr_pad = pt_liste;
     LISTE_PAD* lim = pt_liste + nb_pad - 1;
 
@@ -556,34 +559,35 @@ static int SortPadsByXCoord( const void* pt_ref, const void* pt_comp )
 void CreateSortedPadListByXCoord( BOARD* aBoard, std::vector<D_PAD*>* aVector )
 /*****************************************************************************/
 {
-    aVector->insert( aVector->end(), aBoard->m_Pads.begin(), aBoard->m_Pads.end() );
+    aVector->insert( aVector->end(), aBoard->m_NetInfo->m_PadsFullList.begin(), aBoard->m_NetInfo->m_PadsFullList.end() );
 
-    qsort( &(*aVector)[0], aBoard->m_Pads.size(), sizeof( D_PAD*), SortPadsByXCoord );
+    qsort( &(*aVector)[0], aBoard->GetPadsCount(), sizeof( D_PAD*), SortPadsByXCoord );
 }
 
 
 /********************************************************************/
-void WinEDA_BasePcbFrame::reattribution_reference_piste( int affiche )
+void PCB_BASE_FRAME::RecalculateAllTracksNetcode()
 /********************************************************************/
 
 /* search connections between tracks and pads, and propagate pad net codes to the track segments
  * This is a 2 pass computation.
- * The pad netcodes are assumed to be initialized.
  * First:
  * We search a connection between a track segment and a pad: if found : this segment  netcode is set to the pad netcode
  */
 {
     TRACK*              pt_piste;
     TRACK*              pt_next;
-    int                 a_color;
-    char                new_passe_request = 1, flag;
+    char                new_passe_request = 1;
 
     std::vector<D_PAD*> sortedPads;
     BOARD_ITEM*         PtStruct;
     int                 masque_layer;
     wxString            msg;
 
-    if( m_Pcb->m_Pads.size() == 0 )     // If no pad, reset pointers and netcode, and do nothing else
+    // Build the net info list
+    GetBoard()->m_NetInfo->BuildListOfNets();
+
+    if( m_Pcb->GetPadsCount() == 0 )     // If no pad, reset pointers and netcode, and do nothing else
     {
         pt_piste = m_Pcb->m_Track;
         for( ; pt_piste != NULL; pt_piste = pt_piste->Next() )
@@ -593,33 +597,19 @@ void WinEDA_BasePcbFrame::reattribution_reference_piste( int affiche )
             pt_piste->SetNet( 0 );
             pt_piste->end = NULL;
         }
-
         return;
     }
 
-    a_color = CYAN;
-
-    if( affiche )
-        Affiche_1_Parametre( this, POS_AFF_CHREF, wxT( "DataBase" ), wxT( "Netcodes" ), a_color );
-
-    recalcule_pad_net_code();
-
-    if( affiche )
-        Affiche_1_Parametre( this, -1, wxEmptyString, wxT( "Gen Pads " ), a_color );
-
     /**************************************************************/
     /* Pass 1: search the connections between track ends and pads */
     /**************************************************************/
     CreateSortedPadListByXCoord( m_Pcb, &sortedPads );
 
-    if( affiche )
-        Affiche_1_Parametre( this, -1, wxEmptyString, wxT( "Conn Pads" ), a_color );
-
     /* Reset variables and flags used in computation */
     pt_piste = m_Pcb->m_Track;
     for( ; pt_piste != NULL; pt_piste = pt_piste->Next() )
     {
-        pt_piste->SetState( BUSY | EDIT | BEGIN_ONPAD | END_ONPAD, OFF );
+        pt_piste->SetState( BUSY | IN_EDIT | BEGIN_ONPAD | END_ONPAD, OFF );
         pt_piste->SetZoneSubNet( 0 );
         pt_piste->SetNet( 0 );  // net code = 0 means not connected
     }
@@ -630,7 +620,6 @@ void WinEDA_BasePcbFrame::reattribution_reference_piste( int affiche )
     pt_piste = m_Pcb->m_Track;
     for( ; pt_piste != NULL; pt_piste = pt_piste->Next() )
     {
-        flag = 0;
         masque_layer = g_TabOneLayerMask[pt_piste->GetLayer()];
 
         /* Search for a pad on the segment starting point */
@@ -667,8 +656,6 @@ void WinEDA_BasePcbFrame::reattribution_reference_piste( int affiche )
      * the connection (if found) is between segments
      * when a track has a net code and the other has a null net code, the null net code is changed
      */
-    if( affiche )
-        Affiche_1_Parametre( this, POS_AFF_CHREF, wxEmptyString, wxT( "Conn Segm" ), a_color );
 
     for( pt_piste = m_Pcb->m_Track; pt_piste != NULL; pt_piste = pt_piste->Next() )
     {
@@ -687,17 +674,10 @@ void WinEDA_BasePcbFrame::reattribution_reference_piste( int affiche )
     /* Propagate net codes from a segment to an other segment */
     /**********************************************************/
 
-    a_color = YELLOW;
-
     while( new_passe_request )
     {
         bool reset_flag = FALSE;
         new_passe_request = 0;
-        if( affiche )
-        {
-            msg.Printf( wxT( "Net->Segm pass %d  " ), new_passe_request + 1 );
-            Affiche_1_Parametre( this, POS_AFF_CHREF, wxEmptyString, msg, a_color );
-        }
 
         /* look for vias which could be connect many tracks */
         for( TRACK* via = m_Pcb->m_Track; via != NULL; via = via->Next() )
@@ -789,12 +769,7 @@ void WinEDA_BasePcbFrame::reattribution_reference_piste( int affiche )
     }
 
     /* Sort the track list by net codes: */
-    if( affiche )
-        Affiche_1_Parametre( this, -1, wxEmptyString, wxT( "Reorder " ), a_color );
     RebuildTrackChain( m_Pcb );
-
-    if( affiche )
-        Affiche_1_Parametre( this, -1, wxEmptyString, wxT( "         " ), a_color );
 }
 
 
