@@ -15,6 +15,7 @@
 #include "3d_viewer.h"
 #include "pcbnew.h"
 #include "wxPcbStruct.h"
+#include "module_editor_frame.h"
 #include "protos.h"
 
 #include "kicad_device_context.h"
@@ -30,6 +31,7 @@ BOARD_ITEM* WinEDA_ModuleEditFrame::ModeditLocateAndDisplay( int aHotKeyCode )
 
     if( GetBoard()->m_Modules == NULL )
         return NULL;
+
     GENERAL_COLLECTORS_GUIDE guide = GetCollectorsGuide();
 
     // Assign to scanList the proper item types desired based on tool type
@@ -107,14 +109,14 @@ BOARD_ITEM* WinEDA_ModuleEditFrame::ModeditLocateAndDisplay( int aHotKeyCode )
         }
 
         // this menu's handler is void
-        // WinEDA_BasePcbFrame::ProcessItemSelection()
+        // PCB_BASE_FRAME::ProcessItemSelection()
         // and it calls SetCurItem() which in turn calls DisplayInfo() on the
         // item.
         DrawPanel->m_AbortRequest = true;   // changed in false if an item
         PopupMenu( &itemMenu );             // m_AbortRequest = false if an
                                             // item is selected
 
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
 
         DrawPanel->m_IgnoreMouseEvents = FALSE;
 
@@ -131,11 +133,24 @@ BOARD_ITEM* WinEDA_ModuleEditFrame::ModeditLocateAndDisplay( int aHotKeyCode )
     return item;
 }
 
-
+/**
+ * Function LoadModuleFromBoard
+ * called from the main toolbar
+ * to load a footprint from board mainly to edit it
+ */
 void WinEDA_ModuleEditFrame::LoadModuleFromBoard( wxCommandEvent& event )
 {
+    if(  GetScreen()->IsModify() )
+    {
+        if( !IsOK( this,
+            _( "Current footprint changes will be lost and this operation cannot be undone. Continue ?" ) ) )
+            return;
+    }
+
+    if( ! Load_Module_From_BOARD( NULL ) )
+        return;
+
     GetScreen()->ClearUndoRedoList();
-    Load_Module_From_BOARD( NULL );
     GetScreen()->ClrModify();
 
     if( m_Draw3DFrame )
@@ -149,7 +164,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     wxPoint    pos;
     bool       redraw = false;
 
-    INSTALL_DC( dc, DrawPanel );
+    INSTALL_UNBUFFERED_DC( dc, DrawPanel );
 
     wxGetMousePosition( &pos.x, &pos.y );
 
@@ -188,13 +203,15 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
 
     case ID_POPUP_CANCEL_CURRENT_COMMAND:
     default:
-        if( DrawPanel->ManageCurseur && DrawPanel->ForceCloseManageCurseur )
+        if( DrawPanel->IsMouseCaptured() )
         {
             //  for all other commands: stop the move in progress
-            DrawPanel->ForceCloseManageCurseur( DrawPanel, &dc );
+            DrawPanel->m_endMouseCaptureCallback( DrawPanel, &dc );
         }
+
         if( id != ID_POPUP_CANCEL_CURRENT_COMMAND )
-            SetToolID( 0, wxCURSOR_ARROW, wxEmptyString );
+            SetToolID( ID_NO_TOOL_SELECTED, DrawPanel->GetDefaultCursor(), wxEmptyString );
+
         break;
     }
 
@@ -223,9 +240,10 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         Clear_Pcb( true );
         GetScreen()->ClearUndoRedoList();
         SetCurItem( NULL );
-        GetScreen()->m_Curseur = wxPoint( 0, 0 );
+        GetScreen()->SetCrossHairPosition( wxPoint( 0, 0 ) );
+
+        MODULE* module = Create_1_Module( wxEmptyString );
 
-        MODULE* module = Create_1_Module( NULL, wxEmptyString );
         if( module )        // i.e. if create module command not aborted
         {
             // Initialize data relative to nets and netclasses (for a new
@@ -236,7 +254,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
             module->SetPosition( wxPoint( 0, 0 ) );
             if( GetBoard()->m_Modules )
                 GetBoard()->m_Modules->m_Flags = 0;
-            Zoom_Automatique( true );
+            Zoom_Automatique( false );
         }
         break;
     }
@@ -246,8 +264,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         wxFileName fn;
         fn = wxFileName( wxEmptyString, m_CurrentLib, ModuleFileExtension );
         wxString   full_filename = wxGetApp().FindLibraryPath( fn );
-        Save_Module_In_Library( full_filename, GetBoard()->m_Modules,
-                                true, true, true );
+        Save_Module_In_Library( full_filename, GetBoard()->m_Modules, true, true );
         GetScreen()->ClrModify();
         break;
     }
@@ -257,10 +274,10 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     {
         // update module in the current board,
         // not just add it to the board with total disregard for the netlist...
-        WinEDA_PcbFrame* pcbframe = (WinEDA_PcbFrame*) GetParent();
-        BOARD*           mainpcb  = pcbframe->GetBoard();
-        MODULE*          source_module  = NULL;
-        MODULE*          module_in_edit = GetBoard()->m_Modules;
+        PCB_EDIT_FRAME* pcbframe = (PCB_EDIT_FRAME*) GetParent();
+        BOARD*          mainpcb  = pcbframe->GetBoard();
+        MODULE*         source_module  = NULL;
+        MODULE*         module_in_edit = GetBoard()->m_Modules;
 
         // Search the old module (source) if exists
         // Because this source could be deleted when editing the main board...
@@ -317,10 +334,10 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         }
         else        // This is an insert command
         {
-            wxPoint cursor_pos = pcbframe->GetScreen()->m_Curseur;
-            pcbframe->GetScreen()->m_Curseur = wxPoint( 0, 0 );
+            wxPoint cursor_pos = pcbframe->GetScreen()->GetCrossHairPosition();
+            pcbframe->GetScreen()->SetCrossHairPosition( wxPoint( 0, 0 ) );
             pcbframe->Place_Module( newmodule, NULL );
-            pcbframe->GetScreen()->m_Curseur = cursor_pos;
+            pcbframe->GetScreen()->SetCrossHairPosition( cursor_pos );
             newmodule->m_TimeStamp = GetTimeStamp();
             pcbframe->SaveCopyInUndoList( newmodule, UR_NEW );
         }
@@ -333,16 +350,17 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     break;
 
     case ID_MODEDIT_IMPORT_PART:
+        if( ! Clear_Pcb( true ) )
+            break;                  // //this command is aborted
         GetScreen()->ClearUndoRedoList();
         SetCurItem( NULL );
-        Clear_Pcb( true );
-        GetScreen()->m_Curseur = wxPoint( 0, 0 );
-        Import_Module( NULL );
+        GetScreen()->SetCrossHairPosition( wxPoint( 0, 0 ) );
+        Import_Module( );
         redraw = true;
         if( GetBoard()->m_Modules )
             GetBoard()->m_Modules->m_Flags = 0;
         GetScreen()->ClrModify();
-        Zoom_Automatique( true );
+        Zoom_Automatique( false );
         if( m_Draw3DFrame )
             m_Draw3DFrame->NewDisplay();
         break;
@@ -363,20 +381,21 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     case ID_MODEDIT_LOAD_MODULE:
     {
         wxString full_libraryfilename;
+
         if( !m_CurrentLib.IsEmpty() )
         {
-            wxFileName fn = wxFileName( wxEmptyString, m_CurrentLib,
-                                        ModuleFileExtension );
+            wxFileName fn = wxFileName( wxEmptyString, m_CurrentLib, ModuleFileExtension );
             full_libraryfilename = wxGetApp().FindLibraryPath( fn );
         }
 
         GetScreen()->ClearUndoRedoList();
         SetCurItem( NULL );
         Clear_Pcb( true );
-        GetScreen()->m_Curseur = wxPoint( 0, 0 );
+        GetScreen()->SetCrossHairPosition( wxPoint( 0, 0 ) );
         Load_Module_From_Library( full_libraryfilename, NULL );
         redraw = true;
     }
+
         if( GetBoard()->m_Modules )
             GetBoard()->m_Modules->m_Flags = 0;
 
@@ -397,7 +416,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
             }
         }
         GetScreen()->ClrModify();
-        Zoom_Automatique( true );
+        Zoom_Automatique( false );
         if( m_Draw3DFrame )
             m_Draw3DFrame->NewDisplay();
         break;
@@ -423,50 +442,20 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         }
         break;
 
-    case ID_MODEDIT_ADD_PAD:
-        if( GetBoard()->m_Modules )
-            SetToolID( id, wxCURSOR_PENCIL, _( "Add Pad" ) );
-        else
-        {
-            SetToolID( id, wxCURSOR_ARROW, _( "Pad Settings" ) );
-            InstallPadOptionsFrame( NULL );
-            SetToolID( 0, wxCURSOR_ARROW, wxEmptyString );
-        }
-        break;
-
-    case ID_PCB_ADD_LINE_BUTT:
-    case ID_PCB_ARC_BUTT:
-    case ID_PCB_CIRCLE_BUTT:
-    case ID_PCB_ADD_TEXT_BUTT:
-        SetToolID( id, wxCURSOR_PENCIL, _( "Add Drawing" ) );
-        break;
-
-    case ID_MODEDIT_PLACE_ANCHOR:
-        SetToolID( id, wxCURSOR_PENCIL, _( "Place anchor" ) );
-        break;
-
-    case ID_NO_SELECT_BUTT:
-        SetToolID( 0, wxCURSOR_ARROW, wxEmptyString );
-        break;
-
     case ID_POPUP_CLOSE_CURRENT_TOOL:
         break;
 
     case ID_POPUP_CANCEL_CURRENT_COMMAND:
         break;
 
-    case ID_MODEDIT_DELETE_ITEM_BUTT:
-        SetToolID( id, wxCURSOR_BULLSEYE, _( "Delete item" ) );
-        break;
-
     case ID_POPUP_PCB_ROTATE_MODULE_COUNTERCLOCKWISE:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Rotate_Module( NULL, (MODULE*) GetScreen()->GetCurItem(), 900, true );
         redraw = true;
         break;
 
     case ID_POPUP_PCB_ROTATE_MODULE_CLOCKWISE:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Rotate_Module( NULL, (MODULE*) GetScreen()->GetCurItem(), -900, true );
         redraw = true;
         break;
@@ -478,7 +467,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         int ret = dialog.ShowModal();
         GetScreen()->GetCurItem()->m_Flags = 0;
         GetScreen()->GetCurItem()->m_Flags = 0;
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         if( ret > 0 )
             DrawPanel->Refresh();
     }
@@ -486,7 +475,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
 
     case ID_POPUP_PCB_MOVE_PAD_REQUEST:
     {
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         StartMovePad( (D_PAD*) GetScreen()->GetCurItem(), &dc );
     }
     break;
@@ -494,31 +483,31 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     case ID_POPUP_PCB_EDIT_PAD:
     {
         InstallPadOptionsFrame( (D_PAD*) GetScreen()->GetCurItem() );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
     }
     break;
 
     case ID_POPUP_PCB_DELETE_PAD:
         SaveCopyInUndoList( GetBoard()->m_Modules, UR_MODEDIT );
-        DeletePad( (D_PAD*) GetScreen()->GetCurItem() );
+        DeletePad( (D_PAD*) GetScreen()->GetCurItem(), false );
         SetCurItem( NULL );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         break;
 
     case ID_POPUP_PCB_IMPORT_PAD_SETTINGS:
         SaveCopyInUndoList( GetBoard()->m_Modules, UR_MODEDIT );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Import_Pad_Settings( (D_PAD*) GetScreen()->GetCurItem(), true );
         break;
 
     case ID_POPUP_PCB_GLOBAL_IMPORT_PAD_SETTINGS:
         SaveCopyInUndoList( GetBoard()->m_Modules, UR_MODEDIT );
         Global_Import_Pad_Settings( (D_PAD*) GetScreen()->GetCurItem(), true );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         break;
 
     case ID_POPUP_PCB_EXPORT_PAD_SETTINGS:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Export_Pad_Settings( (D_PAD*) GetScreen()->GetCurItem() );
         break;
 
@@ -526,13 +515,13 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     {
         InstallTextModOptionsFrame(
              (TEXTE_MODULE*) GetScreen()->GetCurItem(), &dc );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
     }
     break;
 
     case ID_POPUP_PCB_MOVE_TEXTMODULE_REQUEST:
     {
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         StartMoveTexteModule( (TEXTE_MODULE*) GetScreen()->GetCurItem(), &dc );
     }
     break;
@@ -540,7 +529,7 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     case ID_POPUP_PCB_ROTATE_TEXTMODULE:
     {
         RotateTextModule( (TEXTE_MODULE*) GetScreen()->GetCurItem(), &dc );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
     }
     break;
 
@@ -548,21 +537,21 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         SaveCopyInUndoList( GetBoard()->m_Modules, UR_MODEDIT );
         DeleteTextModule( (TEXTE_MODULE*) GetScreen()->GetCurItem() );
         SetCurItem( NULL );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         break;
 
     case ID_POPUP_PCB_MOVE_EDGE:
     {
         Start_Move_EdgeMod( (EDGE_MODULE*) GetScreen()->GetCurItem(), &dc );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
     }
     break;
 
     case ID_POPUP_PCB_STOP_CURRENT_DRAWING:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         if( (GetScreen()->GetCurItem()->m_Flags & IS_NEW) )
         {
-            End_Edge_Module( (EDGE_MODULE*) GetScreen()->GetCurItem(), &dc );
+            End_Edge_Module( (EDGE_MODULE*) GetScreen()->GetCurItem() );
             SetCurItem( NULL );
         }
         break;
@@ -571,39 +560,45 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
     {
         EDGE_MODULE* edge = NULL;
         if( GetScreen()->GetCurItem()
-           && ( GetScreen()->GetCurItem()->m_Flags & IS_NEW )
            && ( GetScreen()->GetCurItem()->Type() == TYPE_EDGE_MODULE ) )
         {
             edge = (EDGE_MODULE*) GetScreen()->GetCurItem();
         }
-        Enter_Edge_Width( edge, &dc );
-        DrawPanel->MouseToCursorSchema();
+        Enter_Edge_Width( edge );
+        DrawPanel->MoveCursorToCrossHair();
+        if( edge )
+            DrawPanel->Refresh();
+
     }
     break;
 
     case ID_POPUP_PCB_EDIT_WIDTH_CURRENT_EDGE:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Edit_Edge_Width( (EDGE_MODULE*) GetScreen()->GetCurItem() );
+        DrawPanel->Refresh( );
         break;
 
     case ID_POPUP_PCB_EDIT_WIDTH_ALL_EDGE:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Edit_Edge_Width( NULL );
+        DrawPanel->Refresh( );
         break;
 
     case ID_POPUP_PCB_EDIT_LAYER_CURRENT_EDGE:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Edit_Edge_Layer( (EDGE_MODULE*) GetScreen()->GetCurItem() );
+        DrawPanel->Refresh( );
         break;
 
     case ID_POPUP_PCB_EDIT_LAYER_ALL_EDGE:
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         Edit_Edge_Layer( NULL );
+        DrawPanel->Refresh( );
         break;
 
     case ID_POPUP_PCB_DELETE_EDGE:
         SaveCopyInUndoList( GetBoard()->m_Modules, UR_MODEDIT );
-        DrawPanel->MouseToCursorSchema();
+        DrawPanel->MoveCursorToCrossHair();
         RemoveStruct( GetScreen()->GetCurItem() );
         SetCurItem( NULL );
         break;
@@ -678,7 +673,6 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
         break;
     }
 
-    SetToolbars();
     if( redraw )
         DrawPanel->Refresh();
 }
@@ -692,11 +686,11 @@ void WinEDA_ModuleEditFrame::Process_Special_Functions( wxCommandEvent& event )
  */
 void WinEDA_ModuleEditFrame::Transform( MODULE* module, int transform )
 {
-    D_PAD*          pad = module->m_Pads;
-    EDA_BaseStruct* PtStruct = module->m_Drawings;
-    TEXTE_MODULE*   textmod;
-    EDGE_MODULE*    edgemod;
-    int             angle = 900; // Necessary +- 900 (+- 90 degrees) )
+    D_PAD*        pad = module->m_Pads;
+    EDA_ITEM*     PtStruct = module->m_Drawings;
+    TEXTE_MODULE* textmod;
+    EDGE_MODULE*  edgemod;
+    int           angle = 900; // Necessary +- 900 (+- 90 degrees) )
 
     switch( transform )
     {
@@ -777,6 +771,7 @@ void WinEDA_ModuleEditFrame::Transform( MODULE* module, int transform )
                 /* Invert local coordinates */
                 NEGATE( edgemod->m_Start0.y );
                 NEGATE( edgemod->m_End0.y );
+                NEGATE( edgemod->m_Angle );
                 break;
 
             case TYPE_TEXTE_MODULE:
@@ -802,4 +797,62 @@ void WinEDA_ModuleEditFrame::Transform( MODULE* module, int transform )
     }
 
     module->Set_Rectangle_Encadrement();
+    OnModify();
+}
+
+
+void WinEDA_ModuleEditFrame::OnVerticalToolbar( wxCommandEvent& aEvent )
+{
+    int id = aEvent.GetId();
+
+    SetToolID( ID_NO_TOOL_SELECTED, DrawPanel->GetDefaultCursor(), wxEmptyString );
+
+    switch( id )
+    {
+    case ID_NO_TOOL_SELECTED:
+        break;
+
+    case ID_MODEDIT_LINE_TOOL:
+        SetToolID( id, wxCURSOR_PENCIL, _( "Add line" ) );
+        break;
+
+    case ID_MODEDIT_ARC_TOOL:
+        SetToolID( id, wxCURSOR_PENCIL, _( "Add arc" ) );
+        break;
+
+    case ID_MODEDIT_CIRCLE_TOOL:
+        SetToolID( id, wxCURSOR_PENCIL, _( "Add circle" ) );
+        break;
+
+    case ID_MODEDIT_TEXT_TOOL:
+        SetToolID( id, wxCURSOR_PENCIL, _( "Add text" ) );
+        break;
+
+    case ID_MODEDIT_ANCHOR_TOOL:
+        SetToolID( id, wxCURSOR_PENCIL, _( "Place anchor" ) );
+        break;
+
+    case ID_MODEDIT_PLACE_GRID_COORD:
+        SetToolID( id, wxCURSOR_PENCIL, _( "Set grid origin" ) );
+        break;
+
+    case ID_MODEDIT_PAD_TOOL:
+        if( GetBoard()->m_Modules )
+            SetToolID( id, wxCURSOR_PENCIL, _( "Add pad" ) );
+        else
+        {
+            SetToolID( id, wxCURSOR_ARROW, _( "Pad settings" ) );
+            InstallPadOptionsFrame( NULL );
+            SetToolID( ID_NO_TOOL_SELECTED, DrawPanel->GetDefaultCursor(), wxEmptyString );
+        }
+        break;
+
+    case ID_MODEDIT_DELETE_TOOL:
+        SetToolID( id, wxCURSOR_BULLSEYE, _( "Delete item" ) );
+        break;
+
+    default:
+        wxFAIL_MSG( wxT( "Unknown command id." ) );
+        SetToolID( ID_NO_TOOL_SELECTED, DrawPanel->GetDefaultCursor(), wxEmptyString );
+    }
 }
