@@ -9,6 +9,7 @@
 
 #include "pcbnew.h"
 #include "wxPcbStruct.h"
+#include "module_editor_frame.h"
 
 #include "pcbnew_id.h"
 
@@ -21,31 +22,6 @@ void WinEDA_ModuleEditFrame::OnSelectOptionToolbar( wxCommandEvent& event )
 
     switch( id )
     {
-    case ID_TB_OPTIONS_SHOW_GRID:
-        SetGridVisibility( m_OptionsToolBar->GetToolState( id ) );
-        DrawPanel->Refresh( );
-        break;
-
-    case ID_TB_OPTIONS_SELECT_UNIT_MM:
-        g_UnitMetric = MILLIMETRE;
-
-    case ID_TB_OPTIONS_SELECT_UNIT_INCH:
-        if( id == ID_TB_OPTIONS_SELECT_UNIT_INCH )
-            g_UnitMetric = INCHES;
-        UpdateStatusBar();
-        ReCreateAuxiliaryToolbar();
-        break;
-
-    case ID_TB_OPTIONS_SHOW_POLAR_COORD:
-        Affiche_Message( wxEmptyString );
-        DisplayOpt.DisplayPolarCood = m_OptionsToolBar->GetToolState( id );
-        UpdateStatusBar();
-        break;
-
-    case ID_TB_OPTIONS_SELECT_CURSOR:
-        m_CursorShape = m_OptionsToolBar->GetToolState( id );
-        break;
-
     case ID_TB_OPTIONS_SHOW_PADS_SKETCH:
         m_DisplayPadFill = !m_OptionsToolBar->GetToolState( id );
         DrawPanel->Refresh( );
@@ -73,6 +49,4 @@ void WinEDA_ModuleEditFrame::OnSelectOptionToolbar( wxCommandEvent& event )
                       wxT( "WinEDA_ModuleEditFrame::OnSelectOptionToolbar error" ) );
         break;
     }
-
-    SetToolbars();
 }
