@@ -23,14 +23,12 @@
 static wxMenu* Append_Track_Width_List( BOARD* aBoard );
 
 
-/******************************************************************************/
-bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
-/******************************************************************************/
+bool PCB_EDIT_FRAME::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
 {
     wxString    msg;
     int         flags = 0;
     bool        locate_track = FALSE;
-    bool        BlockActive  = (GetScreen()->m_BlockLocate.m_Command != BLOCK_IDLE);
+    bool        blockActive  = (GetScreen()->m_BlockLocate.m_Command != BLOCK_IDLE);
 
     wxClientDC  dc( DrawPanel );
 
@@ -42,27 +40,27 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
     // If a command or a block is in progress:
     // Put the Cancel command (if needed) and the End command
 
-    if( BlockActive )
+    if( blockActive )
     {
         createPopUpBlockMenu( aPopMenu );
         aPopMenu->AppendSeparator();
         return true;
     }
 
-    DrawPanel->CursorOff( &dc );
+    DrawPanel->CrossHairOff( &dc );
 
-    if( m_ID_current_state )
+    if( GetToolId() != ID_NO_TOOL_SELECTED )
     {
         if( item && item->m_Flags )
         {
-            ADD_MENUITEM( aPopMenu, ID_POPUP_CANCEL_CURRENT_COMMAND,
-                          _( "Cancel" ), cancel_xpm );
+            ADD_MENUITEM( aPopMenu, ID_POPUP_CANCEL_CURRENT_COMMAND, _( "Cancel" ), cancel_xpm );
         }
         else
         {
             ADD_MENUITEM( aPopMenu, ID_POPUP_CLOSE_CURRENT_TOOL,
                           _( "End Tool" ), cancel_tool_xpm );
         }
+
         aPopMenu->AppendSeparator();
     }
     else
@@ -75,13 +73,12 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         }
     }
 
-
     /* Select a proper item */
 
-    wxPoint cursorPos = GetScreen()->m_Curseur;
+    wxPoint cursorPos = GetScreen()->GetCrossHairPosition();
     wxPoint selectPos = m_Collector->GetRefPos();
 
-    PutOnGrid( &selectPos );
+    selectPos = GetScreen()->GetNearestGridPosition( selectPos );
 
     /*  We can reselect another item only if there are no item being edited
      * because ALL moving functions use GetCurItem(), therefore GetCurItem()
@@ -99,9 +96,10 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         {
             DrawPanel->m_AbortRequest = false;
             item = PcbGeneralLocateAndDisplay();
+
             if( DrawPanel->m_AbortRequest )
             {
-                DrawPanel->CursorOn( &dc );
+                DrawPanel->CrossHairOn( &dc );
                 return false;
             }
         }
@@ -120,22 +118,20 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         case TYPE_MODULE:
             createPopUpMenuForFootprints( (MODULE*) item, aPopMenu );
 
-            if( m_HTOOL_current_state == ID_TOOLBARH_PCB_AUTOPLACE )
+            if( m_HTOOL_current_state == ID_TOOLBARH_PCB_MODE_MODULE )
             {
                 aPopMenu->AppendSeparator();
 
                 if( !( (MODULE*) item )->IsLocked() )
                 {
-                    msg = AddHotkeyName( _(
-                                             "Lock Module" ), s_Board_Editor_Hokeys_Descr,
+                    msg = AddHotkeyName( _("Lock Module" ), g_Board_Editor_Hokeys_Descr,
                                          HK_LOCK_UNLOCK_FOOTPRINT );
                     ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_AUTOPLACE_FIXE_MODULE, msg,
                                   locked_xpm );
                 }
                 else
                 {
-                    msg = AddHotkeyName( _(
-                                             "Unlock Module" ), s_Board_Editor_Hokeys_Descr,
+                    msg = AddHotkeyName( _( "Unlock Module" ), g_Board_Editor_Hokeys_Descr,
                                          HK_LOCK_UNLOCK_FOOTPRINT );
                     ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_AUTOPLACE_FREE_MODULE, msg,
                                   unlocked_xpm );
@@ -143,10 +139,10 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
 
                 if( !flags )
                     aPopMenu->Append( ID_POPUP_PCB_AUTOPLACE_CURRENT_MODULE,
-                                     _( "Auto Place Module" ) );
+                                      _( "Auto Place Module" ) );
             }
 
-            if( m_HTOOL_current_state == ID_TOOLBARH_PCB_AUTOROUTE )
+            if( m_HTOOL_current_state == ID_TOOLBARH_PCB_MODE_TRACKS )
             {
                 if( !flags )
                     aPopMenu->Append( ID_POPUP_PCB_AUTOROUTE_MODULE, _( "Autoroute Module" ) );
@@ -167,13 +163,17 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
                 ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_STOP_CURRENT_DRAWING,
                               _( "End Drawing" ), apply_xpm );
             }
+
             if( !flags )
             {
+                msg = AddHotkeyName( _( "Move Drawing" ), g_Board_Editor_Hokeys_Descr,
+                                     HK_MOVE_ITEM );
                 ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_MOVE_DRAWING_REQUEST,
-                              _( "Move Drawing" ), move_xpm );
+                              msg, move_xpm );
                 ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_EDIT_DRAWING, _( "Edit Drawing" ), edit_xpm );
                 ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_DELETE_DRAWING, _(
                                   "Delete Drawing" ), delete_xpm );
+
                 if( item->GetLayer() > LAST_COPPER_LAYER )
                     ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_DELETE_DRAWING_LAYER,
                                   _( "Delete All Drawing on Layer" ), delete_body_xpm );
@@ -214,8 +214,9 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         case TYPE_DIMENSION:
             if( !flags )
             {
-                ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_EDIT_DIMENSION,
-                              _( "Edit Dimension" ), edit_xpm );
+                msg = AddHotkeyName( _( "Edit Dimension" ), g_Board_Editor_Hokeys_Descr,
+                                     HK_EDIT_ITEM );
+                ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_EDIT_DIMENSION, msg, edit_xpm );
                 ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_DELETE_DIMENSION,
                               _( "Delete Dimension" ), delete_xpm );
             }
@@ -224,10 +225,12 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         case TYPE_MIRE:
             if( !flags )
             {
-                ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_MOVE_MIRE_REQUEST,
-                              _( "Move Target" ), move_xpm );
-                ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_EDIT_MIRE,
-                              _( "Edit Target" ), edit_xpm );
+                msg = AddHotkeyName( _( "Move Target" ), g_Board_Editor_Hokeys_Descr,
+                                     HK_MOVE_ITEM );
+                ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_MOVE_MIRE_REQUEST, msg, move_xpm );
+                msg = AddHotkeyName( _( "Edit Target" ), g_Board_Editor_Hokeys_Descr,
+                                     HK_EDIT_ITEM );
+                ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_EDIT_MIRE, msg, edit_xpm );
                 ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_DELETE_MIRE,
                               _( "Delete Target" ), delete_xpm );
             }
@@ -238,7 +241,7 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         case TYPE_NOT_INIT:
         case TYPE_PCB:
             msg.Printf(
-                wxT( "WinEDA_PcbFrame::OnRightClick() Error: unexpected DrawType %d" ),
+                wxT( "PCB_EDIT_FRAME::OnRightClick() Error: unexpected DrawType %d" ),
                 item->Type() );
             DisplayError( this, msg );
             SetCurItem( NULL );
@@ -246,7 +249,7 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
 
         default:
             msg.Printf(
-                wxT( "WinEDA_PcbFrame::OnRightClick() Error: unknown DrawType %d" ),
+                wxT( "PCB_EDIT_FRAME::OnRightClick() Error: unknown DrawType %d" ),
                 item->Type() );
             DisplayError( this, msg );
 
@@ -262,13 +265,13 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
     if( !flags )
     {
         msg = AddHotkeyName( _( "Get and Move Footprint" ),
-                             s_Board_Editor_Hokeys_Descr, HK_GET_AND_MOVE_FOOTPRINT );
+                             g_Board_Editor_Hokeys_Descr, HK_GET_AND_MOVE_FOOTPRINT );
         ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_GET_AND_MOVE_MODULE_REQUEST,
                       msg, move_module_xpm );
     }
 
     /* Display context sensitive comands: */
-    switch(  m_ID_current_state )
+    switch(  GetToolId() )
     {
     case ID_PCB_ZONES_BUTT:
         if(  GetBoard()->m_ZoneDescriptorList.size() > 0 )
@@ -308,19 +311,18 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         aPopMenu->AppendSeparator();
         break;
 
-    case ID_COMPONENT_BUTT:
+    case ID_PCB_MODULE_BUTT:
         ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_DISPLAY_FOOTPRINT_DOC,
                       _( "Footprint Documentation" ), book_xpm );
         aPopMenu->AppendSeparator();
         break;
 
-    case 0:
-        if( m_HTOOL_current_state == ID_TOOLBARH_PCB_AUTOPLACE )
+    case ID_NO_TOOL_SELECTED:
+        if( m_HTOOL_current_state == ID_TOOLBARH_PCB_MODE_MODULE )
         {
             wxMenu* commands = new wxMenu;
-            ADD_MENUITEM_WITH_SUBMENU( aPopMenu, commands,
-                                       ID_POPUP_PCB_AUTOPLACE_COMMANDS, _(
-                                           "Glob Move and Place" ), move_xpm );
+            ADD_MENUITEM_WITH_SUBMENU( aPopMenu, commands, ID_POPUP_PCB_AUTOPLACE_COMMANDS,
+                                       _( "Glob Move and Place" ), move_xpm );
             ADD_MENUITEM( commands, ID_POPUP_PCB_AUTOPLACE_FREE_ALL_MODULES,
                           _( "Unlock All Modules" ), unlocked_xpm );
             ADD_MENUITEM( commands, ID_POPUP_PCB_AUTOPLACE_FIXE_ALL_MODULES,
@@ -339,7 +341,7 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
             aPopMenu->AppendSeparator();
         }
 
-        if( m_HTOOL_current_state == ID_TOOLBARH_PCB_AUTOROUTE )
+        if( m_HTOOL_current_state == ID_TOOLBARH_PCB_MODE_TRACKS )
         {
             wxMenu* commands = new wxMenu;
             aPopMenu->Append( ID_POPUP_PCB_AUTOROUTE_COMMANDS, _( "Autoroute" ), commands );
@@ -362,52 +364,40 @@ bool WinEDA_PcbFrame::OnRightClick( const wxPoint& aMousePos, wxMenu* aPopMenu )
         break;
     }
 
-    DrawPanel->CursorOn( &dc );
+    DrawPanel->CrossHairOn( &dc );
     return true;
 }
 
 
-/*********************************************************/
-void WinEDA_PcbFrame::createPopUpBlockMenu( wxMenu* menu )
-/*********************************************************/
-
 /* Create Pop sub menu for block commands
  */
+void PCB_EDIT_FRAME::createPopUpBlockMenu( wxMenu* menu )
 {
-    ADD_MENUITEM( menu, ID_POPUP_CANCEL_CURRENT_COMMAND,
-                  _( "Cancel Block" ), cancel_xpm );
-    ADD_MENUITEM( menu, ID_POPUP_ZOOM_BLOCK,
-                  _( "Zoom Block" ), zoom_selected_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_CANCEL_CURRENT_COMMAND, _( "Cancel Block" ), cancel_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_ZOOM_BLOCK, _( "Zoom Block" ), zoom_area_xpm );
     menu->AppendSeparator();
-    ADD_MENUITEM( menu, ID_POPUP_PLACE_BLOCK,
-                  _( "Place Block" ), apply_xpm );
-    ADD_MENUITEM( menu, ID_POPUP_COPY_BLOCK,
-                  _( "Copy Block" ), copyblock_xpm );
-    ADD_MENUITEM( menu, ID_POPUP_FLIP_BLOCK,
-                  _( "Flip Block" ), invert_module_xpm );
-    ADD_MENUITEM( menu, ID_POPUP_ROTATE_BLOCK,
-                  _( "Rotate Block" ), rotate_pos_xpm );
-    ADD_MENUITEM( menu, ID_POPUP_DELETE_BLOCK,
-                  _( "Delete Block" ), delete_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_PLACE_BLOCK, _( "Place Block" ), apply_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_COPY_BLOCK, _( "Copy Block" ), copyblock_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_FLIP_BLOCK, _( "Flip Block" ), invert_module_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_ROTATE_BLOCK, _( "Rotate Block" ), rotate_CCW_xpm );
+    ADD_MENUITEM( menu, ID_POPUP_DELETE_BLOCK, _( "Delete Block" ), delete_xpm );
 }
 
 
-/******************************************************************************/
-void WinEDA_PcbFrame::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
-/******************************************************************************/
-
 /* Create command lines for a popup menu, for track and via editing
  * also update Netclass selection
  */
+void PCB_EDIT_FRAME::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
 {
-    wxPoint  cursorPosition = GetScreen()->m_Curseur;
+    wxPoint  cursorPosition = GetScreen()->GetCrossHairPosition();
     wxString msg;
 
     GetBoard()->SetCurrentNetClass( Track->GetNetClassName() );
-    m_TrackAndViasSizesList_Changed = true;
-    AuxiliaryToolBar_Update_UI();
+    updateTraceWidthSelectBox();
+    updateViaSizeSelectBox();
 
     int flags = Track->m_Flags;
+
     if( flags == 0 )
     {
         if( Track->Type() == TYPE_VIA )
@@ -418,15 +408,18 @@ void WinEDA_PcbFrame::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
         {
             if( Track->IsPointOnEnds( cursorPosition, -1 ) != 0 )
             {
+                msg = AddHotkeyName( _( "Move Node" ), g_Board_Editor_Hokeys_Descr, HK_MOVE_ITEM );
                 ADD_MENUITEM( PopMenu, ID_POPUP_PCB_MOVE_TRACK_NODE,
-                              _( "Move Node" ), move_xpm );
+                              msg, move_xpm );
             }
             else
             {
                 ADD_MENUITEM( PopMenu, ID_POPUP_PCB_DRAG_TRACK_SEGMENT_KEEP_SLOPE,
                               _( "Drag Segments, Keep Slope" ), drag_segment_withslope_xpm );
+                msg = AddHotkeyName( _( "Drag Segment" ), g_Board_Editor_Hokeys_Descr,
+                                     HK_DRAG_ITEM );
                 ADD_MENUITEM( PopMenu, ID_POPUP_PCB_DRAG_TRACK_SEGMENT,
-                              _( "Drag Segment" ), drag_track_segment_xpm );
+                              msg, drag_track_segment_xpm );
                 ADD_MENUITEM( PopMenu, ID_POPUP_PCB_BREAK_TRACK,
                               _( "Break Track" ), break_line_xpm );
             }
@@ -442,17 +435,20 @@ void WinEDA_PcbFrame::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
     {
         if( flags & IS_NEW )
         {
-            msg = AddHotkeyName( _( "End Track" ), s_Board_Editor_Hokeys_Descr, HK_END_TRACK );
+            msg = AddHotkeyName( _( "End Track" ), g_Board_Editor_Hokeys_Descr, HK_END_TRACK );
             ADD_MENUITEM( PopMenu, ID_POPUP_PCB_END_TRACK, msg, apply_xpm );
         }
-        msg = AddHotkeyName( _( "Place Via" ), s_Board_Editor_Hokeys_Descr, HK_ADD_VIA );
+        msg = AddHotkeyName( _( "Place Via" ), g_Board_Editor_Hokeys_Descr, HK_ADD_VIA );
         PopMenu->Append( ID_POPUP_PCB_PLACE_VIA, msg );
 
+        msg = AddHotkeyName( _( "Switch Track Posture" ), g_Board_Editor_Hokeys_Descr,
+                             HK_SWITCH_TRACK_POSTURE );
+        PopMenu->Append( ID_POPUP_PCB_SWITCH_TRACK_POSTURE, msg );
+
         // See if we can place a Micro Via (4 or more layers, and start from an external layer):
         if( IsMicroViaAcceptable() )
         {
-            msg = AddHotkeyName( _(
-                                     "Place Micro Via" ), s_Board_Editor_Hokeys_Descr,
+            msg = AddHotkeyName( _( "Place Micro Via" ), g_Board_Editor_Hokeys_Descr,
                                  HK_ADD_MICROVIA );
             PopMenu->Append( ID_POPUP_PCB_PLACE_MICROVIA, msg );
         }
@@ -463,52 +459,53 @@ void WinEDA_PcbFrame::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
     {
         if( Track->Type() == TYPE_VIA )
         {
-            ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_TRACKSEG, _(
-                              "Change Via Size and Drill" ), width_segment_xpm );
+            msg = AddHotkeyName( _( "Change Via Size and Drill" ), g_Board_Editor_Hokeys_Descr,
+                                 HK_EDIT_ITEM );
+            ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_TRACKSEG, msg, width_segment_xpm );
         }
         else
         {
-            ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_TRACKSEG, _(
-                              "Change Segment Width" ), width_segment_xpm );
+            msg = AddHotkeyName( _( "Change Segment Width" ), g_Board_Editor_Hokeys_Descr,
+                                 HK_EDIT_ITEM );
+            ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_TRACKSEG, msg, width_segment_xpm );
             ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_TRACK,
                           _( "Change Track Width" ), width_track_xpm );
         }
-        ADD_MENUITEM_WITH_SUBMENU( PopMenu, Append_Track_Width_List( GetBoard() ),
-                                   ID_POPUP_PCB_SELECT_WIDTH,
-                                   _( "Select Track Width" ), width_track_xpm );
-        PopMenu->AppendSeparator();
-        ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_ALL_VIAS_AND_TRACK_SIZE,
-                      _( "Global Tracks and Vias Edition" ), width_track_via_xpm );
-        PopMenu->AppendSeparator();
     }
 
-    else    // Allows switching to an other track/via size when routing
-    {
-        ADD_MENUITEM_WITH_SUBMENU( PopMenu, Append_Track_Width_List( GetBoard() ),
-                                   ID_POPUP_PCB_SELECT_WIDTH,
-                                   _( "Select Track Width" ), width_track_xpm );
-        PopMenu->AppendSeparator();
-    }
+    // Allows switching to an other track/via size when routing
+    ADD_MENUITEM_WITH_SUBMENU( PopMenu, Append_Track_Width_List( GetBoard() ),
+                               ID_POPUP_PCB_SELECT_WIDTH,
+                               _( "Select Track Width" ), width_track_xpm );
 
     // Delete control:
+    PopMenu->AppendSeparator();
     wxMenu* track_mnu = new wxMenu;
-    ADD_MENUITEM_WITH_SUBMENU( PopMenu, track_mnu,
-                               ID_POPUP_PCB_DELETE_TRACK_MNU, _( "Delete" ), delete_xpm );
+    ADD_MENUITEM_WITH_SUBMENU( PopMenu, track_mnu, ID_POPUP_PCB_DELETE_TRACK_MNU,
+                               _( "Delete" ), delete_xpm );
 
     msg = AddHotkeyName( Track->Type()==TYPE_VIA ?
                         _( "Delete Via" ) : _( "Delete Segment" ),
-                         s_Board_Editor_Hokeys_Descr, HK_BACK_SPACE );
+                         g_Board_Editor_Hokeys_Descr, HK_BACK_SPACE );
+
+    ADD_MENUITEM( track_mnu, ID_POPUP_PCB_DELETE_TRACKSEG, msg, delete_line_xpm );
 
-    ADD_MENUITEM( track_mnu, ID_POPUP_PCB_DELETE_TRACKSEG,
-                  msg, delete_line_xpm );
     if( !flags )
     {
-        msg = AddHotkeyName( _( "Delete Track" ), s_Board_Editor_Hokeys_Descr, HK_DELETE );
-        ADD_MENUITEM( track_mnu, ID_POPUP_PCB_DELETE_TRACK,
-                      msg, delete_track_xpm );
-        ADD_MENUITEM( track_mnu, ID_POPUP_PCB_DELETE_TRACKNET,
-                      _( "Delete Net" ), delete_net_xpm );
+        msg = AddHotkeyName( _( "Delete Track" ), g_Board_Editor_Hokeys_Descr, HK_DELETE );
+        ADD_MENUITEM( track_mnu, ID_POPUP_PCB_DELETE_TRACK, msg, delete_track_xpm );
+        ADD_MENUITEM( track_mnu, ID_POPUP_PCB_DELETE_TRACKNET, _( "Delete Net" ), delete_net_xpm );
     }
+
+    // Add global edition command
+    if( !flags )
+    {
+        PopMenu->AppendSeparator();
+        ADD_MENUITEM( PopMenu, ID_POPUP_PCB_EDIT_ALL_VIAS_AND_TRACK_SIZE,
+                      _( "Global Tracks and Vias Edition" ), width_track_via_xpm );
+    }
+
+    // Add lock/unlock flags menu:
     track_mnu = new wxMenu;
 
     ADD_MENUITEM_WITH_SUBMENU( PopMenu, track_mnu,
@@ -516,14 +513,13 @@ void WinEDA_PcbFrame::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
     track_mnu->Append( ID_POPUP_PCB_LOCK_ON_TRACKSEG, _( "Locked: Yes" ), wxEmptyString, true );
     track_mnu->Append( ID_POPUP_PCB_LOCK_OFF_TRACKSEG, _( "Locked: No" ), wxEmptyString, true );
 
-    if( Track->GetState( SEGM_FIXE ) )
+    if( Track->GetState( TRACK_LOCKED ) )
         track_mnu->Check( ID_POPUP_PCB_LOCK_ON_TRACKSEG, true );
     else
         track_mnu->Check( ID_POPUP_PCB_LOCK_OFF_TRACKSEG, true );
 
     if( !flags )
     {
-        track_mnu->AppendSeparator();
         track_mnu->Append( ID_POPUP_PCB_LOCK_ON_TRACK, _( "Track Locked: Yes" ) );
         track_mnu->Append( ID_POPUP_PCB_LOCK_OFF_TRACK, _( "Track Locked: No" ) );
         track_mnu->AppendSeparator();
@@ -533,13 +529,12 @@ void WinEDA_PcbFrame::createPopupMenuForTracks( TRACK* Track, wxMenu* PopMenu )
 }
 
 
-/********************************************************************************************/
-void WinEDA_PcbFrame::createPopUpMenuForZones( ZONE_CONTAINER* edge_zone, wxMenu* aPopMenu )
-/********************************************************************************************/
-
 /* Create the wxMenuitem list for zone outlines editing and zone filling
  */
+void PCB_EDIT_FRAME::createPopUpMenuForZones( ZONE_CONTAINER* edge_zone, wxMenu* aPopMenu )
 {
+    wxString msg;
+
     if( edge_zone->m_Flags == IS_DRAGGED )
     {
         ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_PLACE_DRAGGED_ZONE_OUTLINE_SEGMENT,
@@ -560,20 +555,21 @@ void WinEDA_PcbFrame::createPopUpMenuForZones( ZONE_CONTAINER* edge_zone, wxMenu
 
         ADD_MENUITEM_WITH_SUBMENU( aPopMenu, zones_menu,
                                    -1, _( "Zones" ), add_zone_xpm );
-        int index;
-        if( ( index = edge_zone->HitTestForCorner( GetScreen()->RefPos( true ) ) ) >= 0 )
+        if( edge_zone->HitTestForCorner( GetScreen()->RefPos( true ) ) )
         {
             ADD_MENUITEM( zones_menu, ID_POPUP_PCB_MOVE_ZONE_CORNER,
                           _( "Move Corner" ), move_xpm );
             ADD_MENUITEM( zones_menu, ID_POPUP_PCB_DELETE_ZONE_CORNER,
                           _( "Delete Corner" ), delete_xpm );
         }
-        else if( ( index = edge_zone->HitTestForEdge( GetScreen()->RefPos( true ) ) ) >= 0 )
+        else if( edge_zone->HitTestForEdge( GetScreen()->RefPos( true ) ) )
         {
             ADD_MENUITEM( zones_menu, ID_POPUP_PCB_ADD_ZONE_CORNER,
                           _( "Create Corner" ), add_corner_xpm );
+            msg = AddHotkeyName( _( "Drag Outline Segment" ), g_Board_Editor_Hokeys_Descr,
+                                 HK_DRAG_ITEM );
             ADD_MENUITEM( zones_menu, ID_POPUP_PCB_DRAG_ZONE_OUTLINE_SEGMENT,
-                          _( "Drag Outline Segment" ), drag_outline_segment_xpm );
+                          msg, drag_outline_segment_xpm );
         }
 
         zones_menu->AppendSeparator();
@@ -584,8 +580,7 @@ void WinEDA_PcbFrame::createPopUpMenuForZones( ZONE_CONTAINER* edge_zone, wxMenu
                       _( "Add Cutout Area" ), add_zone_cutout );
         zones_menu->AppendSeparator();
 
-        ADD_MENUITEM( zones_menu, ID_POPUP_PCB_FILL_ZONE,
-                      _( "Fill Zone" ), fill_zone_xpm );
+        ADD_MENUITEM( zones_menu, ID_POPUP_PCB_FILL_ZONE, _( "Fill Zone" ), fill_zone_xpm );
 
         if( edge_zone->m_FilledPolysList.size() > 0 )
         {
@@ -593,14 +588,16 @@ void WinEDA_PcbFrame::createPopUpMenuForZones( ZONE_CONTAINER* edge_zone, wxMenu
                           _( "Remove Filled Areas in Zone" ), fill_zone_xpm );
         }
 
-        ADD_MENUITEM( zones_menu, ID_POPUP_PCB_MOVE_ZONE_OUTLINES,
-                      _( "Move Zone" ), move_xpm );
+        msg = AddHotkeyName( _( "Move Zone" ), g_Board_Editor_Hokeys_Descr, HK_MOVE_ITEM );
+        ADD_MENUITEM( zones_menu, ID_POPUP_PCB_MOVE_ZONE_OUTLINES, msg, move_xpm );
 
+        msg = AddHotkeyName( _( "Edit Zone Params" ), g_Board_Editor_Hokeys_Descr, HK_EDIT_ITEM );
         ADD_MENUITEM( zones_menu, ID_POPUP_PCB_EDIT_ZONE_PARAMS,
-                      _( "Edit Zone Params" ), edit_xpm );
+                      msg, edit_xpm );
 
         zones_menu->AppendSeparator();
-        if( index >= 0 && edge_zone->m_Poly->IsCutoutContour( edge_zone->m_CornerSelection ) )
+        if( edge_zone->m_CornerSelection >= 0 &&
+            edge_zone->m_Poly->IsCutoutContour( edge_zone->m_CornerSelection ) )
             ADD_MENUITEM( zones_menu, ID_POPUP_PCB_DELETE_ZONE_CUTOUT,
                           _( "Delete Cutout" ), delete_xpm );
 
@@ -610,12 +607,9 @@ void WinEDA_PcbFrame::createPopUpMenuForZones( ZONE_CONTAINER* edge_zone, wxMenu
 }
 
 
-/*********************************************************************************/
-void WinEDA_PcbFrame::createPopUpMenuForFootprints( MODULE* aModule, wxMenu* menu )
-/*********************************************************************************/
-
 /* Create the wxMenuitem list for footprint editing
  */
+void PCB_EDIT_FRAME::createPopUpMenuForFootprints( MODULE* aModule, wxMenu* menu )
 {
     wxMenu*  sub_menu_footprint;
     int      flags = aModule->m_Flags;
@@ -625,28 +619,30 @@ void WinEDA_PcbFrame::createPopUpMenuForFootprints( MODULE* aModule, wxMenu* men
 
     msg = aModule->MenuText( GetBoard() );
     ADD_MENUITEM_WITH_SUBMENU( menu, sub_menu_footprint, -1, msg, module_xpm );
+
     if( !flags )
     {
-        msg = AddHotkeyName( _( "Move" ), s_Board_Editor_Hokeys_Descr, HK_MOVE_FOOTPRINT );
+        msg = AddHotkeyName( _( "Move" ), g_Board_Editor_Hokeys_Descr, HK_MOVE_ITEM );
         ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_MOVE_MODULE_REQUEST,
                       msg, move_module_xpm );
-        msg = AddHotkeyName( _( "Drag" ), s_Board_Editor_Hokeys_Descr, HK_DRAG_FOOTPRINT );
+        msg = AddHotkeyName( _( "Drag" ), g_Board_Editor_Hokeys_Descr, HK_DRAG_ITEM  );
         ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_DRAG_MODULE_REQUEST,
                       msg, drag_module_xpm );
     }
-    msg = AddHotkeyName( _( "Rotate +" ), s_Board_Editor_Hokeys_Descr, HK_ROTATE_FOOTPRINT );
+
+    msg = AddHotkeyName( _( "Rotate +" ), g_Board_Editor_Hokeys_Descr, HK_ROTATE_ITEM );
     ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_ROTATE_MODULE_COUNTERCLOCKWISE,
                   msg, rotate_module_pos_xpm );
     ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_ROTATE_MODULE_CLOCKWISE,
                   _( "Rotate -" ), rotate_module_neg_xpm );
-    msg = AddHotkeyName( _( "Flip" ), s_Board_Editor_Hokeys_Descr, HK_FLIP_FOOTPRINT );
+    msg = AddHotkeyName( _( "Flip" ), g_Board_Editor_Hokeys_Descr, HK_FLIP_FOOTPRINT );
     ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_CHANGE_SIDE_MODULE,
                   msg, invert_module_xpm );
 
     if( !flags )
     {
-        ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_EDIT_MODULE,
-                      _( "Edit" ), edit_module_xpm );
+        msg = AddHotkeyName( _( "Edit" ), g_Board_Editor_Hokeys_Descr, HK_EDIT_ITEM );
+        ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_EDIT_MODULE, msg, edit_module_xpm );
         sub_menu_footprint->AppendSeparator();
         ADD_MENUITEM( sub_menu_footprint, ID_POPUP_PCB_DELETE_MODULE,
                       _( "Delete Module" ), delete_module_xpm );
@@ -654,12 +650,9 @@ void WinEDA_PcbFrame::createPopUpMenuForFootprints( MODULE* aModule, wxMenu* men
 }
 
 
-/********************************************************************/
-void WinEDA_PcbFrame::createPopUpMenuForFpTexts( TEXTE_MODULE* FpText, wxMenu* menu )
-/********************************************************************/
-
 /* Create the wxMenuitem list for editing texts on footprints
  */
+void PCB_EDIT_FRAME::createPopUpMenuForFpTexts( TEXTE_MODULE* FpText, wxMenu* menu )
 {
     wxMenu*  sub_menu_Fp_text;
     int      flags = FpText->m_Flags;
@@ -671,16 +664,26 @@ void WinEDA_PcbFrame::createPopUpMenuForFpTexts( TEXTE_MODULE* FpText, wxMenu* m
     ADD_MENUITEM_WITH_SUBMENU( menu, sub_menu_Fp_text, -1, msg, footprint_text_xpm );
 
     if( !flags )
+    {
+        msg = AddHotkeyName( _( "Move" ), g_Board_Editor_Hokeys_Descr, HK_MOVE_ITEM );
         ADD_MENUITEM( sub_menu_Fp_text, ID_POPUP_PCB_MOVE_TEXTMODULE_REQUEST,
-                      _( "Move" ), move_field_xpm );
+                      msg, move_field_xpm );
+    }
 
+    msg = AddHotkeyName( _( "Rotate" ), g_Board_Editor_Hokeys_Descr, HK_ROTATE_ITEM );
     ADD_MENUITEM( sub_menu_Fp_text, ID_POPUP_PCB_ROTATE_TEXTMODULE,
-                  _( "Rotate" ), rotate_field_xpm );
+                  msg, rotate_field_xpm );
     if( !flags )
+    {
+        msg = AddHotkeyName( _( "Edit" ), g_Board_Editor_Hokeys_Descr, HK_EDIT_ITEM );
         ADD_MENUITEM( sub_menu_Fp_text, ID_POPUP_PCB_EDIT_TEXTMODULE,
-                      _( "Edit" ), edit_text_xpm );
+                      msg, edit_text_xpm );
+        ADD_MENUITEM( sub_menu_Fp_text, ID_POPUP_PCB_RESET_TEXT_SIZE,
+                      _( "Reset Size" ), reset_text_xpm );
+    }
 
-    if( !flags && FpText->m_Type == TEXT_is_DIVERS )    // Graphic texts can be deleted only if are not currently edited
+    // Graphic texts can be deleted only if are not currently edited.
+    if( !flags && FpText->m_Type == TEXT_is_DIVERS )
     {
         ADD_MENUITEM( sub_menu_Fp_text, ID_POPUP_PCB_DELETE_TEXTMODULE,
                       _( "Delete" ), delete_xpm );
@@ -689,6 +692,7 @@ void WinEDA_PcbFrame::createPopUpMenuForFpTexts( TEXTE_MODULE* FpText, wxMenu* m
     if( !flags )
     {
         MODULE* module = (MODULE*) FpText->GetParent();
+
         if( module )
         {
             menu->AppendSeparator();
@@ -698,13 +702,10 @@ void WinEDA_PcbFrame::createPopUpMenuForFpTexts( TEXTE_MODULE* FpText, wxMenu* m
 }
 
 
-/************************************************************************/
-void WinEDA_PcbFrame::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
-/************************************************************************/
-
 /* Create pop menu for pads
  * also update Netclass selection
  */
+void PCB_EDIT_FRAME::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
 {
     wxMenu* sub_menu_Pad;
     int     flags = Pad->m_Flags;
@@ -713,20 +714,18 @@ void WinEDA_PcbFrame::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
         return;
 
     GetBoard()->SetCurrentNetClass( Pad->GetNetClassName() );
-    m_TrackAndViasSizesList_Changed = true;
-    AuxiliaryToolBar_Update_UI();
+    updateTraceWidthSelectBox();
+    updateViaSizeSelectBox();
 
     wxString msg = Pad->MenuText( GetBoard() );
 
     sub_menu_Pad = new wxMenu;
     ADD_MENUITEM_WITH_SUBMENU( menu, sub_menu_Pad, -1, msg, pad_xpm );
 
-    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_MOVE_PAD_REQUEST,
-                  _( "Move" ), move_pad_xpm );
-    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_DRAG_PAD_REQUEST,
-                  _( "Drag" ), drag_pad_xpm );
+    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_MOVE_PAD_REQUEST, _( "Move" ), move_pad_xpm );
+    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_DRAG_PAD_REQUEST, _( "Drag" ), drag_pad_xpm );
 
-    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_EDIT_PAD, _( "Edit Pad" ), options_pad_xpm );
+    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_EDIT_PAD, _( "Edit" ), options_pad_xpm );
     sub_menu_Pad->AppendSeparator();
 
     ADD_MENUITEM_WITH_HELP( sub_menu_Pad, ID_POPUP_PCB_IMPORT_PAD_SETTINGS,
@@ -744,15 +743,16 @@ void WinEDA_PcbFrame::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
                             global_options_pad_xpm );
     sub_menu_Pad->AppendSeparator();
 
-    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_DELETE_PAD,
-                  _( "Delete" ), delete_pad_xpm );
+    ADD_MENUITEM( sub_menu_Pad, ID_POPUP_PCB_DELETE_PAD, _( "Delete" ), delete_pad_xpm );
 
-    if( m_HTOOL_current_state == ID_TOOLBARH_PCB_AUTOROUTE )
+    if( m_HTOOL_current_state == ID_TOOLBARH_PCB_MODE_TRACKS )
     {
         menu->Append( ID_POPUP_PCB_AUTOROUTE_PAD, _( "Autoroute Pad" ) );
         menu->Append( ID_POPUP_PCB_AUTOROUTE_NET, _( "Autoroute Net" ) );
     }
+
     MODULE* module = (MODULE*) Pad->GetParent();
+
     if( module )
     {
         menu->AppendSeparator();
@@ -761,10 +761,8 @@ void WinEDA_PcbFrame::createPopUpMenuForFpPads( D_PAD* Pad, wxMenu* menu )
 }
 
 
-/*****************************************************************************/
-void WinEDA_PcbFrame::createPopUpMenuForTexts( TEXTE_PCB* Text, wxMenu* menu )
-/*****************************************************************************/
 /* Create pop menu for pcb texts */
+void PCB_EDIT_FRAME::createPopUpMenuForTexts( TEXTE_PCB* Text, wxMenu* menu )
 {
     wxMenu*  sub_menu_Text;
     int      flags = Text->m_Flags;
@@ -777,37 +775,35 @@ void WinEDA_PcbFrame::createPopUpMenuForTexts( TEXTE_PCB* Text, wxMenu* menu )
 
     if( !flags )
     {
+        msg = AddHotkeyName( _( "Move" ), g_Board_Editor_Hokeys_Descr, HK_MOVE_ITEM );
         ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_MOVE_TEXTEPCB_REQUEST,
-                      _( "Move" ), move_text_xpm );
+                      msg, move_text_xpm );
     }
-    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_ROTATE_TEXTEPCB,
-                  _( "Rotate" ), rotate_pos_xpm );
-    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_EDIT_TEXTEPCB,
-                  _( "Edit" ), edit_text_xpm );
+    msg = AddHotkeyName( _( "Rotate" ), g_Board_Editor_Hokeys_Descr, HK_ROTATE_ITEM );
+    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_ROTATE_TEXTEPCB, msg, rotate_CCW_xpm );
+    msg = AddHotkeyName( _( "Edit" ), g_Board_Editor_Hokeys_Descr, HK_EDIT_ITEM );
+    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_EDIT_TEXTEPCB, msg, edit_text_xpm );
+    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_RESET_TEXT_SIZE,
+                  _( "Reset Size" ), reset_text_xpm );
 
     sub_menu_Text->AppendSeparator();
-    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_DELETE_TEXTEPCB,
-                  _( "Delete" ), delete_text_xpm );
+    ADD_MENUITEM( sub_menu_Text, ID_POPUP_PCB_DELETE_TEXTEPCB, _( "Delete" ), delete_text_xpm );
 }
 
 
-/**********************************************************************/
-void WinEDA_PcbFrame::createPopUpMenuForMarkers( MARKER_PCB* aMarker, wxMenu* aPopMenu )
-/**********************************************************************/
+void PCB_EDIT_FRAME::createPopUpMenuForMarkers( MARKER_PCB* aMarker, wxMenu* aPopMenu )
 {
     ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_DELETE_MARKER, _( "Delete Marker" ), delete_xpm );
     ADD_MENUITEM( aPopMenu, ID_POPUP_PCB_GETINFO_MARKER, _( "Marker Error Info" ), info_xpm );
 }
 
 
-/*******************************************************/
-static wxMenu* Append_Track_Width_List( BOARD* aBoard )
-/*******************************************************/
-
-/** function Append_Track_Width_List
+/**
+ * Function Append_Track_Width_List
  * creates a wxMenu * which shows the last used track widths and via diameters
  * @return a pointeur to the menu
  */
+static wxMenu* Append_Track_Width_List( BOARD* aBoard )
 {
     wxString msg;
     wxMenu*  trackwidth_menu;
@@ -815,10 +811,8 @@ static wxMenu* Append_Track_Width_List( BOARD* aBoard )
 
     trackwidth_menu = new wxMenu;
 
-    trackwidth_menu->Append( ID_POPUP_PCB_SELECT_AUTO_WIDTH,
-                             _( "Auto Width" ),
-                             _(
-                                 "Use the track width when starting on a track, otherwise the current track width" ),
+    trackwidth_menu->Append( ID_POPUP_PCB_SELECT_AUTO_WIDTH, _( "Auto Width" ),
+                             _( "Use the track width when starting on a track, otherwise the current track width" ),
                              true );
 
     if( aBoard->GetBoardDesignSettings()->m_UseConnectedTrackWidth )
@@ -834,31 +828,26 @@ static wxMenu* Append_Track_Width_List( BOARD* aBoard )
 
     for( unsigned ii = 0; ii < aBoard->m_TrackWidthList.size(); ii++ )
     {
-        value = ReturnStringFromValue( g_UnitMetric, aBoard->m_TrackWidthList[ii],
+        value = ReturnStringFromValue( g_UserUnit, aBoard->m_TrackWidthList[ii],
                                        PCB_INTERNAL_UNIT, true );
         msg.Printf( _( "Track %s" ), GetChars( value ) );
+
         if( ii == 0 )
             msg << _( " (use NetClass)" );
+
         trackwidth_menu->Append( ID_POPUP_PCB_SELECT_WIDTH1 + ii, msg, wxEmptyString, true );
     }
 
-    if( aBoard->GetBoardDesignSettings()->m_UseConnectedTrackWidth )
-        trackwidth_menu->Check( ID_POPUP_PCB_SELECT_AUTO_WIDTH, true );
-    else
-    {
-        if( aBoard->m_TrackWidthSelector < aBoard->m_TrackWidthList.size() )
-            trackwidth_menu->Check( ID_POPUP_PCB_SELECT_WIDTH1 + aBoard->m_TrackWidthSelector,
-                                    true );
-    }
-
     trackwidth_menu->AppendSeparator();
+
     for( unsigned ii = 0; ii < aBoard->m_ViasDimensionsList.size(); ii++ )
     {
-        value = ReturnStringFromValue( g_UnitMetric, aBoard->m_ViasDimensionsList[ii].m_Diameter,
+        value = ReturnStringFromValue( g_UserUnit, aBoard->m_ViasDimensionsList[ii].m_Diameter,
                                        PCB_INTERNAL_UNIT, true );
-        wxString drill = ReturnStringFromValue( g_UnitMetric,
+        wxString drill = ReturnStringFromValue( g_UserUnit,
                                                 aBoard->m_ViasDimensionsList[ii].m_Drill,
                                                 PCB_INTERNAL_UNIT,  true );
+
         if( aBoard->m_ViasDimensionsList[ii].m_Drill <= 0 )
             msg.Printf( _( "Via %s" ), GetChars( value ) );
         else
@@ -867,11 +856,9 @@ static wxMenu* Append_Track_Width_List( BOARD* aBoard )
         }
         if( ii == 0 )
             msg << _( " (use NetClass)" );
+
         trackwidth_menu->Append( ID_POPUP_PCB_SELECT_VIASIZE1 + ii, msg, wxEmptyString, true );
     }
 
-    if( aBoard->m_ViaSizeSelector < aBoard->m_ViasDimensionsList.size() )
-        trackwidth_menu->Check( ID_POPUP_PCB_SELECT_VIASIZE1 + aBoard->m_ViaSizeSelector, true );
-
     return trackwidth_menu;
 }
