@@ -1,7 +1,8 @@
 /****************************************************************************/
-/* Name:        zones_by_polygon.cpp										*/
+/* Name:        zones_test_and_combine_areas.cpp							*/
 /* Licence:     GPL License													*/
-/* functions to test, merges and cut polygons used as copper areas outlines */
+/* functions to test, merge and cut polygons used as copper areas outlines  */
+/* some pieces of code come from FreePCB                                    */
 /****************************************************************************/
 
 #include <vector>
@@ -10,41 +11,61 @@
 #include "common.h"
 #include "confirm.h"
 #include "pcbnew.h"
+#include "drc_stuff.h"
 
-using namespace std;
-
-#undef ASSERT
-#define ASSERT wxASSERT
-
-bool bDontShowSelfIntersectionArcsWarning;
-bool bDontShowSelfIntersectionWarning;
-bool bDontShowIntersectionArcsWarning;
-bool bDontShowIntersectionWarning;
+static bool bDontShowSelfIntersectionArcsWarning;
+static bool bDontShowSelfIntersectionWarning;
+static bool bDontShowIntersectionArcsWarning;
 
 
 /**
  * Function AddArea
- * add empty copper area to net
+ * Add an empty copper area to board areas list
+ * @param aNewZonesList = a PICKED_ITEMS_LIST * where to store new areas pickers (useful in undo commands)
+ *                      can be NULL
+ * @param aNetcode = the necode of the copper area (0 = no net)
+ * @param aLayer = the layer of area
+ * @param aStartPointPosition = position of the first point of the polygon outline of this area
+ * @param aHatch = hacth option
  * @return pointer to the new area
  */
-ZONE_CONTAINER* BOARD::AddArea( int netcode, int layer, int x, int y, int hatch )
+ZONE_CONTAINER* BOARD::AddArea( PICKED_ITEMS_LIST* aNewZonesList, int aNetcode,
+            int aLayer, wxPoint aStartPointPosition, int aHatch )
 {
-    ZONE_CONTAINER* new_area = InsertArea( netcode, m_ZoneDescriptorList.size(
-                                               ) - 1, layer, x, y, hatch );
+    ZONE_CONTAINER* new_area = InsertArea( aNetcode,
+                        m_ZoneDescriptorList.size( ) - 1,
+                        aLayer, aStartPointPosition.x, aStartPointPosition.y, aHatch );
 
+    if( aNewZonesList )
+    {
+        ITEM_PICKER picker( new_area, UR_NEW );
+        picker.m_PickedItemType = new_area->Type();
+        aNewZonesList->PushItem( picker );
+    }
     return new_area;
 }
 
 
 /**
- * remove copper area from net
- * @param  area = area to remove
- * @return 0
+ * Function RemoveArea
+ * remove copper area from net, and put it in a deleted list (if exists)
+ * @param aDeletedList = a PICKED_ITEMS_LIST * where to store deleted areas (useful in undo commands)
+ *                      can be NULL
+ * @param  area_to_remove = area to delete or put in deleted list
  */
-int BOARD::RemoveArea( ZONE_CONTAINER* area_to_remove )
+void BOARD::RemoveArea( PICKED_ITEMS_LIST* aDeletedList, ZONE_CONTAINER* area_to_remove )
 {
-    Delete( area_to_remove );
-    return 0;
+    if( area_to_remove == NULL )
+        return;
+    if( aDeletedList )
+    {
+        ITEM_PICKER picker( area_to_remove, UR_DELETED );
+        picker.m_PickedItemType = area_to_remove->Type();
+        aDeletedList->PushItem( picker );
+        Remove( area_to_remove );   // remove from zone list, but does not delete it
+    }
+    else
+        Delete( area_to_remove );
 }
 
 
@@ -86,9 +107,8 @@ int BOARD::CompleteArea( ZONE_CONTAINER* area_to_complete, int style )
         return 1;
     }
     else
-    {
-        RemoveArea( area_to_complete );
-    }
+        Delete( area_to_complete );
+
     return 0;
 }
 
@@ -210,19 +230,24 @@ int BOARD::TestAreaPolygon( ZONE_CONTAINER* CurrArea )
  * Function ClipAreaPolygon
  * Process an area that has been modified, by clipping its polygon against itself.
  * This may change the number and order of copper areas in the net.
+ * @param aNewZonesList = a PICKED_ITEMS_LIST * where to store new areas pickers (useful in undo commands)
+ *                      can be NULL
+ * @param aCurrArea = the zone to process
  * @param bMessageBoxInt == true, shows message when clipping occurs.
  * @param  bMessageBoxArc == true, shows message when clipping can't be done due to arcs.
+ * @param bRetainArcs = true to handle arcs (not really used in kicad)
  * @return:
  *	-1 if arcs intersect other sides, so polygon can't be clipped
  *	 0 if no intersecting sides
  *	 1 if intersecting sides
  * Also sets areas->utility1 flags if areas are modified
  */
-int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
+int BOARD::ClipAreaPolygon( PICKED_ITEMS_LIST * aNewZonesList,
+                            ZONE_CONTAINER* aCurrArea,
                             bool bMessageBoxArc, bool bMessageBoxInt, bool bRetainArcs )
 {
-    CPolyLine* curr_polygon = CurrArea->m_Poly;
-    int        test = TestAreaPolygon( CurrArea ); // this sets utility2 flag
+    CPolyLine* curr_polygon = aCurrArea->m_Poly;
+    int        test = TestAreaPolygon( aCurrArea ); // this sets utility2 flag
 
     if( test == -1 && !bRetainArcs )
         test = 1;
@@ -233,7 +258,7 @@ int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
         {
             wxString str;
             str.Printf( wxT( "Area %8.8X of net \"%s\" has arcs intersecting other sides.\n" ),
-                       CurrArea->m_TimeStamp, CurrArea->m_Netname.GetData() );
+                       aCurrArea->m_TimeStamp, GetChars( aCurrArea->m_Netname ) );
             str += wxT( "This may cause problems with other editing operations,\n" );
             str += wxT( "such as adding cutouts. It can't be fixed automatically.\n" );
             str += wxT( "Manual correction is recommended." );
@@ -246,7 +271,7 @@ int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
     for( unsigned ia = 0; ia < m_ZoneDescriptorList.size(); ia++ )
         m_ZoneDescriptorList[ia]->utility = 0;
 
-    CurrArea->utility = 1;
+    aCurrArea->utility = 1;
 
     if( test == 1 )
     {
@@ -256,7 +281,7 @@ int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
             wxString str;
             str.Printf( wxT(
                            "Area %8.8X of net \"%s\" is self-intersecting and will be clipped.\n" ),
-                       CurrArea->m_TimeStamp, CurrArea->m_Netname.GetData() );
+                       aCurrArea->m_TimeStamp, GetChars( aCurrArea->m_Netname ) );
             str += wxT( "This may result in splitting the area.\n" );
             str += wxT( "If the area is complex, this may take a few seconds." );
             wxMessageBox( str );
@@ -270,7 +295,7 @@ int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
     {
         std::vector<CPolyLine*>* pa = new std::vector<CPolyLine*>;
         curr_polygon->Undraw();
-        int n_poly = CurrArea->m_Poly->NormalizeAreaOutlines( pa, bRetainArcs );
+        int n_poly = aCurrArea->m_Poly->NormalizeAreaOutlines( pa, bRetainArcs );
         if( n_poly > 1 )    // i.e if clipping has created some polygons, we must add these new copper areas
         {
             ZONE_CONTAINER* NewArea;
@@ -278,7 +303,8 @@ int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
             {
                 // create new copper area and copy poly into it
                 CPolyLine* new_p = (*pa)[ip - 1];
-                NewArea = AddArea( CurrArea->GetNet(), CurrArea->GetLayer(), 0, 0, 0 );
+                NewArea = AddArea( aNewZonesList, aCurrArea->GetNet(), aCurrArea->GetLayer(),
+                                wxPoint(0, 0), CPolyLine::NO_HATCH );
 
                 // remove the poly that was automatically created for the new area
                 // and replace it with a poly from NormalizeWithKbool
@@ -299,20 +325,23 @@ int BOARD::ClipAreaPolygon( ZONE_CONTAINER* CurrArea,
  * Process an area that has been modified, by clipping its polygon against
  * itself and the polygons for any other areas on the same net.
  * This may change the number and order of copper areas in the net.
+ * @param aModifiedZonesList = a PICKED_ITEMS_LIST * where to store deleted or added areas (useful in undo commands
+ *                      can be NULL
  * @param modified_area = area to test
+ * @param  bMessageBoxArc if true, shows message when clipping can't be done due to arcs.
  * @param bMessageBoxInt == true, shows message when clipping occurs.
- * @param  bMessageBoxArc == true, shows message when clipping can't be done due to arcs.
  * @return :
  * -1 if arcs intersect other sides, so polygon can't be clipped
  *  0 if no intersecting sides
  *  1 if intersecting sides, polygon clipped
  */
-int BOARD::AreaPolygonModified( ZONE_CONTAINER* modified_area,
+int BOARD::AreaPolygonModified( PICKED_ITEMS_LIST* aModifiedZonesList,
+                                ZONE_CONTAINER* modified_area,
                                 bool            bMessageBoxArc,
                                 bool            bMessageBoxInt )
 {
     // clip polygon against itself
-    int test = ClipAreaPolygon( modified_area, bMessageBoxArc, bMessageBoxInt );
+    int test = ClipAreaPolygon( aModifiedZonesList, modified_area, bMessageBoxArc, bMessageBoxInt );
 
     if( test == -1 )
         return test;
@@ -325,7 +354,7 @@ int BOARD::AreaPolygonModified( ZONE_CONTAINER* modified_area,
     else
         bCheckAllAreas = TestAreaIntersections( modified_area );
     if( bCheckAllAreas )
-        CombineAllAreasInNet( modified_area->GetNet(), bMessageBoxInt, true );
+        CombineAllAreasInNet( aModifiedZonesList, modified_area->GetNet(), bMessageBoxInt, true );
 
     if( layer >= FIRST_NO_COPPER_LAYER )    // Refill non copper zones on this layer
     {
@@ -347,7 +376,7 @@ int BOARD::AreaPolygonModified( ZONE_CONTAINER* modified_area,
 
         // Remove zone because it is incorrect:
         else
-            RemoveArea( zone );
+            RemoveArea( aModifiedZonesList, zone );
     }
 
     return test;
@@ -357,13 +386,15 @@ int BOARD::AreaPolygonModified( ZONE_CONTAINER* modified_area,
 /**
  * Function CombineAllAreasInNet
  * Checks all copper areas in net for intersections, combining them if found
+ * @param aDeletedList = a PICKED_ITEMS_LIST * where to store deleted areas (useful in undo commands
+ *                      can be NULL
  * @param aNetCode = net to consider
  * @param bMessageBox : if true display warning message box
  * @param bUseUtility : if true, don't check areas if both utility flags are 0
  * Sets utility flag = 1 for any areas modified
  * If an area has self-intersecting arcs, doesn't try to combine it
  */
-int BOARD::CombineAllAreasInNet( int aNetCode, bool bMessageBox, bool bUseUtility )
+int BOARD::CombineAllAreasInNet( PICKED_ITEMS_LIST* aDeletedList, int aNetCode, bool bMessageBox, bool bUseUtility )
 {
     if( m_ZoneDescriptorList.size() <= 1 )
         return 0;
@@ -401,7 +432,7 @@ int BOARD::CombineAllAreasInNet( int aNetCode, bool bMessageBox, bool bUseUtilit
                     {
                         int ret = TestAreaIntersection( curr_area, area2 );
                         if( ret == 1 )
-                            ret = CombineAreas( curr_area, area2 );
+                            ret = CombineAreas( aDeletedList, curr_area, area2 );
                         if( ret == 1 )
                         {
                             mod_ia1 = true;
@@ -416,7 +447,7 @@ int BOARD::CombineAllAreasInNet( int aNetCode, bool bMessageBox, bool bUseUtilit
                                         "Areas %d and %d of net \"%s\" intersect, but some of the intersecting sides are arcs.\n" ),
                                     ia1 + 1,
                                     ia2 + 1,
-                                    curr_area->m_Netname.GetData() );
+                                    GetChars( curr_area->m_Netname ) );
                                 str += wxT( "Therefore, these areas can't be combined." );
                                 wxMessageBox( str );
                             }
@@ -675,16 +706,22 @@ int BOARD::TestAreaIntersection( ZONE_CONTAINER* area_ref, ZONE_CONTAINER* area_
 /**
  * Function CombineAreas
  * If possible, combine 2 copper areas
- * area_ref must be BEFORE area_to_combine in m_ZoneDescriptorList
+ * @param aDeletedList = a PICKED_ITEMS_LIST * where to store deleted areas (useful in undo commands
+ *                      can be NULL
+ * @param area_ref = tje main area (zone)
+ * @param area_to_combine = the zone that can be merged with area_ref
+ * area_ref must be BEFORE area_to_combine
  * area_to_combine will be deleted, if areas are combined
  * @return : 0 if no intersection
  *         1 if intersection
  *         2 if arcs intersect
  */
-int BOARD::CombineAreas( ZONE_CONTAINER* area_ref, ZONE_CONTAINER* area_to_combine )
+int BOARD::CombineAreas( PICKED_ITEMS_LIST* aDeletedList, ZONE_CONTAINER* area_ref, ZONE_CONTAINER* area_to_combine )
 {
     if( area_ref == area_to_combine )
-        ASSERT( 0 );
+    {
+        wxASSERT( 0 );
+    }
 
     // polygons intersect, combine them
     std::vector<CArc> arc_array1;
@@ -762,12 +799,15 @@ int BOARD::CombineAreas( ZONE_CONTAINER* area_ref, ZONE_CONTAINER* area_to_combi
 #endif
 
     // add holes
+    bool show_error = true;
     while( booleng->StartPolygonGet() )
     {
-        if( booleng->GetPolygonPointEdgeType() != KB_INSIDE_EDGE )
+        if( booleng->GetPolygonPointEdgeType() != KB_INSIDE_EDGE ) // we expect all vertex are holes inside the main outline
         {
-            DisplayError( NULL,
+            if( show_error )    // show this error only once, if happens
+                DisplayError( NULL,
                          wxT( "BOARD::CombineAreas() error: unexpected outside contour descriptor" ) );
+            show_error = false;
             continue;
         }
         while( booleng->PolygonHasMorePoints() )
@@ -782,7 +822,7 @@ int BOARD::CombineAreas( ZONE_CONTAINER* area_ref, ZONE_CONTAINER* area_to_combi
     }
 
     if( !keep_area_to_combine )
-        RemoveArea( area_to_combine );
+        RemoveArea( aDeletedList, area_to_combine );
 
     area_ref->utility = 1;
     area_ref->m_Poly->RestoreArcs( &arc_array1 );
@@ -808,19 +848,24 @@ int BOARD::Test_Drc_Areas_Outlines_To_Areas_Outlines( ZONE_CONTAINER* aArea_To_E
 {
     wxString str;
     long     nerrors = 0;
+    int zone2zoneClearance;
 
     // iterate through all areas
     for( int ia = 0; ia < GetAreaCount(); ia++ )
     {
         ZONE_CONTAINER* Area_Ref = GetArea( ia );
+        CPolyLine* refSmoothedPoly = Area_Ref->GetSmoothedPoly();
+
         if( !Area_Ref->IsOnCopperLayer() )
             continue;
 
         if( aArea_To_Examine && (aArea_To_Examine != Area_Ref) )
             continue;
+
         for( int ia2 = 0; ia2 < GetAreaCount(); ia2++ )
         {
             ZONE_CONTAINER* Area_To_Test = GetArea( ia2 );
+            CPolyLine* testSmoothedPoly = Area_To_Test->GetSmoothedPoly();
 
             if( Area_Ref == Area_To_Test )
                 continue;
@@ -833,19 +878,27 @@ int BOARD::Test_Drc_Areas_Outlines_To_Areas_Outlines( ZONE_CONTAINER* aArea_To_E
             if( Area_Ref->GetNet() == Area_To_Test->GetNet() && Area_Ref->GetNet() >= 0 )
                 continue;
 
+            /* Examine a candidate zone: compare Area_To_Test to Area_Ref
+            */
+
+            // Calculate the clearance used in zone to zone test:
+            zone2zoneClearance = Area_Ref->GetClearance(Area_To_Test);
+            zone2zoneClearance = MAX( zone2zoneClearance, Area_Ref->m_ZoneClearance );
+            zone2zoneClearance = MAX( zone2zoneClearance, Area_To_Test->m_ZoneClearance );
+
             // test for some corners of Area_Ref inside Area_To_Test
-            for( int ic = 0; ic < Area_Ref->m_Poly->GetNumCorners(); ic++ )
+            for( int ic = 0; ic < refSmoothedPoly->GetNumCorners(); ic++ )
             {
-                int x = Area_Ref->m_Poly->GetX( ic );
-                int y = Area_Ref->m_Poly->GetY( ic );
-                if( Area_To_Test->m_Poly->TestPointInside( x, y ) )
+                int x = refSmoothedPoly->GetX( ic );
+                int y = refSmoothedPoly->GetY( ic );
+                if( testSmoothedPoly->TestPointInside( x, y ) )
                 {
                     // COPPERAREA_COPPERAREA error: copper area ref corner inside copper area
                     if( aCreate_Markers )
                     {
                         wxString msg1   = Area_Ref->MenuText( this );
                         wxString msg2   = Area_To_Test->MenuText( this );
-                        MARKER*  marker = new MARKER( COPPERAREA_INSIDE_COPPERAREA, wxPoint( x, y ),
+                        MARKER_PCB*  marker = new MARKER_PCB( COPPERAREA_INSIDE_COPPERAREA, wxPoint( x, y ),
                                                      msg1, wxPoint( x, y ),
                                                      msg2, wxPoint( x, y ) );
                         Add( marker );
@@ -855,18 +908,18 @@ int BOARD::Test_Drc_Areas_Outlines_To_Areas_Outlines( ZONE_CONTAINER* aArea_To_E
             }
 
             // test for some corners of Area_To_Test inside Area_Ref
-            for( int ic2 = 0; ic2 < Area_To_Test->m_Poly->GetNumCorners(); ic2++ )
+            for( int ic2 = 0; ic2 < testSmoothedPoly->GetNumCorners(); ic2++ )
             {
-                int x = Area_To_Test->m_Poly->GetX( ic2 );
-                int y = Area_To_Test->m_Poly->GetY( ic2 );
-                if( Area_Ref->m_Poly->TestPointInside( x, y ) )
+                int x = testSmoothedPoly->GetX( ic2 );
+                int y = testSmoothedPoly->GetY( ic2 );
+                if( refSmoothedPoly->TestPointInside( x, y ) )
                 {
                     // COPPERAREA_COPPERAREA error: copper area corner inside copper area ref
                     if( aCreate_Markers )
                     {
                         wxString msg1   = Area_To_Test->MenuText( this );
                         wxString msg2   = Area_Ref->MenuText( this );
-                        MARKER*  marker = new MARKER( COPPERAREA_INSIDE_COPPERAREA, wxPoint( x, y ),
+                        MARKER_PCB*  marker = new MARKER_PCB( COPPERAREA_INSIDE_COPPERAREA, wxPoint( x, y ),
                                                      msg1, wxPoint( x, y ),
                                                      msg2, wxPoint( x, y ) );
                         Add( marker );
@@ -876,64 +929,65 @@ int BOARD::Test_Drc_Areas_Outlines_To_Areas_Outlines( ZONE_CONTAINER* aArea_To_E
             }
 
             // now test spacing between areas
-            for( int icont = 0; icont < Area_Ref->m_Poly->GetNumContours(); icont++ )
+            for( int icont = 0; icont < refSmoothedPoly->GetNumContours(); icont++ )
             {
-                int ic_start = Area_Ref->m_Poly->GetContourStart( icont );
-                int ic_end   = Area_Ref->m_Poly->GetContourEnd( icont );
+                int ic_start = refSmoothedPoly->GetContourStart( icont );
+                int ic_end   = refSmoothedPoly->GetContourEnd( icont );
                 for( int ic = ic_start; ic<=ic_end; ic++ )
                 {
-                    int ax1 = Area_Ref->m_Poly->GetX( ic );
-                    int ay1 = Area_Ref->m_Poly->GetY( ic );
+                    int ax1 = refSmoothedPoly->GetX( ic );
+                    int ay1 = refSmoothedPoly->GetY( ic );
                     int ax2, ay2;
                     if( ic == ic_end )
                     {
-                        ax2 = Area_Ref->m_Poly->GetX( ic_start );
-                        ay2 = Area_Ref->m_Poly->GetY( ic_start );
+                        ax2 = refSmoothedPoly->GetX( ic_start );
+                        ay2 = refSmoothedPoly->GetY( ic_start );
                     }
                     else
                     {
-                        ax2 = Area_Ref->m_Poly->GetX( ic + 1 );
-                        ay2 = Area_Ref->m_Poly->GetY( ic + 1 );
+                        ax2 = refSmoothedPoly->GetX( ic + 1 );
+                        ay2 = refSmoothedPoly->GetY( ic + 1 );
                     }
-                    int astyle = Area_Ref->m_Poly->GetSideStyle( ic );
-                    for( int icont2 = 0; icont2 < Area_To_Test->m_Poly->GetNumContours(); icont2++ )
+                    int astyle = refSmoothedPoly->GetSideStyle( ic );
+                    for( int icont2 = 0; icont2 < testSmoothedPoly->GetNumContours(); icont2++ )
                     {
-                        int ic_start2 = Area_To_Test->m_Poly->GetContourStart( icont2 );
-                        int ic_end2   = Area_To_Test->m_Poly->GetContourEnd( icont2 );
+                        int ic_start2 = testSmoothedPoly->GetContourStart( icont2 );
+                        int ic_end2   = testSmoothedPoly->GetContourEnd( icont2 );
                         for( int ic2 = ic_start2; ic2<=ic_end2; ic2++ )
                         {
-                            int bx1 = Area_To_Test->m_Poly->GetX( ic2 );
-                            int by1 = Area_To_Test->m_Poly->GetY( ic2 );
+                            int bx1 = testSmoothedPoly->GetX( ic2 );
+                            int by1 = testSmoothedPoly->GetY( ic2 );
                             int bx2, by2;
                             if( ic2 == ic_end2 )
                             {
-                                bx2 = Area_To_Test->m_Poly->GetX( ic_start2 );
-                                by2 = Area_To_Test->m_Poly->GetY( ic_start2 );
+                                bx2 = testSmoothedPoly->GetX( ic_start2 );
+                                by2 = testSmoothedPoly->GetY( ic_start2 );
                             }
                             else
                             {
-                                bx2 = Area_To_Test->m_Poly->GetX( ic2 + 1 );
-                                by2 = Area_To_Test->m_Poly->GetY( ic2 + 1 );
+                                bx2 = testSmoothedPoly->GetX( ic2 + 1 );
+                                by2 = testSmoothedPoly->GetY( ic2 + 1 );
                             }
-                            int bstyle = Area_To_Test->m_Poly->GetSideStyle( ic2 );
+                            int bstyle = testSmoothedPoly->GetSideStyle( ic2 );
                             int x, y;
-                            int d = ::GetClearanceBetweenSegments(
+
+                            int d = GetClearanceBetweenSegments(
                                 bx1, by1, bx2, by2, bstyle,
                                 0,
                                 ax1, ay1, ax2,
                                 ay2, astyle,
                                 0,
-                                g_DesignSettings.
-                                m_TrackClearence,
+                                zone2zoneClearance,
                                 &x, &y );
-                            if( d < g_DesignSettings.m_TrackClearence )
+
+                            if( d < zone2zoneClearance )
                             {
                                 // COPPERAREA_COPPERAREA error : intersect or too close
                                 if( aCreate_Markers )
                                 {
                                     wxString msg1   = Area_Ref->MenuText( this );
                                     wxString msg2   = Area_To_Test->MenuText( this );
-                                    MARKER*  marker = new MARKER( COPPERAREA_CLOSE_TO_COPPERAREA,
+                                    MARKER_PCB*  marker = new MARKER_PCB( COPPERAREA_CLOSE_TO_COPPERAREA,
                                                                  wxPoint( x, y ),
                                                                  msg1, wxPoint( x, y ),
                                                                  msg2, wxPoint( x, y ) );
@@ -1046,7 +1100,7 @@ bool DRC::doEdgeZoneDrc( ZONE_CONTAINER* aArea, int aCornerIndex )
                 }
                 int bstyle = Area_To_Test->m_Poly->GetSideStyle( ic2 );
                 int x, y;
-                int d = ::GetClearanceBetweenSegments( bx1, by1, bx2, by2, bstyle,
+                int d = GetClearanceBetweenSegments( bx1, by1, bx2, by2, bstyle,
                                                        0,
                                                        ax1, ay1, ax2, ay2, astyle,
                                                        0,
